@@ -5,16 +5,16 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "monocdk-experiment",
-    "1.63.0",
+    "1.64.0",
     __name__[0:-6],
-    "monocdk-experiment@1.63.0.jsii.tgz",
+    "monocdk-experiment@1.64.0.jsii.tgz",
 )
 
 __all__ = [
