@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -51,7 +51,9 @@ class FunctionHook(
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, scope: _Construct_f50a3f53, lifecycle_hook: _ILifecycleHook_04206686
+        self,
+        scope: _Construct_f50a3f53,
+        lifecycle_hook: _ILifecycleHook_04206686,
     ) -> _LifecycleHookTargetConfig_83c58429:
         """Called when this object is used as the target of a lifecycle hook.
 
@@ -86,7 +88,9 @@ class QueueHook(
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, _scope: _Construct_f50a3f53, lifecycle_hook: _ILifecycleHook_04206686
+        self,
+        _scope: _Construct_f50a3f53,
+        lifecycle_hook: _ILifecycleHook_04206686,
     ) -> _LifecycleHookTargetConfig_83c58429:
         """Called when this object is used as the target of a lifecycle hook.
 
@@ -121,7 +125,9 @@ class TopicHook(
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, _scope: _Construct_f50a3f53, lifecycle_hook: _ILifecycleHook_04206686
+        self,
+        _scope: _Construct_f50a3f53,
+        lifecycle_hook: _ILifecycleHook_04206686,
     ) -> _LifecycleHookTargetConfig_83c58429:
         """Called when this object is used as the target of a lifecycle hook.
 
