@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,7 +36,7 @@ class CfnBudget(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         budget: typing.Union["BudgetDataProperty", _IResolvable_9ceae33e],
         notifications_with_subscribers: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]] = None,
@@ -68,25 +68,26 @@ class CfnBudget(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="budget")
     def budget(self) -> typing.Union["BudgetDataProperty", _IResolvable_9ceae33e]:
         """``AWS::Budgets::Budget.Budget``.
@@ -96,13 +97,14 @@ class CfnBudget(
         """
         return jsii.get(self, "budget")
 
-    @budget.setter
+    @budget.setter # type: ignore
     def budget(
-        self, value: typing.Union["BudgetDataProperty", _IResolvable_9ceae33e]
+        self,
+        value: typing.Union["BudgetDataProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "budget", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="notificationsWithSubscribers")
     def notifications_with_subscribers(
         self,
@@ -114,7 +116,7 @@ class CfnBudget(
         """
         return jsii.get(self, "notificationsWithSubscribers")
 
-    @notifications_with_subscribers.setter
+    @notifications_with_subscribers.setter # type: ignore
     def notifications_with_subscribers(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]],
@@ -139,10 +141,10 @@ class CfnBudget(
         def __init__(
             self,
             *,
-            budget_type: str,
-            time_unit: str,
+            budget_type: builtins.str,
+            time_unit: builtins.str,
             budget_limit: typing.Optional[typing.Union["CfnBudget.SpendProperty", _IResolvable_9ceae33e]] = None,
-            budget_name: typing.Optional[str] = None,
+            budget_name: typing.Optional[builtins.str] = None,
             cost_filters: typing.Any = None,
             cost_types: typing.Optional[typing.Union["CfnBudget.CostTypesProperty", _IResolvable_9ceae33e]] = None,
             planned_budget_limits: typing.Any = None,
@@ -161,7 +163,7 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "budget_type": budget_type,
                 "time_unit": time_unit,
             }
@@ -179,22 +181,26 @@ class CfnBudget(
                 self._values["time_period"] = time_period
 
         @builtins.property
-        def budget_type(self) -> str:
+        def budget_type(self) -> builtins.str:
             """``CfnBudget.BudgetDataProperty.BudgetType``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-budgettype
             """
-            return self._values.get("budget_type")
+            result = self._values.get("budget_type")
+            assert result is not None, "Required property 'budget_type' is missing"
+            return result
 
         @builtins.property
-        def time_unit(self) -> str:
+        def time_unit(self) -> builtins.str:
             """``CfnBudget.BudgetDataProperty.TimeUnit``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-timeunit
             """
-            return self._values.get("time_unit")
+            result = self._values.get("time_unit")
+            assert result is not None, "Required property 'time_unit' is missing"
+            return result
 
         @builtins.property
         def budget_limit(
@@ -205,16 +211,18 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-budgetlimit
             """
-            return self._values.get("budget_limit")
+            result = self._values.get("budget_limit")
+            return result
 
         @builtins.property
-        def budget_name(self) -> typing.Optional[str]:
+        def budget_name(self) -> typing.Optional[builtins.str]:
             """``CfnBudget.BudgetDataProperty.BudgetName``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-budgetname
             """
-            return self._values.get("budget_name")
+            result = self._values.get("budget_name")
+            return result
 
         @builtins.property
         def cost_filters(self) -> typing.Any:
@@ -223,7 +231,8 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-costfilters
             """
-            return self._values.get("cost_filters")
+            result = self._values.get("cost_filters")
+            return result
 
         @builtins.property
         def cost_types(
@@ -234,7 +243,8 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-costtypes
             """
-            return self._values.get("cost_types")
+            result = self._values.get("cost_types")
+            return result
 
         @builtins.property
         def planned_budget_limits(self) -> typing.Any:
@@ -243,7 +253,8 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-plannedbudgetlimits
             """
-            return self._values.get("planned_budget_limits")
+            result = self._values.get("planned_budget_limits")
+            return result
 
         @builtins.property
         def time_period(
@@ -254,12 +265,13 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-budgetdata.html#cfn-budgets-budget-budgetdata-timeperiod
             """
-            return self._values.get("time_period")
+            result = self._values.get("time_period")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -288,17 +300,17 @@ class CfnBudget(
         def __init__(
             self,
             *,
-            include_credit: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            include_discount: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            include_other_subscription: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            include_recurring: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            include_refund: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            include_subscription: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            include_support: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            include_tax: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            include_upfront: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            use_amortized: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            use_blended: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            include_credit: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            include_discount: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            include_other_subscription: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            include_recurring: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            include_refund: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            include_subscription: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            include_support: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            include_tax: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            include_upfront: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            use_amortized: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+            use_blended: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param include_credit: ``CfnBudget.CostTypesProperty.IncludeCredit``.
@@ -316,7 +328,7 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if include_credit is not None:
                 self._values["include_credit"] = include_credit
             if include_discount is not None:
@@ -343,128 +355,139 @@ class CfnBudget(
         @builtins.property
         def include_credit(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeCredit``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includecredit
             """
-            return self._values.get("include_credit")
+            result = self._values.get("include_credit")
+            return result
 
         @builtins.property
         def include_discount(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeDiscount``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includediscount
             """
-            return self._values.get("include_discount")
+            result = self._values.get("include_discount")
+            return result
 
         @builtins.property
         def include_other_subscription(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeOtherSubscription``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includeothersubscription
             """
-            return self._values.get("include_other_subscription")
+            result = self._values.get("include_other_subscription")
+            return result
 
         @builtins.property
         def include_recurring(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeRecurring``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includerecurring
             """
-            return self._values.get("include_recurring")
+            result = self._values.get("include_recurring")
+            return result
 
         @builtins.property
         def include_refund(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeRefund``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includerefund
             """
-            return self._values.get("include_refund")
+            result = self._values.get("include_refund")
+            return result
 
         @builtins.property
         def include_subscription(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeSubscription``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includesubscription
             """
-            return self._values.get("include_subscription")
+            result = self._values.get("include_subscription")
+            return result
 
         @builtins.property
         def include_support(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeSupport``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includesupport
             """
-            return self._values.get("include_support")
+            result = self._values.get("include_support")
+            return result
 
         @builtins.property
         def include_tax(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeTax``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includetax
             """
-            return self._values.get("include_tax")
+            result = self._values.get("include_tax")
+            return result
 
         @builtins.property
         def include_upfront(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.IncludeUpfront``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-includeupfront
             """
-            return self._values.get("include_upfront")
+            result = self._values.get("include_upfront")
+            return result
 
         @builtins.property
         def use_amortized(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.UseAmortized``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-useamortized
             """
-            return self._values.get("use_amortized")
+            result = self._values.get("use_amortized")
+            return result
 
         @builtins.property
         def use_blended(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnBudget.CostTypesProperty.UseBlended``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-costtypes.html#cfn-budgets-budget-costtypes-useblended
             """
-            return self._values.get("use_blended")
+            result = self._values.get("use_blended")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -486,10 +509,10 @@ class CfnBudget(
         def __init__(
             self,
             *,
-            comparison_operator: str,
-            notification_type: str,
+            comparison_operator: builtins.str,
+            notification_type: builtins.str,
             threshold: jsii.Number,
-            threshold_type: typing.Optional[str] = None,
+            threshold_type: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param comparison_operator: ``CfnBudget.NotificationProperty.ComparisonOperator``.
@@ -500,7 +523,7 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notification.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "comparison_operator": comparison_operator,
                 "notification_type": notification_type,
                 "threshold": threshold,
@@ -509,22 +532,26 @@ class CfnBudget(
                 self._values["threshold_type"] = threshold_type
 
         @builtins.property
-        def comparison_operator(self) -> str:
+        def comparison_operator(self) -> builtins.str:
             """``CfnBudget.NotificationProperty.ComparisonOperator``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notification.html#cfn-budgets-budget-notification-comparisonoperator
             """
-            return self._values.get("comparison_operator")
+            result = self._values.get("comparison_operator")
+            assert result is not None, "Required property 'comparison_operator' is missing"
+            return result
 
         @builtins.property
-        def notification_type(self) -> str:
+        def notification_type(self) -> builtins.str:
             """``CfnBudget.NotificationProperty.NotificationType``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notification.html#cfn-budgets-budget-notification-notificationtype
             """
-            return self._values.get("notification_type")
+            result = self._values.get("notification_type")
+            assert result is not None, "Required property 'notification_type' is missing"
+            return result
 
         @builtins.property
         def threshold(self) -> jsii.Number:
@@ -533,21 +560,24 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notification.html#cfn-budgets-budget-notification-threshold
             """
-            return self._values.get("threshold")
+            result = self._values.get("threshold")
+            assert result is not None, "Required property 'threshold' is missing"
+            return result
 
         @builtins.property
-        def threshold_type(self) -> typing.Optional[str]:
+        def threshold_type(self) -> typing.Optional[builtins.str]:
             """``CfnBudget.NotificationProperty.ThresholdType``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notification.html#cfn-budgets-budget-notification-thresholdtype
             """
-            return self._values.get("threshold_type")
+            result = self._values.get("threshold_type")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -574,7 +604,7 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notificationwithsubscribers.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "notification": notification,
                 "subscribers": subscribers,
             }
@@ -588,7 +618,9 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notificationwithsubscribers.html#cfn-budgets-budget-notificationwithsubscribers-notification
             """
-            return self._values.get("notification")
+            result = self._values.get("notification")
+            assert result is not None, "Required property 'notification' is missing"
+            return result
 
         @builtins.property
         def subscribers(
@@ -599,12 +631,14 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-notificationwithsubscribers.html#cfn-budgets-budget-notificationwithsubscribers-subscribers
             """
-            return self._values.get("subscribers")
+            result = self._values.get("subscribers")
+            assert result is not None, "Required property 'subscribers' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -618,7 +652,7 @@ class CfnBudget(
         name_mapping={"amount": "amount", "unit": "unit"},
     )
     class SpendProperty:
-        def __init__(self, *, amount: jsii.Number, unit: str) -> None:
+        def __init__(self, *, amount: jsii.Number, unit: builtins.str) -> None:
             """
             :param amount: ``CfnBudget.SpendProperty.Amount``.
             :param unit: ``CfnBudget.SpendProperty.Unit``.
@@ -626,7 +660,7 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-spend.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "amount": amount,
                 "unit": unit,
             }
@@ -638,21 +672,25 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-spend.html#cfn-budgets-budget-spend-amount
             """
-            return self._values.get("amount")
+            result = self._values.get("amount")
+            assert result is not None, "Required property 'amount' is missing"
+            return result
 
         @builtins.property
-        def unit(self) -> str:
+        def unit(self) -> builtins.str:
             """``CfnBudget.SpendProperty.Unit``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-spend.html#cfn-budgets-budget-spend-unit
             """
-            return self._values.get("unit")
+            result = self._values.get("unit")
+            assert result is not None, "Required property 'unit' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -666,7 +704,12 @@ class CfnBudget(
         name_mapping={"address": "address", "subscription_type": "subscriptionType"},
     )
     class SubscriberProperty:
-        def __init__(self, *, address: str, subscription_type: str) -> None:
+        def __init__(
+            self,
+            *,
+            address: builtins.str,
+            subscription_type: builtins.str,
+        ) -> None:
             """
             :param address: ``CfnBudget.SubscriberProperty.Address``.
             :param subscription_type: ``CfnBudget.SubscriberProperty.SubscriptionType``.
@@ -674,33 +717,37 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-subscriber.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "address": address,
                 "subscription_type": subscription_type,
             }
 
         @builtins.property
-        def address(self) -> str:
+        def address(self) -> builtins.str:
             """``CfnBudget.SubscriberProperty.Address``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-subscriber.html#cfn-budgets-budget-subscriber-address
             """
-            return self._values.get("address")
+            result = self._values.get("address")
+            assert result is not None, "Required property 'address' is missing"
+            return result
 
         @builtins.property
-        def subscription_type(self) -> str:
+        def subscription_type(self) -> builtins.str:
             """``CfnBudget.SubscriberProperty.SubscriptionType``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-subscriber.html#cfn-budgets-budget-subscriber-subscriptiontype
             """
-            return self._values.get("subscription_type")
+            result = self._values.get("subscription_type")
+            assert result is not None, "Required property 'subscription_type' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -717,8 +764,8 @@ class CfnBudget(
         def __init__(
             self,
             *,
-            end: typing.Optional[str] = None,
-            start: typing.Optional[str] = None,
+            end: typing.Optional[builtins.str] = None,
+            start: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param end: ``CfnBudget.TimePeriodProperty.End``.
@@ -727,34 +774,36 @@ class CfnBudget(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-timeperiod.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if end is not None:
                 self._values["end"] = end
             if start is not None:
                 self._values["start"] = start
 
         @builtins.property
-        def end(self) -> typing.Optional[str]:
+        def end(self) -> typing.Optional[builtins.str]:
             """``CfnBudget.TimePeriodProperty.End``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-timeperiod.html#cfn-budgets-budget-timeperiod-end
             """
-            return self._values.get("end")
+            result = self._values.get("end")
+            return result
 
         @builtins.property
-        def start(self) -> typing.Optional[str]:
+        def start(self) -> typing.Optional[builtins.str]:
             """``CfnBudget.TimePeriodProperty.Start``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-budgets-budget-timeperiod.html#cfn-budgets-budget-timeperiod-start
             """
-            return self._values.get("start")
+            result = self._values.get("start")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -786,7 +835,7 @@ class CfnBudgetProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budget.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "budget": budget,
         }
         if notifications_with_subscribers is not None:
@@ -801,7 +850,9 @@ class CfnBudgetProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budget.html#cfn-budgets-budget-budget
         """
-        return self._values.get("budget")
+        result = self._values.get("budget")
+        assert result is not None, "Required property 'budget' is missing"
+        return result
 
     @builtins.property
     def notifications_with_subscribers(
@@ -812,12 +863,13 @@ class CfnBudgetProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budget.html#cfn-budgets-budget-notificationswithsubscribers
         """
-        return self._values.get("notifications_with_subscribers")
+        result = self._values.get("notifications_with_subscribers")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
