@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -40,10 +40,10 @@ class CertificateProps:
     def __init__(
         self,
         *,
-        domain_name: str,
-        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        domain_name: builtins.str,
+        subject_alternative_names: typing.Optional[typing.List[builtins.str]] = None,
         validation: typing.Optional["CertificateValidation"] = None,
-        validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
+        validation_domains: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         validation_method: typing.Optional["ValidationMethod"] = None,
     ) -> None:
         """Properties for your certificate.
@@ -57,7 +57,7 @@ class CertificateProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "domain_name": domain_name,
         }
         if subject_alternative_names is not None:
@@ -70,7 +70,7 @@ class CertificateProps:
             self._values["validation_method"] = validation_method
 
     @builtins.property
-    def domain_name(self) -> str:
+    def domain_name(self) -> builtins.str:
         """Fully-qualified domain name to request a certificate for.
 
         May contain wildcards, such as ``*.domain.com``.
@@ -78,10 +78,12 @@ class CertificateProps:
         stability
         :stability: experimental
         """
-        return self._values.get("domain_name")
+        result = self._values.get("domain_name")
+        assert result is not None, "Required property 'domain_name' is missing"
+        return result
 
     @builtins.property
-    def subject_alternative_names(self) -> typing.Optional[typing.List[str]]:
+    def subject_alternative_names(self) -> typing.Optional[typing.List[builtins.str]]:
         """Alternative domain names on your certificate.
 
         Use this to register alternative domain names that represent the same site.
@@ -92,7 +94,8 @@ class CertificateProps:
         stability
         :stability: experimental
         """
-        return self._values.get("subject_alternative_names")
+        result = self._values.get("subject_alternative_names")
+        return result
 
     @builtins.property
     def validation(self) -> typing.Optional["CertificateValidation"]:
@@ -104,10 +107,13 @@ class CertificateProps:
         stability
         :stability: experimental
         """
-        return self._values.get("validation")
+        result = self._values.get("validation")
+        return result
 
     @builtins.property
-    def validation_domains(self) -> typing.Optional[typing.Mapping[str, str]]:
+    def validation_domains(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         """What validation domain to use for every requested domain.
 
         Has to be a superdomain of the requested domain.
@@ -121,7 +127,8 @@ class CertificateProps:
         stability
         :stability: deprecated
         """
-        return self._values.get("validation_domains")
+        result = self._values.get("validation_domains")
+        return result
 
     @builtins.property
     def validation_method(self) -> typing.Optional["ValidationMethod"]:
@@ -136,12 +143,13 @@ class CertificateProps:
         stability
         :stability: deprecated
         """
-        return self._values.get("validation_method")
+        result = self._values.get("validation_method")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -163,7 +171,8 @@ class CertificateValidation(
     @jsii.member(jsii_name="fromDns")
     @builtins.classmethod
     def from_dns(
-        cls, hosted_zone: typing.Optional[_IHostedZone_59ffab76] = None
+        cls,
+        hosted_zone: typing.Optional[_IHostedZone_59ffab76] = None,
     ) -> "CertificateValidation":
         """Validate the certifcate with DNS.
 
@@ -181,7 +190,8 @@ class CertificateValidation(
     @jsii.member(jsii_name="fromDnsMultiZone")
     @builtins.classmethod
     def from_dns_multi_zone(
-        cls, hosted_zones: typing.Mapping[str, _IHostedZone_59ffab76]
+        cls,
+        hosted_zones: typing.Mapping[builtins.str, _IHostedZone_59ffab76],
     ) -> "CertificateValidation":
         """Validate the certifcate with automatically created DNS records in multiple Amazon Route 53 hosted zones.
 
@@ -195,7 +205,8 @@ class CertificateValidation(
     @jsii.member(jsii_name="fromEmail")
     @builtins.classmethod
     def from_email(
-        cls, validation_domains: typing.Optional[typing.Mapping[str, str]] = None
+        cls,
+        validation_domains: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     ) -> "CertificateValidation":
         """Validate the certifcate with Email.
 
@@ -220,7 +231,7 @@ class CertificateValidation(
         """
         return jsii.sinvoke(cls, "fromEmail", [validation_domains])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="method")
     def method(self) -> "ValidationMethod":
         """The validation method.
@@ -230,7 +241,7 @@ class CertificateValidation(
         """
         return jsii.get(self, "method")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="props")
     def props(self) -> "CertificationValidationProps":
         """Certification validation properties.
@@ -256,9 +267,9 @@ class CertificationValidationProps:
         self,
         *,
         hosted_zone: typing.Optional[_IHostedZone_59ffab76] = None,
-        hosted_zones: typing.Optional[typing.Mapping[str, _IHostedZone_59ffab76]] = None,
+        hosted_zones: typing.Optional[typing.Mapping[builtins.str, _IHostedZone_59ffab76]] = None,
         method: typing.Optional["ValidationMethod"] = None,
-        validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
+        validation_domains: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     ) -> None:
         """Properties for certificate validation.
 
@@ -270,7 +281,7 @@ class CertificationValidationProps:
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if hosted_zone is not None:
             self._values["hosted_zone"] = hosted_zone
         if hosted_zones is not None:
@@ -290,12 +301,13 @@ class CertificationValidationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("hosted_zone")
+        result = self._values.get("hosted_zone")
+        return result
 
     @builtins.property
     def hosted_zones(
         self,
-    ) -> typing.Optional[typing.Mapping[str, _IHostedZone_59ffab76]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _IHostedZone_59ffab76]]:
         """A map of hosted zones to use for DNS validation.
 
         default
@@ -304,7 +316,8 @@ class CertificationValidationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("hosted_zones")
+        result = self._values.get("hosted_zones")
+        return result
 
     @builtins.property
     def method(self) -> typing.Optional["ValidationMethod"]:
@@ -316,10 +329,13 @@ class CertificationValidationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("method")
+        result = self._values.get("method")
+        return result
 
     @builtins.property
-    def validation_domains(self) -> typing.Optional[typing.Mapping[str, str]]:
+    def validation_domains(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         """Validation domains to use for email validation.
 
         default
@@ -328,12 +344,13 @@ class CertificationValidationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("validation_domains")
+        result = self._values.get("validation_domains")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -359,15 +376,15 @@ class CfnCertificate(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        domain_name: str,
-        certificate_authority_arn: typing.Optional[str] = None,
-        certificate_transparency_logging_preference: typing.Optional[str] = None,
+        domain_name: builtins.str,
+        certificate_authority_arn: typing.Optional[builtins.str] = None,
+        certificate_transparency_logging_preference: typing.Optional[builtins.str] = None,
         domain_validation_options: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DomainValidationOptionProperty", _IResolvable_9ceae33e]]]] = None,
-        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        subject_alternative_names: typing.Optional[typing.List[builtins.str]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        validation_method: typing.Optional[str] = None,
+        validation_method: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::CertificateManager::Certificate``.
 
@@ -406,25 +423,26 @@ class CfnCertificate(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::CertificateManager::Certificate.Tags``.
@@ -434,9 +452,9 @@ class CfnCertificate(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="domainName")
-    def domain_name(self) -> str:
+    def domain_name(self) -> builtins.str:
         """``AWS::CertificateManager::Certificate.DomainName``.
 
         see
@@ -444,13 +462,13 @@ class CfnCertificate(
         """
         return jsii.get(self, "domainName")
 
-    @domain_name.setter
-    def domain_name(self, value: str) -> None:
+    @domain_name.setter # type: ignore
+    def domain_name(self, value: builtins.str) -> None:
         jsii.set(self, "domainName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="certificateAuthorityArn")
-    def certificate_authority_arn(self) -> typing.Optional[str]:
+    def certificate_authority_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::CertificateManager::Certificate.CertificateAuthorityArn``.
 
         see
@@ -458,13 +476,15 @@ class CfnCertificate(
         """
         return jsii.get(self, "certificateAuthorityArn")
 
-    @certificate_authority_arn.setter
-    def certificate_authority_arn(self, value: typing.Optional[str]) -> None:
+    @certificate_authority_arn.setter # type: ignore
+    def certificate_authority_arn(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "certificateAuthorityArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="certificateTransparencyLoggingPreference")
-    def certificate_transparency_logging_preference(self) -> typing.Optional[str]:
+    def certificate_transparency_logging_preference(
+        self,
+    ) -> typing.Optional[builtins.str]:
         """``AWS::CertificateManager::Certificate.CertificateTransparencyLoggingPreference``.
 
         see
@@ -472,13 +492,14 @@ class CfnCertificate(
         """
         return jsii.get(self, "certificateTransparencyLoggingPreference")
 
-    @certificate_transparency_logging_preference.setter
+    @certificate_transparency_logging_preference.setter # type: ignore
     def certificate_transparency_logging_preference(
-        self, value: typing.Optional[str]
+        self,
+        value: typing.Optional[builtins.str],
     ) -> None:
         jsii.set(self, "certificateTransparencyLoggingPreference", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="domainValidationOptions")
     def domain_validation_options(
         self,
@@ -490,16 +511,16 @@ class CfnCertificate(
         """
         return jsii.get(self, "domainValidationOptions")
 
-    @domain_validation_options.setter
+    @domain_validation_options.setter # type: ignore
     def domain_validation_options(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DomainValidationOptionProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "domainValidationOptions", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="subjectAlternativeNames")
-    def subject_alternative_names(self) -> typing.Optional[typing.List[str]]:
+    def subject_alternative_names(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::CertificateManager::Certificate.SubjectAlternativeNames``.
 
         see
@@ -507,15 +528,16 @@ class CfnCertificate(
         """
         return jsii.get(self, "subjectAlternativeNames")
 
-    @subject_alternative_names.setter
+    @subject_alternative_names.setter # type: ignore
     def subject_alternative_names(
-        self, value: typing.Optional[typing.List[str]]
+        self,
+        value: typing.Optional[typing.List[builtins.str]],
     ) -> None:
         jsii.set(self, "subjectAlternativeNames", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="validationMethod")
-    def validation_method(self) -> typing.Optional[str]:
+    def validation_method(self) -> typing.Optional[builtins.str]:
         """``AWS::CertificateManager::Certificate.ValidationMethod``.
 
         see
@@ -523,8 +545,8 @@ class CfnCertificate(
         """
         return jsii.get(self, "validationMethod")
 
-    @validation_method.setter
-    def validation_method(self, value: typing.Optional[str]) -> None:
+    @validation_method.setter # type: ignore
+    def validation_method(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "validationMethod", value)
 
     @jsii.data_type(
@@ -540,9 +562,9 @@ class CfnCertificate(
         def __init__(
             self,
             *,
-            domain_name: str,
-            hosted_zone_id: typing.Optional[str] = None,
-            validation_domain: typing.Optional[str] = None,
+            domain_name: builtins.str,
+            hosted_zone_id: typing.Optional[builtins.str] = None,
+            validation_domain: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param domain_name: ``CfnCertificate.DomainValidationOptionProperty.DomainName``.
@@ -552,7 +574,7 @@ class CfnCertificate(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "domain_name": domain_name,
             }
             if hosted_zone_id is not None:
@@ -561,36 +583,40 @@ class CfnCertificate(
                 self._values["validation_domain"] = validation_domain
 
         @builtins.property
-        def domain_name(self) -> str:
+        def domain_name(self) -> builtins.str:
             """``CfnCertificate.DomainValidationOptionProperty.DomainName``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
             """
-            return self._values.get("domain_name")
+            result = self._values.get("domain_name")
+            assert result is not None, "Required property 'domain_name' is missing"
+            return result
 
         @builtins.property
-        def hosted_zone_id(self) -> typing.Optional[str]:
+        def hosted_zone_id(self) -> typing.Optional[builtins.str]:
             """``CfnCertificate.DomainValidationOptionProperty.HostedZoneId``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-hostedzoneid
             """
-            return self._values.get("hosted_zone_id")
+            result = self._values.get("hosted_zone_id")
+            return result
 
         @builtins.property
-        def validation_domain(self) -> typing.Optional[str]:
+        def validation_domain(self) -> typing.Optional[builtins.str]:
             """``CfnCertificate.DomainValidationOptionProperty.ValidationDomain``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
             """
-            return self._values.get("validation_domain")
+            result = self._values.get("validation_domain")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -616,13 +642,13 @@ class CfnCertificateProps:
     def __init__(
         self,
         *,
-        domain_name: str,
-        certificate_authority_arn: typing.Optional[str] = None,
-        certificate_transparency_logging_preference: typing.Optional[str] = None,
+        domain_name: builtins.str,
+        certificate_authority_arn: typing.Optional[builtins.str] = None,
+        certificate_transparency_logging_preference: typing.Optional[builtins.str] = None,
         domain_validation_options: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnCertificate.DomainValidationOptionProperty", _IResolvable_9ceae33e]]]] = None,
-        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        subject_alternative_names: typing.Optional[typing.List[builtins.str]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        validation_method: typing.Optional[str] = None,
+        validation_method: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::CertificateManager::Certificate``.
 
@@ -637,7 +663,7 @@ class CfnCertificateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "domain_name": domain_name,
         }
         if certificate_authority_arn is not None:
@@ -654,31 +680,37 @@ class CfnCertificateProps:
             self._values["validation_method"] = validation_method
 
     @builtins.property
-    def domain_name(self) -> str:
+    def domain_name(self) -> builtins.str:
         """``AWS::CertificateManager::Certificate.DomainName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-domainname
         """
-        return self._values.get("domain_name")
+        result = self._values.get("domain_name")
+        assert result is not None, "Required property 'domain_name' is missing"
+        return result
 
     @builtins.property
-    def certificate_authority_arn(self) -> typing.Optional[str]:
+    def certificate_authority_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::CertificateManager::Certificate.CertificateAuthorityArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-certificateauthorityarn
         """
-        return self._values.get("certificate_authority_arn")
+        result = self._values.get("certificate_authority_arn")
+        return result
 
     @builtins.property
-    def certificate_transparency_logging_preference(self) -> typing.Optional[str]:
+    def certificate_transparency_logging_preference(
+        self,
+    ) -> typing.Optional[builtins.str]:
         """``AWS::CertificateManager::Certificate.CertificateTransparencyLoggingPreference``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-certificatetransparencyloggingpreference
         """
-        return self._values.get("certificate_transparency_logging_preference")
+        result = self._values.get("certificate_transparency_logging_preference")
+        return result
 
     @builtins.property
     def domain_validation_options(
@@ -689,16 +721,18 @@ class CfnCertificateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-domainvalidationoptions
         """
-        return self._values.get("domain_validation_options")
+        result = self._values.get("domain_validation_options")
+        return result
 
     @builtins.property
-    def subject_alternative_names(self) -> typing.Optional[typing.List[str]]:
+    def subject_alternative_names(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::CertificateManager::Certificate.SubjectAlternativeNames``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-subjectalternativenames
         """
-        return self._values.get("subject_alternative_names")
+        result = self._values.get("subject_alternative_names")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -707,21 +741,23 @@ class CfnCertificateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
     @builtins.property
-    def validation_method(self) -> typing.Optional[str]:
+    def validation_method(self) -> typing.Optional[builtins.str]:
         """``AWS::CertificateManager::Certificate.ValidationMethod``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html#cfn-certificatemanager-certificate-validationmethod
         """
-        return self._values.get("validation_method")
+        result = self._values.get("validation_method")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -749,15 +785,15 @@ class DnsValidatedCertificateProps(CertificateProps):
     def __init__(
         self,
         *,
-        domain_name: str,
-        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        domain_name: builtins.str,
+        subject_alternative_names: typing.Optional[typing.List[builtins.str]] = None,
         validation: typing.Optional["CertificateValidation"] = None,
-        validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
+        validation_domains: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         validation_method: typing.Optional["ValidationMethod"] = None,
         hosted_zone: _IHostedZone_59ffab76,
         custom_resource_role: typing.Optional[_IRole_e69bbae4] = None,
-        region: typing.Optional[str] = None,
-        route53_endpoint: typing.Optional[str] = None,
+        region: typing.Optional[builtins.str] = None,
+        route53_endpoint: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties to create a DNS validated certificate managed by AWS Certificate Manager.
 
@@ -774,7 +810,7 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "domain_name": domain_name,
             "hosted_zone": hosted_zone,
         }
@@ -794,7 +830,7 @@ class DnsValidatedCertificateProps(CertificateProps):
             self._values["route53_endpoint"] = route53_endpoint
 
     @builtins.property
-    def domain_name(self) -> str:
+    def domain_name(self) -> builtins.str:
         """Fully-qualified domain name to request a certificate for.
 
         May contain wildcards, such as ``*.domain.com``.
@@ -802,10 +838,12 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get("domain_name")
+        result = self._values.get("domain_name")
+        assert result is not None, "Required property 'domain_name' is missing"
+        return result
 
     @builtins.property
-    def subject_alternative_names(self) -> typing.Optional[typing.List[str]]:
+    def subject_alternative_names(self) -> typing.Optional[typing.List[builtins.str]]:
         """Alternative domain names on your certificate.
 
         Use this to register alternative domain names that represent the same site.
@@ -816,7 +854,8 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get("subject_alternative_names")
+        result = self._values.get("subject_alternative_names")
+        return result
 
     @builtins.property
     def validation(self) -> typing.Optional["CertificateValidation"]:
@@ -828,10 +867,13 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get("validation")
+        result = self._values.get("validation")
+        return result
 
     @builtins.property
-    def validation_domains(self) -> typing.Optional[typing.Mapping[str, str]]:
+    def validation_domains(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         """What validation domain to use for every requested domain.
 
         Has to be a superdomain of the requested domain.
@@ -845,7 +887,8 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: deprecated
         """
-        return self._values.get("validation_domains")
+        result = self._values.get("validation_domains")
+        return result
 
     @builtins.property
     def validation_method(self) -> typing.Optional["ValidationMethod"]:
@@ -860,7 +903,8 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: deprecated
         """
-        return self._values.get("validation_method")
+        result = self._values.get("validation_method")
+        return result
 
     @builtins.property
     def hosted_zone(self) -> _IHostedZone_59ffab76:
@@ -872,7 +916,9 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get("hosted_zone")
+        result = self._values.get("hosted_zone")
+        assert result is not None, "Required property 'hosted_zone' is missing"
+        return result
 
     @builtins.property
     def custom_resource_role(self) -> typing.Optional[_IRole_e69bbae4]:
@@ -884,10 +930,11 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get("custom_resource_role")
+        result = self._values.get("custom_resource_role")
+        return result
 
     @builtins.property
-    def region(self) -> typing.Optional[str]:
+    def region(self) -> typing.Optional[builtins.str]:
         """AWS region that will host the certificate.
 
         This is needed especially
@@ -900,10 +947,11 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get("region")
+        result = self._values.get("region")
+        return result
 
     @builtins.property
-    def route53_endpoint(self) -> typing.Optional[str]:
+    def route53_endpoint(self) -> typing.Optional[builtins.str]:
         """An endpoint of Route53 service, which is not necessary as AWS SDK could figure out the right endpoints for most regions, but for some regions such as those in aws-cn partition, the default endpoint is not working now, hence the right endpoint need to be specified through this prop.
 
         Route53 is not been offically launched in China, it is only available for AWS
@@ -916,12 +964,13 @@ class DnsValidatedCertificateProps(CertificateProps):
         stability
         :stability: experimental
         """
-        return self._values.get("route53_endpoint")
+        result = self._values.get("route53_endpoint")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -931,7 +980,7 @@ class DnsValidatedCertificateProps(CertificateProps):
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_certificatemanager.ICertificate")
-class ICertificate(_IResource_72f7ee7e, jsii.compat.Protocol):
+class ICertificate(_IResource_72f7ee7e, typing_extensions.Protocol):
     """Represents a certificate in AWS Certificate Manager.
 
     stability
@@ -942,9 +991,9 @@ class ICertificate(_IResource_72f7ee7e, jsii.compat.Protocol):
     def __jsii_proxy_class__():
         return _ICertificateProxy
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="certificateArn")
-    def certificate_arn(self) -> str:
+    def certificate_arn(self) -> builtins.str:
         """The certificate's ARN.
 
         stability
@@ -955,18 +1004,20 @@ class ICertificate(_IResource_72f7ee7e, jsii.compat.Protocol):
         ...
 
 
-class _ICertificateProxy(jsii.proxy_for(_IResource_72f7ee7e)):
+class _ICertificateProxy(
+    jsii.proxy_for(_IResource_72f7ee7e) # type: ignore
+):
     """Represents a certificate in AWS Certificate Manager.
 
     stability
     :stability: experimental
     """
 
-    __jsii_type__ = "monocdk-experiment.aws_certificatemanager.ICertificate"
+    __jsii_type__: typing.ClassVar[str] = "monocdk-experiment.aws_certificatemanager.ICertificate"
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="certificateArn")
-    def certificate_arn(self) -> str:
+    def certificate_arn(self) -> builtins.str:
         """The certificate's ARN.
 
         stability
@@ -1018,12 +1069,12 @@ class Certificate(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        domain_name: str,
-        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        domain_name: builtins.str,
+        subject_alternative_names: typing.Optional[typing.List[builtins.str]] = None,
         validation: typing.Optional["CertificateValidation"] = None,
-        validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
+        validation_domains: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         validation_method: typing.Optional["ValidationMethod"] = None,
     ) -> None:
         """
@@ -1051,7 +1102,10 @@ class Certificate(
     @jsii.member(jsii_name="fromCertificateArn")
     @builtins.classmethod
     def from_certificate_arn(
-        cls, scope: _Construct_f50a3f53, id: str, certificate_arn: str
+        cls,
+        scope: _Construct_f50a3f53,
+        id: builtins.str,
+        certificate_arn: builtins.str,
     ) -> "ICertificate":
         """Import a certificate.
 
@@ -1064,9 +1118,9 @@ class Certificate(
         """
         return jsii.sinvoke(cls, "fromCertificateArn", [scope, id, certificate_arn])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="certificateArn")
-    def certificate_arn(self) -> str:
+    def certificate_arn(self) -> builtins.str:
         """The certificate's ARN.
 
         stability
@@ -1095,16 +1149,16 @@ class DnsValidatedCertificate(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         hosted_zone: _IHostedZone_59ffab76,
         custom_resource_role: typing.Optional[_IRole_e69bbae4] = None,
-        region: typing.Optional[str] = None,
-        route53_endpoint: typing.Optional[str] = None,
-        domain_name: str,
-        subject_alternative_names: typing.Optional[typing.List[str]] = None,
+        region: typing.Optional[builtins.str] = None,
+        route53_endpoint: typing.Optional[builtins.str] = None,
+        domain_name: builtins.str,
+        subject_alternative_names: typing.Optional[typing.List[builtins.str]] = None,
         validation: typing.Optional["CertificateValidation"] = None,
-        validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
+        validation_domains: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         validation_method: typing.Optional["ValidationMethod"] = None,
     ) -> None:
         """
@@ -1138,7 +1192,7 @@ class DnsValidatedCertificate(
         jsii.create(DnsValidatedCertificate, self, [scope, id, props])
 
     @jsii.member(jsii_name="validate")
-    def _validate(self) -> typing.List[str]:
+    def _validate(self) -> typing.List[builtins.str]:
         """Validate the current construct.
 
         This method can be implemented by derived constructs in order to perform
@@ -1149,9 +1203,9 @@ class DnsValidatedCertificate(
         """
         return jsii.invoke(self, "validate", [])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="certificateArn")
-    def certificate_arn(self) -> str:
+    def certificate_arn(self) -> builtins.str:
         """The certificate's ARN.
 
         stability
