@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -54,14 +54,14 @@ class CfnSlackChannelConfiguration(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        configuration_name: str,
-        iam_role_arn: str,
-        slack_channel_id: str,
-        slack_workspace_id: str,
-        logging_level: typing.Optional[str] = None,
-        sns_topic_arns: typing.Optional[typing.List[str]] = None,
+        configuration_name: builtins.str,
+        iam_role_arn: builtins.str,
+        slack_channel_id: builtins.str,
+        slack_workspace_id: builtins.str,
+        logging_level: typing.Optional[builtins.str] = None,
+        sns_topic_arns: typing.Optional[typing.List[builtins.str]] = None,
     ) -> None:
         """Create a new ``AWS::Chatbot::SlackChannelConfiguration``.
 
@@ -98,36 +98,37 @@ class CfnSlackChannelConfiguration(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="configurationName")
-    def configuration_name(self) -> str:
+    def configuration_name(self) -> builtins.str:
         """``AWS::Chatbot::SlackChannelConfiguration.ConfigurationName``.
 
         see
@@ -135,13 +136,13 @@ class CfnSlackChannelConfiguration(
         """
         return jsii.get(self, "configurationName")
 
-    @configuration_name.setter
-    def configuration_name(self, value: str) -> None:
+    @configuration_name.setter # type: ignore
+    def configuration_name(self, value: builtins.str) -> None:
         jsii.set(self, "configurationName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="iamRoleArn")
-    def iam_role_arn(self) -> str:
+    def iam_role_arn(self) -> builtins.str:
         """``AWS::Chatbot::SlackChannelConfiguration.IamRoleArn``.
 
         see
@@ -149,13 +150,13 @@ class CfnSlackChannelConfiguration(
         """
         return jsii.get(self, "iamRoleArn")
 
-    @iam_role_arn.setter
-    def iam_role_arn(self, value: str) -> None:
+    @iam_role_arn.setter # type: ignore
+    def iam_role_arn(self, value: builtins.str) -> None:
         jsii.set(self, "iamRoleArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="slackChannelId")
-    def slack_channel_id(self) -> str:
+    def slack_channel_id(self) -> builtins.str:
         """``AWS::Chatbot::SlackChannelConfiguration.SlackChannelId``.
 
         see
@@ -163,13 +164,13 @@ class CfnSlackChannelConfiguration(
         """
         return jsii.get(self, "slackChannelId")
 
-    @slack_channel_id.setter
-    def slack_channel_id(self, value: str) -> None:
+    @slack_channel_id.setter # type: ignore
+    def slack_channel_id(self, value: builtins.str) -> None:
         jsii.set(self, "slackChannelId", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="slackWorkspaceId")
-    def slack_workspace_id(self) -> str:
+    def slack_workspace_id(self) -> builtins.str:
         """``AWS::Chatbot::SlackChannelConfiguration.SlackWorkspaceId``.
 
         see
@@ -177,13 +178,13 @@ class CfnSlackChannelConfiguration(
         """
         return jsii.get(self, "slackWorkspaceId")
 
-    @slack_workspace_id.setter
-    def slack_workspace_id(self, value: str) -> None:
+    @slack_workspace_id.setter # type: ignore
+    def slack_workspace_id(self, value: builtins.str) -> None:
         jsii.set(self, "slackWorkspaceId", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="loggingLevel")
-    def logging_level(self) -> typing.Optional[str]:
+    def logging_level(self) -> typing.Optional[builtins.str]:
         """``AWS::Chatbot::SlackChannelConfiguration.LoggingLevel``.
 
         see
@@ -191,13 +192,13 @@ class CfnSlackChannelConfiguration(
         """
         return jsii.get(self, "loggingLevel")
 
-    @logging_level.setter
-    def logging_level(self, value: typing.Optional[str]) -> None:
+    @logging_level.setter # type: ignore
+    def logging_level(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "loggingLevel", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="snsTopicArns")
-    def sns_topic_arns(self) -> typing.Optional[typing.List[str]]:
+    def sns_topic_arns(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Chatbot::SlackChannelConfiguration.SnsTopicArns``.
 
         see
@@ -205,8 +206,8 @@ class CfnSlackChannelConfiguration(
         """
         return jsii.get(self, "snsTopicArns")
 
-    @sns_topic_arns.setter
-    def sns_topic_arns(self, value: typing.Optional[typing.List[str]]) -> None:
+    @sns_topic_arns.setter # type: ignore
+    def sns_topic_arns(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
         jsii.set(self, "snsTopicArns", value)
 
 
@@ -226,12 +227,12 @@ class CfnSlackChannelConfigurationProps:
     def __init__(
         self,
         *,
-        configuration_name: str,
-        iam_role_arn: str,
-        slack_channel_id: str,
-        slack_workspace_id: str,
-        logging_level: typing.Optional[str] = None,
-        sns_topic_arns: typing.Optional[typing.List[str]] = None,
+        configuration_name: builtins.str,
+        iam_role_arn: builtins.str,
+        slack_channel_id: builtins.str,
+        slack_workspace_id: builtins.str,
+        logging_level: typing.Optional[builtins.str] = None,
+        sns_topic_arns: typing.Optional[typing.List[builtins.str]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Chatbot::SlackChannelConfiguration``.
 
@@ -245,7 +246,7 @@ class CfnSlackChannelConfigurationProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-chatbot-slackchannelconfiguration.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "configuration_name": configuration_name,
             "iam_role_arn": iam_role_arn,
             "slack_channel_id": slack_channel_id,
@@ -257,63 +258,73 @@ class CfnSlackChannelConfigurationProps:
             self._values["sns_topic_arns"] = sns_topic_arns
 
     @builtins.property
-    def configuration_name(self) -> str:
+    def configuration_name(self) -> builtins.str:
         """``AWS::Chatbot::SlackChannelConfiguration.ConfigurationName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-chatbot-slackchannelconfiguration.html#cfn-chatbot-slackchannelconfiguration-configurationname
         """
-        return self._values.get("configuration_name")
+        result = self._values.get("configuration_name")
+        assert result is not None, "Required property 'configuration_name' is missing"
+        return result
 
     @builtins.property
-    def iam_role_arn(self) -> str:
+    def iam_role_arn(self) -> builtins.str:
         """``AWS::Chatbot::SlackChannelConfiguration.IamRoleArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-chatbot-slackchannelconfiguration.html#cfn-chatbot-slackchannelconfiguration-iamrolearn
         """
-        return self._values.get("iam_role_arn")
+        result = self._values.get("iam_role_arn")
+        assert result is not None, "Required property 'iam_role_arn' is missing"
+        return result
 
     @builtins.property
-    def slack_channel_id(self) -> str:
+    def slack_channel_id(self) -> builtins.str:
         """``AWS::Chatbot::SlackChannelConfiguration.SlackChannelId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-chatbot-slackchannelconfiguration.html#cfn-chatbot-slackchannelconfiguration-slackchannelid
         """
-        return self._values.get("slack_channel_id")
+        result = self._values.get("slack_channel_id")
+        assert result is not None, "Required property 'slack_channel_id' is missing"
+        return result
 
     @builtins.property
-    def slack_workspace_id(self) -> str:
+    def slack_workspace_id(self) -> builtins.str:
         """``AWS::Chatbot::SlackChannelConfiguration.SlackWorkspaceId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-chatbot-slackchannelconfiguration.html#cfn-chatbot-slackchannelconfiguration-slackworkspaceid
         """
-        return self._values.get("slack_workspace_id")
+        result = self._values.get("slack_workspace_id")
+        assert result is not None, "Required property 'slack_workspace_id' is missing"
+        return result
 
     @builtins.property
-    def logging_level(self) -> typing.Optional[str]:
+    def logging_level(self) -> typing.Optional[builtins.str]:
         """``AWS::Chatbot::SlackChannelConfiguration.LoggingLevel``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-chatbot-slackchannelconfiguration.html#cfn-chatbot-slackchannelconfiguration-logginglevel
         """
-        return self._values.get("logging_level")
+        result = self._values.get("logging_level")
+        return result
 
     @builtins.property
-    def sns_topic_arns(self) -> typing.Optional[typing.List[str]]:
+    def sns_topic_arns(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::Chatbot::SlackChannelConfiguration.SnsTopicArns``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-chatbot-slackchannelconfiguration.html#cfn-chatbot-slackchannelconfiguration-snstopicarns
         """
-        return self._values.get("sns_topic_arns")
+        result = self._values.get("sns_topic_arns")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -324,7 +335,9 @@ class CfnSlackChannelConfigurationProps:
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_chatbot.ISlackChannelConfiguration")
 class ISlackChannelConfiguration(
-    _IResource_72f7ee7e, _IGrantable_0fcfc53a, jsii.compat.Protocol
+    _IResource_72f7ee7e,
+    _IGrantable_0fcfc53a,
+    typing_extensions.Protocol,
 ):
     """Represents a Slack channel configuration.
 
@@ -336,9 +349,9 @@ class ISlackChannelConfiguration(
     def __jsii_proxy_class__():
         return _ISlackChannelConfigurationProxy
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="slackChannelConfigurationArn")
-    def slack_channel_configuration_arn(self) -> str:
+    def slack_channel_configuration_arn(self) -> builtins.str:
         """The ARN of the Slack channel configuration In the form of arn:aws:chatbot:{region}:{account}:chat-configuration/slack-channel/{slackChannelName}.
 
         stability
@@ -348,9 +361,9 @@ class ISlackChannelConfiguration(
         """
         ...
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="slackChannelConfigurationName")
-    def slack_channel_configuration_name(self) -> str:
+    def slack_channel_configuration_name(self) -> builtins.str:
         """The name of Slack channel configuration.
 
         stability
@@ -360,7 +373,7 @@ class ISlackChannelConfiguration(
         """
         ...
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="role")
     def role(self) -> typing.Optional[_IRole_e69bbae4]:
         """The permission role of Slack channel configuration.
@@ -389,15 +402,15 @@ class ISlackChannelConfiguration(
     @jsii.member(jsii_name="metric")
     def metric(
         self,
-        metric_name: str,
+        metric_name: builtins.str,
         *,
-        account: typing.Optional[str] = None,
-        color: typing.Optional[str] = None,
-        dimensions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
-        label: typing.Optional[str] = None,
+        account: typing.Optional[builtins.str] = None,
+        color: typing.Optional[builtins.str] = None,
+        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        label: typing.Optional[builtins.str] = None,
         period: typing.Optional[_Duration_5170c158] = None,
-        region: typing.Optional[str] = None,
-        statistic: typing.Optional[str] = None,
+        region: typing.Optional[builtins.str] = None,
+        statistic: typing.Optional[builtins.str] = None,
         unit: typing.Optional[_Unit_e1b74f3c] = None,
     ) -> _Metric_53e89548:
         """Return the given named metric for this SlackChannelConfiguration.
@@ -419,7 +432,8 @@ class ISlackChannelConfiguration(
 
 
 class _ISlackChannelConfigurationProxy(
-    jsii.proxy_for(_IResource_72f7ee7e), jsii.proxy_for(_IGrantable_0fcfc53a)
+    jsii.proxy_for(_IResource_72f7ee7e), # type: ignore
+    jsii.proxy_for(_IGrantable_0fcfc53a), # type: ignore
 ):
     """Represents a Slack channel configuration.
 
@@ -427,11 +441,11 @@ class _ISlackChannelConfigurationProxy(
     :stability: experimental
     """
 
-    __jsii_type__ = "monocdk-experiment.aws_chatbot.ISlackChannelConfiguration"
+    __jsii_type__: typing.ClassVar[str] = "monocdk-experiment.aws_chatbot.ISlackChannelConfiguration"
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="slackChannelConfigurationArn")
-    def slack_channel_configuration_arn(self) -> str:
+    def slack_channel_configuration_arn(self) -> builtins.str:
         """The ARN of the Slack channel configuration In the form of arn:aws:chatbot:{region}:{account}:chat-configuration/slack-channel/{slackChannelName}.
 
         stability
@@ -441,9 +455,9 @@ class _ISlackChannelConfigurationProxy(
         """
         return jsii.get(self, "slackChannelConfigurationArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="slackChannelConfigurationName")
-    def slack_channel_configuration_name(self) -> str:
+    def slack_channel_configuration_name(self) -> builtins.str:
         """The name of Slack channel configuration.
 
         stability
@@ -453,7 +467,7 @@ class _ISlackChannelConfigurationProxy(
         """
         return jsii.get(self, "slackChannelConfigurationName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="role")
     def role(self) -> typing.Optional[_IRole_e69bbae4]:
         """The permission role of Slack channel configuration.
@@ -482,15 +496,15 @@ class _ISlackChannelConfigurationProxy(
     @jsii.member(jsii_name="metric")
     def metric(
         self,
-        metric_name: str,
+        metric_name: builtins.str,
         *,
-        account: typing.Optional[str] = None,
-        color: typing.Optional[str] = None,
-        dimensions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
-        label: typing.Optional[str] = None,
+        account: typing.Optional[builtins.str] = None,
+        color: typing.Optional[builtins.str] = None,
+        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        label: typing.Optional[builtins.str] = None,
         period: typing.Optional[_Duration_5170c158] = None,
-        region: typing.Optional[str] = None,
-        statistic: typing.Optional[str] = None,
+        region: typing.Optional[builtins.str] = None,
+        statistic: typing.Optional[builtins.str] = None,
         unit: typing.Optional[_Unit_e1b74f3c] = None,
     ) -> _Metric_53e89548:
         """Return the given named metric for this SlackChannelConfiguration.
@@ -565,11 +579,11 @@ class SlackChannelConfiguration(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        slack_channel_configuration_name: str,
-        slack_channel_id: str,
-        slack_workspace_id: str,
+        slack_channel_configuration_name: builtins.str,
+        slack_channel_id: builtins.str,
+        slack_workspace_id: builtins.str,
         logging_level: typing.Optional["LoggingLevel"] = None,
         log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
         log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_32a28927] = None,
@@ -610,7 +624,10 @@ class SlackChannelConfiguration(
     @jsii.member(jsii_name="fromSlackChannelConfigurationArn")
     @builtins.classmethod
     def from_slack_channel_configuration_arn(
-        cls, scope: _Construct_f50a3f53, id: str, slack_channel_configuration_arn: str
+        cls,
+        scope: _Construct_f50a3f53,
+        id: builtins.str,
+        slack_channel_configuration_arn: builtins.str,
     ) -> "ISlackChannelConfiguration":
         """Import an existing Slack channel configuration provided an ARN.
 
@@ -630,15 +647,15 @@ class SlackChannelConfiguration(
     @builtins.classmethod
     def metric_all(
         cls,
-        metric_name: str,
+        metric_name: builtins.str,
         *,
-        account: typing.Optional[str] = None,
-        color: typing.Optional[str] = None,
-        dimensions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
-        label: typing.Optional[str] = None,
+        account: typing.Optional[builtins.str] = None,
+        color: typing.Optional[builtins.str] = None,
+        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        label: typing.Optional[builtins.str] = None,
         period: typing.Optional[_Duration_5170c158] = None,
-        region: typing.Optional[str] = None,
-        statistic: typing.Optional[str] = None,
+        region: typing.Optional[builtins.str] = None,
+        statistic: typing.Optional[builtins.str] = None,
         unit: typing.Optional[_Unit_e1b74f3c] = None,
     ) -> _Metric_53e89548:
         """Return the given named metric for All SlackChannelConfigurations.
@@ -683,15 +700,15 @@ class SlackChannelConfiguration(
     @jsii.member(jsii_name="metric")
     def metric(
         self,
-        metric_name: str,
+        metric_name: builtins.str,
         *,
-        account: typing.Optional[str] = None,
-        color: typing.Optional[str] = None,
-        dimensions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
-        label: typing.Optional[str] = None,
+        account: typing.Optional[builtins.str] = None,
+        color: typing.Optional[builtins.str] = None,
+        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+        label: typing.Optional[builtins.str] = None,
         period: typing.Optional[_Duration_5170c158] = None,
-        region: typing.Optional[str] = None,
-        statistic: typing.Optional[str] = None,
+        region: typing.Optional[builtins.str] = None,
+        statistic: typing.Optional[builtins.str] = None,
         unit: typing.Optional[_Unit_e1b74f3c] = None,
     ) -> _Metric_53e89548:
         """Return the given named metric for this SlackChannelConfiguration.
@@ -722,7 +739,7 @@ class SlackChannelConfiguration(
 
         return jsii.invoke(self, "metric", [metric_name, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="grantPrincipal")
     def grant_principal(self) -> _IPrincipal_97126874:
         """The principal to grant permissions to.
@@ -732,9 +749,9 @@ class SlackChannelConfiguration(
         """
         return jsii.get(self, "grantPrincipal")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="slackChannelConfigurationArn")
-    def slack_channel_configuration_arn(self) -> str:
+    def slack_channel_configuration_arn(self) -> builtins.str:
         """The ARN of the Slack channel configuration In the form of arn:aws:chatbot:{region}:{account}:chat-configuration/slack-channel/{slackChannelName}.
 
         stability
@@ -742,9 +759,9 @@ class SlackChannelConfiguration(
         """
         return jsii.get(self, "slackChannelConfigurationArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="slackChannelConfigurationName")
-    def slack_channel_configuration_name(self) -> str:
+    def slack_channel_configuration_name(self) -> builtins.str:
         """The name of Slack channel configuration.
 
         stability
@@ -752,7 +769,7 @@ class SlackChannelConfiguration(
         """
         return jsii.get(self, "slackChannelConfigurationName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="role")
     def role(self) -> typing.Optional[_IRole_e69bbae4]:
         """The permission role of Slack channel configuration.
@@ -782,9 +799,9 @@ class SlackChannelConfigurationProps:
     def __init__(
         self,
         *,
-        slack_channel_configuration_name: str,
-        slack_channel_id: str,
-        slack_workspace_id: str,
+        slack_channel_configuration_name: builtins.str,
+        slack_channel_id: builtins.str,
+        slack_workspace_id: builtins.str,
         logging_level: typing.Optional["LoggingLevel"] = None,
         log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
         log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_32a28927] = None,
@@ -809,7 +826,7 @@ class SlackChannelConfigurationProps:
         """
         if isinstance(log_retention_retry_options, dict):
             log_retention_retry_options = _LogRetentionRetryOptions_32a28927(**log_retention_retry_options)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "slack_channel_configuration_name": slack_channel_configuration_name,
             "slack_channel_id": slack_channel_id,
             "slack_workspace_id": slack_workspace_id,
@@ -828,16 +845,18 @@ class SlackChannelConfigurationProps:
             self._values["role"] = role
 
     @builtins.property
-    def slack_channel_configuration_name(self) -> str:
+    def slack_channel_configuration_name(self) -> builtins.str:
         """The name of Slack channel configuration.
 
         stability
         :stability: experimental
         """
-        return self._values.get("slack_channel_configuration_name")
+        result = self._values.get("slack_channel_configuration_name")
+        assert result is not None, "Required property 'slack_channel_configuration_name' is missing"
+        return result
 
     @builtins.property
-    def slack_channel_id(self) -> str:
+    def slack_channel_id(self) -> builtins.str:
         """The ID of the Slack channel.
 
         To get the ID, open Slack, right click on the channel name in the left pane, then choose Copy Link.
@@ -846,10 +865,12 @@ class SlackChannelConfigurationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("slack_channel_id")
+        result = self._values.get("slack_channel_id")
+        assert result is not None, "Required property 'slack_channel_id' is missing"
+        return result
 
     @builtins.property
-    def slack_workspace_id(self) -> str:
+    def slack_workspace_id(self) -> builtins.str:
         """The ID of the Slack workspace authorized with AWS Chatbot.
 
         To get the workspace ID, you must perform the initial authorization flow with Slack in the AWS Chatbot console.
@@ -861,7 +882,9 @@ class SlackChannelConfigurationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("slack_workspace_id")
+        result = self._values.get("slack_workspace_id")
+        assert result is not None, "Required property 'slack_workspace_id' is missing"
+        return result
 
     @builtins.property
     def logging_level(self) -> typing.Optional["LoggingLevel"]:
@@ -875,7 +898,8 @@ class SlackChannelConfigurationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("logging_level")
+        result = self._values.get("logging_level")
+        return result
 
     @builtins.property
     def log_retention(self) -> typing.Optional[_RetentionDays_bdc7ad1f]:
@@ -891,7 +915,8 @@ class SlackChannelConfigurationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("log_retention")
+        result = self._values.get("log_retention")
+        return result
 
     @builtins.property
     def log_retention_retry_options(
@@ -907,7 +932,8 @@ class SlackChannelConfigurationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("log_retention_retry_options")
+        result = self._values.get("log_retention_retry_options")
+        return result
 
     @builtins.property
     def log_retention_role(self) -> typing.Optional[_IRole_e69bbae4]:
@@ -919,7 +945,8 @@ class SlackChannelConfigurationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("log_retention_role")
+        result = self._values.get("log_retention_role")
+        return result
 
     @builtins.property
     def notification_topics(self) -> typing.Optional[typing.List[_ITopic_ef0ebe0e]]:
@@ -931,7 +958,8 @@ class SlackChannelConfigurationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("notification_topics")
+        result = self._values.get("notification_topics")
+        return result
 
     @builtins.property
     def role(self) -> typing.Optional[_IRole_e69bbae4]:
@@ -943,12 +971,13 @@ class SlackChannelConfigurationProps:
         stability
         :stability: experimental
         """
-        return self._values.get("role")
+        result = self._values.get("role")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
