@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -46,16 +46,16 @@ class CfnEnvironmentEC2(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        instance_type: str,
+        instance_type: builtins.str,
         automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
-        connection_type: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
-        name: typing.Optional[str] = None,
-        owner_arn: typing.Optional[str] = None,
+        connection_type: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
+        name: typing.Optional[builtins.str] = None,
+        owner_arn: typing.Optional[builtins.str] = None,
         repositories: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["RepositoryProperty", _IResolvable_9ceae33e]]]] = None,
-        subnet_id: typing.Optional[str] = None,
+        subnet_id: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::Cloud9::EnvironmentEC2``.
@@ -99,43 +99,44 @@ class CfnEnvironmentEC2(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrName")
-    def attr_name(self) -> str:
+    def attr_name(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Name
         """
         return jsii.get(self, "attrName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::Cloud9::EnvironmentEC2.Tags``.
@@ -145,9 +146,9 @@ class CfnEnvironmentEC2(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="instanceType")
-    def instance_type(self) -> str:
+    def instance_type(self) -> builtins.str:
         """``AWS::Cloud9::EnvironmentEC2.InstanceType``.
 
         see
@@ -155,11 +156,11 @@ class CfnEnvironmentEC2(
         """
         return jsii.get(self, "instanceType")
 
-    @instance_type.setter
-    def instance_type(self, value: str) -> None:
+    @instance_type.setter # type: ignore
+    def instance_type(self, value: builtins.str) -> None:
         jsii.set(self, "instanceType", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="automaticStopTimeMinutes")
     def automatic_stop_time_minutes(self) -> typing.Optional[jsii.Number]:
         """``AWS::Cloud9::EnvironmentEC2.AutomaticStopTimeMinutes``.
@@ -169,13 +170,13 @@ class CfnEnvironmentEC2(
         """
         return jsii.get(self, "automaticStopTimeMinutes")
 
-    @automatic_stop_time_minutes.setter
+    @automatic_stop_time_minutes.setter # type: ignore
     def automatic_stop_time_minutes(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "automaticStopTimeMinutes", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="connectionType")
-    def connection_type(self) -> typing.Optional[str]:
+    def connection_type(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.ConnectionType``.
 
         see
@@ -183,13 +184,13 @@ class CfnEnvironmentEC2(
         """
         return jsii.get(self, "connectionType")
 
-    @connection_type.setter
-    def connection_type(self, value: typing.Optional[str]) -> None:
+    @connection_type.setter # type: ignore
+    def connection_type(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "connectionType", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.Description``.
 
         see
@@ -197,13 +198,13 @@ class CfnEnvironmentEC2(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.Name``.
 
         see
@@ -211,13 +212,13 @@ class CfnEnvironmentEC2(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: typing.Optional[str]) -> None:
+    @name.setter # type: ignore
+    def name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="ownerArn")
-    def owner_arn(self) -> typing.Optional[str]:
+    def owner_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.OwnerArn``.
 
         see
@@ -225,11 +226,11 @@ class CfnEnvironmentEC2(
         """
         return jsii.get(self, "ownerArn")
 
-    @owner_arn.setter
-    def owner_arn(self, value: typing.Optional[str]) -> None:
+    @owner_arn.setter # type: ignore
+    def owner_arn(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "ownerArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="repositories")
     def repositories(
         self,
@@ -241,16 +242,16 @@ class CfnEnvironmentEC2(
         """
         return jsii.get(self, "repositories")
 
-    @repositories.setter
+    @repositories.setter # type: ignore
     def repositories(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["RepositoryProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "repositories", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="subnetId")
-    def subnet_id(self) -> typing.Optional[str]:
+    def subnet_id(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.SubnetId``.
 
         see
@@ -258,8 +259,8 @@ class CfnEnvironmentEC2(
         """
         return jsii.get(self, "subnetId")
 
-    @subnet_id.setter
-    def subnet_id(self, value: typing.Optional[str]) -> None:
+    @subnet_id.setter # type: ignore
+    def subnet_id(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "subnetId", value)
 
     @jsii.data_type(
@@ -271,7 +272,12 @@ class CfnEnvironmentEC2(
         },
     )
     class RepositoryProperty:
-        def __init__(self, *, path_component: str, repository_url: str) -> None:
+        def __init__(
+            self,
+            *,
+            path_component: builtins.str,
+            repository_url: builtins.str,
+        ) -> None:
             """
             :param path_component: ``CfnEnvironmentEC2.RepositoryProperty.PathComponent``.
             :param repository_url: ``CfnEnvironmentEC2.RepositoryProperty.RepositoryUrl``.
@@ -279,33 +285,37 @@ class CfnEnvironmentEC2(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "path_component": path_component,
                 "repository_url": repository_url,
             }
 
         @builtins.property
-        def path_component(self) -> str:
+        def path_component(self) -> builtins.str:
             """``CfnEnvironmentEC2.RepositoryProperty.PathComponent``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
             """
-            return self._values.get("path_component")
+            result = self._values.get("path_component")
+            assert result is not None, "Required property 'path_component' is missing"
+            return result
 
         @builtins.property
-        def repository_url(self) -> str:
+        def repository_url(self) -> builtins.str:
             """``CfnEnvironmentEC2.RepositoryProperty.RepositoryUrl``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
             """
-            return self._values.get("repository_url")
+            result = self._values.get("repository_url")
+            assert result is not None, "Required property 'repository_url' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -333,14 +343,14 @@ class CfnEnvironmentEC2Props:
     def __init__(
         self,
         *,
-        instance_type: str,
+        instance_type: builtins.str,
         automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
-        connection_type: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
-        name: typing.Optional[str] = None,
-        owner_arn: typing.Optional[str] = None,
+        connection_type: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
+        name: typing.Optional[builtins.str] = None,
+        owner_arn: typing.Optional[builtins.str] = None,
         repositories: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _IResolvable_9ceae33e]]]] = None,
-        subnet_id: typing.Optional[str] = None,
+        subnet_id: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Cloud9::EnvironmentEC2``.
@@ -358,7 +368,7 @@ class CfnEnvironmentEC2Props:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "instance_type": instance_type,
         }
         if automatic_stop_time_minutes is not None:
@@ -379,13 +389,15 @@ class CfnEnvironmentEC2Props:
             self._values["tags"] = tags
 
     @builtins.property
-    def instance_type(self) -> str:
+    def instance_type(self) -> builtins.str:
         """``AWS::Cloud9::EnvironmentEC2.InstanceType``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-instancetype
         """
-        return self._values.get("instance_type")
+        result = self._values.get("instance_type")
+        assert result is not None, "Required property 'instance_type' is missing"
+        return result
 
     @builtins.property
     def automatic_stop_time_minutes(self) -> typing.Optional[jsii.Number]:
@@ -394,43 +406,48 @@ class CfnEnvironmentEC2Props:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-automaticstoptimeminutes
         """
-        return self._values.get("automatic_stop_time_minutes")
+        result = self._values.get("automatic_stop_time_minutes")
+        return result
 
     @builtins.property
-    def connection_type(self) -> typing.Optional[str]:
+    def connection_type(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.ConnectionType``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-connectiontype
         """
-        return self._values.get("connection_type")
+        result = self._values.get("connection_type")
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        return result
 
     @builtins.property
-    def owner_arn(self) -> typing.Optional[str]:
+    def owner_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.OwnerArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-ownerarn
         """
-        return self._values.get("owner_arn")
+        result = self._values.get("owner_arn")
+        return result
 
     @builtins.property
     def repositories(
@@ -441,16 +458,18 @@ class CfnEnvironmentEC2Props:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-repositories
         """
-        return self._values.get("repositories")
+        result = self._values.get("repositories")
+        return result
 
     @builtins.property
-    def subnet_id(self) -> typing.Optional[str]:
+    def subnet_id(self) -> typing.Optional[builtins.str]:
         """``AWS::Cloud9::EnvironmentEC2.SubnetId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-subnetid
         """
-        return self._values.get("subnet_id")
+        result = self._values.get("subnet_id")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -459,12 +478,13 @@ class CfnEnvironmentEC2Props:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -474,7 +494,8 @@ class CfnEnvironmentEC2Props:
 
 
 class CloneRepository(
-    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_cloud9.CloneRepository"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_cloud9.CloneRepository",
 ):
     """The class for different repository providers.
 
@@ -485,7 +506,9 @@ class CloneRepository(
     @jsii.member(jsii_name="fromCodeCommit")
     @builtins.classmethod
     def from_code_commit(
-        cls, repository: _IRepository_91f381de, path: str
+        cls,
+        repository: _IRepository_91f381de,
+        path: builtins.str,
     ) -> "CloneRepository":
         """import repository to cloud9 environment from AWS CodeCommit.
 
@@ -497,18 +520,18 @@ class CloneRepository(
         """
         return jsii.sinvoke(cls, "fromCodeCommit", [repository, path])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="pathComponent")
-    def path_component(self) -> str:
+    def path_component(self) -> builtins.str:
         """
         stability
         :stability: experimental
         """
         return jsii.get(self, "pathComponent")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="repositoryUrl")
-    def repository_url(self) -> str:
+    def repository_url(self) -> builtins.str:
         """
         stability
         :stability: experimental
@@ -534,8 +557,8 @@ class Ec2EnvironmentProps:
         *,
         vpc: _IVpc_3795853f,
         cloned_repositories: typing.Optional[typing.List["CloneRepository"]] = None,
-        description: typing.Optional[str] = None,
-        ec2_environment_name: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        ec2_environment_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[_InstanceType_85a97b30] = None,
         subnet_selection: typing.Optional[_SubnetSelection_36a13cd6] = None,
     ) -> None:
@@ -553,7 +576,7 @@ class Ec2EnvironmentProps:
         """
         if isinstance(subnet_selection, dict):
             subnet_selection = _SubnetSelection_36a13cd6(**subnet_selection)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "vpc": vpc,
         }
         if cloned_repositories is not None:
@@ -574,7 +597,9 @@ class Ec2EnvironmentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("vpc")
+        result = self._values.get("vpc")
+        assert result is not None, "Required property 'vpc' is missing"
+        return result
 
     @builtins.property
     def cloned_repositories(self) -> typing.Optional[typing.List["CloneRepository"]]:
@@ -586,10 +611,11 @@ class Ec2EnvironmentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("cloned_repositories")
+        result = self._values.get("cloned_repositories")
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """Description of the environment.
 
         default
@@ -598,10 +624,11 @@ class Ec2EnvironmentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def ec2_environment_name(self) -> typing.Optional[str]:
+    def ec2_environment_name(self) -> typing.Optional[builtins.str]:
         """Name of the environment.
 
         default
@@ -610,7 +637,8 @@ class Ec2EnvironmentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("ec2_environment_name")
+        result = self._values.get("ec2_environment_name")
+        return result
 
     @builtins.property
     def instance_type(self) -> typing.Optional[_InstanceType_85a97b30]:
@@ -622,7 +650,8 @@ class Ec2EnvironmentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("instance_type")
+        result = self._values.get("instance_type")
+        return result
 
     @builtins.property
     def subnet_selection(self) -> typing.Optional[_SubnetSelection_36a13cd6]:
@@ -634,12 +663,13 @@ class Ec2EnvironmentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("subnet_selection")
+        result = self._values.get("subnet_selection")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -649,7 +679,7 @@ class Ec2EnvironmentProps:
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_cloud9.IEc2Environment")
-class IEc2Environment(_IResource_72f7ee7e, jsii.compat.Protocol):
+class IEc2Environment(_IResource_72f7ee7e, typing_extensions.Protocol):
     """A Cloud9 Environment.
 
     stability
@@ -660,9 +690,9 @@ class IEc2Environment(_IResource_72f7ee7e, jsii.compat.Protocol):
     def __jsii_proxy_class__():
         return _IEc2EnvironmentProxy
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentArn")
-    def ec2_environment_arn(self) -> str:
+    def ec2_environment_arn(self) -> builtins.str:
         """The arn of the EnvironmentEc2.
 
         stability
@@ -672,9 +702,9 @@ class IEc2Environment(_IResource_72f7ee7e, jsii.compat.Protocol):
         """
         ...
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentName")
-    def ec2_environment_name(self) -> str:
+    def ec2_environment_name(self) -> builtins.str:
         """The name of the EnvironmentEc2.
 
         stability
@@ -685,18 +715,20 @@ class IEc2Environment(_IResource_72f7ee7e, jsii.compat.Protocol):
         ...
 
 
-class _IEc2EnvironmentProxy(jsii.proxy_for(_IResource_72f7ee7e)):
+class _IEc2EnvironmentProxy(
+    jsii.proxy_for(_IResource_72f7ee7e) # type: ignore
+):
     """A Cloud9 Environment.
 
     stability
     :stability: experimental
     """
 
-    __jsii_type__ = "monocdk-experiment.aws_cloud9.IEc2Environment"
+    __jsii_type__: typing.ClassVar[str] = "monocdk-experiment.aws_cloud9.IEc2Environment"
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentArn")
-    def ec2_environment_arn(self) -> str:
+    def ec2_environment_arn(self) -> builtins.str:
         """The arn of the EnvironmentEc2.
 
         stability
@@ -706,9 +738,9 @@ class _IEc2EnvironmentProxy(jsii.proxy_for(_IResource_72f7ee7e)):
         """
         return jsii.get(self, "ec2EnvironmentArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentName")
-    def ec2_environment_name(self) -> str:
+    def ec2_environment_name(self) -> builtins.str:
         """The name of the EnvironmentEc2.
 
         stability
@@ -736,12 +768,12 @@ class Ec2Environment(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         vpc: _IVpc_3795853f,
         cloned_repositories: typing.Optional[typing.List["CloneRepository"]] = None,
-        description: typing.Optional[str] = None,
-        ec2_environment_name: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        ec2_environment_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[_InstanceType_85a97b30] = None,
         subnet_selection: typing.Optional[_SubnetSelection_36a13cd6] = None,
     ) -> None:
@@ -772,7 +804,10 @@ class Ec2Environment(
     @jsii.member(jsii_name="fromEc2EnvironmentName")
     @builtins.classmethod
     def from_ec2_environment_name(
-        cls, scope: _Construct_f50a3f53, id: str, ec2_environment_name: str
+        cls,
+        scope: _Construct_f50a3f53,
+        id: builtins.str,
+        ec2_environment_name: builtins.str,
     ) -> "IEc2Environment":
         """import from EnvironmentEc2Name.
 
@@ -785,9 +820,9 @@ class Ec2Environment(
         """
         return jsii.sinvoke(cls, "fromEc2EnvironmentName", [scope, id, ec2_environment_name])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentArn")
-    def ec2_environment_arn(self) -> str:
+    def ec2_environment_arn(self) -> builtins.str:
         """The environment ARN of this Cloud9 environment.
 
         stability
@@ -797,9 +832,9 @@ class Ec2Environment(
         """
         return jsii.get(self, "ec2EnvironmentArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="ec2EnvironmentName")
-    def ec2_environment_name(self) -> str:
+    def ec2_environment_name(self) -> builtins.str:
         """The environment name of this Cloud9 environment.
 
         stability
@@ -809,9 +844,9 @@ class Ec2Environment(
         """
         return jsii.get(self, "ec2EnvironmentName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="environmentId")
-    def environment_id(self) -> str:
+    def environment_id(self) -> builtins.str:
         """The environment ID of this Cloud9 environment.
 
         stability
@@ -819,9 +854,9 @@ class Ec2Environment(
         """
         return jsii.get(self, "environmentId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="ideUrl")
-    def ide_url(self) -> str:
+    def ide_url(self) -> builtins.str:
         """The complete IDE URL of this Cloud9 environment.
 
         stability
@@ -829,7 +864,7 @@ class Ec2Environment(
         """
         return jsii.get(self, "ideUrl")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> _IVpc_3795853f:
         """VPC ID.
