@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -42,7 +42,11 @@ class CfnCustomResource(
     """
 
     def __init__(
-        self, scope: _Construct_f50a3f53, id: str, *, service_token: str
+        self,
+        scope: _Construct_f50a3f53,
+        id: builtins.str,
+        *,
+        service_token: builtins.str,
     ) -> None:
         """Create a new ``AWS::CloudFormation::CustomResource``.
 
@@ -67,27 +71,28 @@ class CfnCustomResource(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="serviceToken")
-    def service_token(self) -> str:
+    def service_token(self) -> builtins.str:
         """``AWS::CloudFormation::CustomResource.ServiceToken``.
 
         see
@@ -95,8 +100,8 @@ class CfnCustomResource(
         """
         return jsii.get(self, "serviceToken")
 
-    @service_token.setter
-    def service_token(self, value: str) -> None:
+    @service_token.setter # type: ignore
+    def service_token(self, value: builtins.str) -> None:
         jsii.set(self, "serviceToken", value)
 
 
@@ -106,7 +111,7 @@ class CfnCustomResource(
     name_mapping={"service_token": "serviceToken"},
 )
 class CfnCustomResourceProps:
-    def __init__(self, *, service_token: str) -> None:
+    def __init__(self, *, service_token: builtins.str) -> None:
         """Properties for defining a ``AWS::CloudFormation::CustomResource``.
 
         :param service_token: ``AWS::CloudFormation::CustomResource.ServiceToken``.
@@ -114,23 +119,25 @@ class CfnCustomResourceProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cfn-customresource.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "service_token": service_token,
         }
 
     @builtins.property
-    def service_token(self) -> str:
+    def service_token(self) -> builtins.str:
         """``AWS::CloudFormation::CustomResource.ServiceToken``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cfn-customresource.html#cfn-customresource-servicetoken
         """
-        return self._values.get("service_token")
+        result = self._values.get("service_token")
+        assert result is not None, "Required property 'service_token' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -156,13 +163,13 @@ class CfnMacro(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        function_name: str,
-        name: str,
-        description: typing.Optional[str] = None,
-        log_group_name: typing.Optional[str] = None,
-        log_role_arn: typing.Optional[str] = None,
+        function_name: builtins.str,
+        name: builtins.str,
+        description: typing.Optional[builtins.str] = None,
+        log_group_name: typing.Optional[builtins.str] = None,
+        log_role_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::CloudFormation::Macro``.
 
@@ -197,27 +204,28 @@ class CfnMacro(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="functionName")
-    def function_name(self) -> str:
+    def function_name(self) -> builtins.str:
         """``AWS::CloudFormation::Macro.FunctionName``.
 
         see
@@ -225,13 +233,13 @@ class CfnMacro(
         """
         return jsii.get(self, "functionName")
 
-    @function_name.setter
-    def function_name(self, value: str) -> None:
+    @function_name.setter # type: ignore
+    def function_name(self, value: builtins.str) -> None:
         jsii.set(self, "functionName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::CloudFormation::Macro.Name``.
 
         see
@@ -239,13 +247,13 @@ class CfnMacro(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: str) -> None:
+    @name.setter # type: ignore
+    def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::CloudFormation::Macro.Description``.
 
         see
@@ -253,13 +261,13 @@ class CfnMacro(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="logGroupName")
-    def log_group_name(self) -> typing.Optional[str]:
+    def log_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::CloudFormation::Macro.LogGroupName``.
 
         see
@@ -267,13 +275,13 @@ class CfnMacro(
         """
         return jsii.get(self, "logGroupName")
 
-    @log_group_name.setter
-    def log_group_name(self, value: typing.Optional[str]) -> None:
+    @log_group_name.setter # type: ignore
+    def log_group_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "logGroupName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="logRoleArn")
-    def log_role_arn(self) -> typing.Optional[str]:
+    def log_role_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::CloudFormation::Macro.LogRoleARN``.
 
         see
@@ -281,8 +289,8 @@ class CfnMacro(
         """
         return jsii.get(self, "logRoleArn")
 
-    @log_role_arn.setter
-    def log_role_arn(self, value: typing.Optional[str]) -> None:
+    @log_role_arn.setter # type: ignore
+    def log_role_arn(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "logRoleArn", value)
 
 
@@ -301,11 +309,11 @@ class CfnMacroProps:
     def __init__(
         self,
         *,
-        function_name: str,
-        name: str,
-        description: typing.Optional[str] = None,
-        log_group_name: typing.Optional[str] = None,
-        log_role_arn: typing.Optional[str] = None,
+        function_name: builtins.str,
+        name: builtins.str,
+        description: typing.Optional[builtins.str] = None,
+        log_group_name: typing.Optional[builtins.str] = None,
+        log_role_arn: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::CloudFormation::Macro``.
 
@@ -318,7 +326,7 @@ class CfnMacroProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-macro.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "function_name": function_name,
             "name": name,
         }
@@ -330,54 +338,61 @@ class CfnMacroProps:
             self._values["log_role_arn"] = log_role_arn
 
     @builtins.property
-    def function_name(self) -> str:
+    def function_name(self) -> builtins.str:
         """``AWS::CloudFormation::Macro.FunctionName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-macro.html#cfn-cloudformation-macro-functionname
         """
-        return self._values.get("function_name")
+        result = self._values.get("function_name")
+        assert result is not None, "Required property 'function_name' is missing"
+        return result
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::CloudFormation::Macro.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-macro.html#cfn-cloudformation-macro-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::CloudFormation::Macro.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-macro.html#cfn-cloudformation-macro-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def log_group_name(self) -> typing.Optional[str]:
+    def log_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::CloudFormation::Macro.LogGroupName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-macro.html#cfn-cloudformation-macro-loggroupname
         """
-        return self._values.get("log_group_name")
+        result = self._values.get("log_group_name")
+        return result
 
     @builtins.property
-    def log_role_arn(self) -> typing.Optional[str]:
+    def log_role_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::CloudFormation::Macro.LogRoleARN``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-macro.html#cfn-cloudformation-macro-logrolearn
         """
-        return self._values.get("log_role_arn")
+        result = self._values.get("log_role_arn")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -403,11 +418,11 @@ class CfnStack(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        template_url: str,
-        notification_arns: typing.Optional[typing.List[str]] = None,
-        parameters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]] = None,
+        template_url: builtins.str,
+        notification_arns: typing.Optional[typing.List[builtins.str]] = None,
+        parameters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, builtins.str]]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
         timeout_in_minutes: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -444,25 +459,26 @@ class CfnStack(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::CloudFormation::Stack.Tags``.
@@ -472,9 +488,9 @@ class CfnStack(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="templateUrl")
-    def template_url(self) -> str:
+    def template_url(self) -> builtins.str:
         """``AWS::CloudFormation::Stack.TemplateURL``.
 
         see
@@ -482,13 +498,13 @@ class CfnStack(
         """
         return jsii.get(self, "templateUrl")
 
-    @template_url.setter
-    def template_url(self, value: str) -> None:
+    @template_url.setter # type: ignore
+    def template_url(self, value: builtins.str) -> None:
         jsii.set(self, "templateUrl", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="notificationArns")
-    def notification_arns(self) -> typing.Optional[typing.List[str]]:
+    def notification_arns(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::CloudFormation::Stack.NotificationARNs``.
 
         see
@@ -496,15 +512,18 @@ class CfnStack(
         """
         return jsii.get(self, "notificationArns")
 
-    @notification_arns.setter
-    def notification_arns(self, value: typing.Optional[typing.List[str]]) -> None:
+    @notification_arns.setter # type: ignore
+    def notification_arns(
+        self,
+        value: typing.Optional[typing.List[builtins.str]],
+    ) -> None:
         jsii.set(self, "notificationArns", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="parameters")
     def parameters(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, builtins.str]]]:
         """``AWS::CloudFormation::Stack.Parameters``.
 
         see
@@ -512,14 +531,14 @@ class CfnStack(
         """
         return jsii.get(self, "parameters")
 
-    @parameters.setter
+    @parameters.setter # type: ignore
     def parameters(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, builtins.str]]],
     ) -> None:
         jsii.set(self, "parameters", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="timeoutInMinutes")
     def timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
         """``AWS::CloudFormation::Stack.TimeoutInMinutes``.
@@ -529,7 +548,7 @@ class CfnStack(
         """
         return jsii.get(self, "timeoutInMinutes")
 
-    @timeout_in_minutes.setter
+    @timeout_in_minutes.setter # type: ignore
     def timeout_in_minutes(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "timeoutInMinutes", value)
 
@@ -549,9 +568,9 @@ class CfnStackProps:
     def __init__(
         self,
         *,
-        template_url: str,
-        notification_arns: typing.Optional[typing.List[str]] = None,
-        parameters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]] = None,
+        template_url: builtins.str,
+        notification_arns: typing.Optional[typing.List[builtins.str]] = None,
+        parameters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, builtins.str]]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
         timeout_in_minutes: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -566,7 +585,7 @@ class CfnStackProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-stack.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "template_url": template_url,
         }
         if notification_arns is not None:
@@ -579,33 +598,37 @@ class CfnStackProps:
             self._values["timeout_in_minutes"] = timeout_in_minutes
 
     @builtins.property
-    def template_url(self) -> str:
+    def template_url(self) -> builtins.str:
         """``AWS::CloudFormation::Stack.TemplateURL``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-stack.html#cfn-cloudformation-stack-templateurl
         """
-        return self._values.get("template_url")
+        result = self._values.get("template_url")
+        assert result is not None, "Required property 'template_url' is missing"
+        return result
 
     @builtins.property
-    def notification_arns(self) -> typing.Optional[typing.List[str]]:
+    def notification_arns(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::CloudFormation::Stack.NotificationARNs``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-stack.html#cfn-cloudformation-stack-notificationarns
         """
-        return self._values.get("notification_arns")
+        result = self._values.get("notification_arns")
+        return result
 
     @builtins.property
     def parameters(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[builtins.str, builtins.str]]]:
         """``AWS::CloudFormation::Stack.Parameters``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-stack.html#cfn-cloudformation-stack-parameters
         """
-        return self._values.get("parameters")
+        result = self._values.get("parameters")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -614,7 +637,8 @@ class CfnStackProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-stack.html#cfn-cloudformation-stack-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
     @builtins.property
     def timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
@@ -623,12 +647,13 @@ class CfnStackProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-stack.html#cfn-cloudformation-stack-timeoutinminutes
         """
-        return self._values.get("timeout_in_minutes")
+        result = self._values.get("timeout_in_minutes")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -654,11 +679,11 @@ class CfnWaitCondition(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         count: typing.Optional[jsii.Number] = None,
-        handle: typing.Optional[str] = None,
-        timeout: typing.Optional[str] = None,
+        handle: typing.Optional[builtins.str] = None,
+        timeout: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::CloudFormation::WaitCondition``.
 
@@ -685,20 +710,21 @@ class CfnWaitCondition(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrData")
     def attr_data(self) -> _IResolvable_9ceae33e:
         """
@@ -707,12 +733,12 @@ class CfnWaitCondition(
         """
         return jsii.get(self, "attrData")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="count")
     def count(self) -> typing.Optional[jsii.Number]:
         """``AWS::CloudFormation::WaitCondition.Count``.
@@ -722,13 +748,13 @@ class CfnWaitCondition(
         """
         return jsii.get(self, "count")
 
-    @count.setter
+    @count.setter # type: ignore
     def count(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "count", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="handle")
-    def handle(self) -> typing.Optional[str]:
+    def handle(self) -> typing.Optional[builtins.str]:
         """``AWS::CloudFormation::WaitCondition.Handle``.
 
         see
@@ -736,13 +762,13 @@ class CfnWaitCondition(
         """
         return jsii.get(self, "handle")
 
-    @handle.setter
-    def handle(self, value: typing.Optional[str]) -> None:
+    @handle.setter # type: ignore
+    def handle(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "handle", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="timeout")
-    def timeout(self) -> typing.Optional[str]:
+    def timeout(self) -> typing.Optional[builtins.str]:
         """``AWS::CloudFormation::WaitCondition.Timeout``.
 
         see
@@ -750,8 +776,8 @@ class CfnWaitCondition(
         """
         return jsii.get(self, "timeout")
 
-    @timeout.setter
-    def timeout(self, value: typing.Optional[str]) -> None:
+    @timeout.setter # type: ignore
+    def timeout(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "timeout", value)
 
 
@@ -769,7 +795,7 @@ class CfnWaitConditionHandle(
     :cloudformationResource:: AWS::CloudFormation::WaitConditionHandle
     """
 
-    def __init__(self, scope: _Construct_f50a3f53, id: str) -> None:
+    def __init__(self, scope: _Construct_f50a3f53, id: builtins.str) -> None:
         """Create a new ``AWS::CloudFormation::WaitConditionHandle``.
 
         :param scope: - scope in which this resource is defined.
@@ -788,9 +814,9 @@ class CfnWaitConditionHandle(
         """
         return jsii.invoke(self, "inspect", [inspector])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
@@ -805,8 +831,8 @@ class CfnWaitConditionProps:
         self,
         *,
         count: typing.Optional[jsii.Number] = None,
-        handle: typing.Optional[str] = None,
-        timeout: typing.Optional[str] = None,
+        handle: typing.Optional[builtins.str] = None,
+        timeout: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::CloudFormation::WaitCondition``.
 
@@ -817,7 +843,7 @@ class CfnWaitConditionProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-waitcondition.html
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if count is not None:
             self._values["count"] = count
         if handle is not None:
@@ -832,30 +858,33 @@ class CfnWaitConditionProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-waitcondition.html#cfn-waitcondition-count
         """
-        return self._values.get("count")
+        result = self._values.get("count")
+        return result
 
     @builtins.property
-    def handle(self) -> typing.Optional[str]:
+    def handle(self) -> typing.Optional[builtins.str]:
         """``AWS::CloudFormation::WaitCondition.Handle``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-waitcondition.html#cfn-waitcondition-handle
         """
-        return self._values.get("handle")
+        result = self._values.get("handle")
+        return result
 
     @builtins.property
-    def timeout(self) -> typing.Optional[str]:
+    def timeout(self) -> typing.Optional[builtins.str]:
         """``AWS::CloudFormation::WaitCondition.Timeout``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-waitcondition.html#cfn-waitcondition-timeout
         """
-        return self._values.get("timeout")
+        result = self._values.get("timeout")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -939,12 +968,12 @@ class CustomResource(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         provider: "ICustomResourceProvider",
-        properties: typing.Optional[typing.Mapping[str, typing.Any]] = None,
+        properties: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         removal_policy: typing.Optional[_RemovalPolicy_5986e9f3] = None,
-        resource_type: typing.Optional[str] = None,
+        resource_type: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param scope: -
@@ -982,9 +1011,9 @@ class CustomResourceProps:
         self,
         *,
         provider: "ICustomResourceProvider",
-        properties: typing.Optional[typing.Mapping[str, typing.Any]] = None,
+        properties: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         removal_policy: typing.Optional[_RemovalPolicy_5986e9f3] = None,
-        resource_type: typing.Optional[str] = None,
+        resource_type: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties to provide a Lambda-backed custom resource.
 
@@ -999,7 +1028,7 @@ class CustomResourceProps:
         stability
         :stability: deprecated
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "provider": provider,
         }
         if properties is not None:
@@ -1037,10 +1066,12 @@ class CustomResourceProps:
         stability
         :stability: deprecated
         """
-        return self._values.get("provider")
+        result = self._values.get("provider")
+        assert result is not None, "Required property 'provider' is missing"
+        return result
 
     @builtins.property
-    def properties(self) -> typing.Optional[typing.Mapping[str, typing.Any]]:
+    def properties(self) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
         """Properties to pass to the Lambda.
 
         default
@@ -1049,7 +1080,8 @@ class CustomResourceProps:
         stability
         :stability: deprecated
         """
-        return self._values.get("properties")
+        result = self._values.get("properties")
+        return result
 
     @builtins.property
     def removal_policy(self) -> typing.Optional[_RemovalPolicy_5986e9f3]:
@@ -1061,10 +1093,11 @@ class CustomResourceProps:
         stability
         :stability: deprecated
         """
-        return self._values.get("removal_policy")
+        result = self._values.get("removal_policy")
+        return result
 
     @builtins.property
-    def resource_type(self) -> typing.Optional[str]:
+    def resource_type(self) -> typing.Optional[builtins.str]:
         """For custom resources, you can specify AWS::CloudFormation::CustomResource (the default) as the resource type, or you can specify your own resource type name.
 
         For example, you can use "Custom::MyCustomResourceTypeName".
@@ -1088,12 +1121,13 @@ class CustomResourceProps:
         stability
         :stability: deprecated
         """
-        return self._values.get("resource_type")
+        result = self._values.get("resource_type")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -1108,7 +1142,7 @@ class CustomResourceProps:
     name_mapping={"service_token": "serviceToken"},
 )
 class CustomResourceProviderConfig:
-    def __init__(self, *, service_token: str) -> None:
+    def __init__(self, *, service_token: builtins.str) -> None:
         """Configuration options for custom resource providers.
 
         :param service_token: The ARN of the SNS topic or the AWS Lambda function which implements this provider.
@@ -1116,23 +1150,25 @@ class CustomResourceProviderConfig:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "service_token": service_token,
         }
 
     @builtins.property
-    def service_token(self) -> str:
+    def service_token(self) -> builtins.str:
         """The ARN of the SNS topic or the AWS Lambda function which implements this provider.
 
         stability
         :stability: experimental
         """
-        return self._values.get("service_token")
+        result = self._values.get("service_token")
+        assert result is not None, "Required property 'service_token' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -1144,7 +1180,7 @@ class CustomResourceProviderConfig:
 @jsii.interface(
     jsii_type="monocdk-experiment.aws_cloudformation.ICustomResourceProvider"
 )
-class ICustomResourceProvider(jsii.compat.Protocol):
+class ICustomResourceProvider(typing_extensions.Protocol):
     """Represents a provider for an AWS CloudFormation custom resources.
 
     deprecated
@@ -1183,7 +1219,7 @@ class _ICustomResourceProviderProxy:
     :stability: deprecated
     """
 
-    __jsii_type__ = "monocdk-experiment.aws_cloudformation.ICustomResourceProvider"
+    __jsii_type__: typing.ClassVar[str] = "monocdk-experiment.aws_cloudformation.ICustomResourceProvider"
 
     @jsii.member(jsii_name="bind")
     def bind(self, scope: _Construct_f50a3f53) -> "CustomResourceProviderConfig":
@@ -1227,10 +1263,10 @@ class NestedStack(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         notifications: typing.Optional[typing.List[_ITopic_ef0ebe0e]] = None,
-        parameters: typing.Optional[typing.Mapping[str, str]] = None,
+        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         timeout: typing.Optional[_Duration_5170c158] = None,
     ) -> None:
         """
@@ -1264,7 +1300,7 @@ class NestedStackProps:
         self,
         *,
         notifications: typing.Optional[typing.List[_ITopic_ef0ebe0e]] = None,
-        parameters: typing.Optional[typing.Mapping[str, str]] = None,
+        parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         timeout: typing.Optional[_Duration_5170c158] = None,
     ) -> None:
         """Initialization props for the ``NestedStack`` construct.
@@ -1276,7 +1312,7 @@ class NestedStackProps:
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if notifications is not None:
             self._values["notifications"] = notifications
         if parameters is not None:
@@ -1294,10 +1330,11 @@ class NestedStackProps:
         stability
         :stability: experimental
         """
-        return self._values.get("notifications")
+        result = self._values.get("notifications")
+        return result
 
     @builtins.property
-    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
+    def parameters(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         """The set value pairs that represent the parameters passed to CloudFormation when this nested stack is created.
 
         Each parameter has a name corresponding
@@ -1313,7 +1350,8 @@ class NestedStackProps:
         stability
         :stability: experimental
         """
-        return self._values.get("parameters")
+        result = self._values.get("parameters")
+        return result
 
     @builtins.property
     def timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -1332,12 +1370,13 @@ class NestedStackProps:
         stability
         :stability: experimental
         """
-        return self._values.get("timeout")
+        result = self._values.get("timeout")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -1424,9 +1463,9 @@ class CustomResourceProvider(
         """
         return jsii.invoke(self, "bind", [_])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="serviceToken")
-    def service_token(self) -> str:
+    def service_token(self) -> builtins.str:
         """the ServiceToken which contains the ARN for this provider.
 
         stability
