@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -37,7 +37,7 @@ class HttpOrigin(
 
     def __init__(
         self,
-        domain_name: str,
+        domain_name: builtins.str,
         *,
         http_port: typing.Optional[jsii.Number] = None,
         https_port: typing.Optional[jsii.Number] = None,
@@ -46,8 +46,8 @@ class HttpOrigin(
         read_timeout: typing.Optional[_Duration_5170c158] = None,
         connection_attempts: typing.Optional[jsii.Number] = None,
         connection_timeout: typing.Optional[_Duration_5170c158] = None,
-        custom_headers: typing.Optional[typing.Mapping[str, str]] = None,
-        origin_path: typing.Optional[str] = None,
+        custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        origin_path: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param domain_name: -
@@ -80,7 +80,7 @@ class HttpOrigin(
 
     @jsii.member(jsii_name="renderCustomOriginConfig")
     def _render_custom_origin_config(
-        self
+        self,
     ) -> typing.Optional[_CfnDistribution_3a5e7b5c.CustomOriginConfigProperty]:
         """
         stability
@@ -110,8 +110,8 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         *,
         connection_attempts: typing.Optional[jsii.Number] = None,
         connection_timeout: typing.Optional[_Duration_5170c158] = None,
-        custom_headers: typing.Optional[typing.Mapping[str, str]] = None,
-        origin_path: typing.Optional[str] = None,
+        custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        origin_path: typing.Optional[builtins.str] = None,
         http_port: typing.Optional[jsii.Number] = None,
         https_port: typing.Optional[jsii.Number] = None,
         keepalive_timeout: typing.Optional[_Duration_5170c158] = None,
@@ -133,7 +133,7 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if connection_attempts is not None:
             self._values["connection_attempts"] = connection_attempts
         if connection_timeout is not None:
@@ -165,7 +165,8 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         stability
         :stability: experimental
         """
-        return self._values.get("connection_attempts")
+        result = self._values.get("connection_attempts")
+        return result
 
     @builtins.property
     def connection_timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -179,10 +180,13 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         stability
         :stability: experimental
         """
-        return self._values.get("connection_timeout")
+        result = self._values.get("connection_timeout")
+        return result
 
     @builtins.property
-    def custom_headers(self) -> typing.Optional[typing.Mapping[str, str]]:
+    def custom_headers(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         """A list of HTTP header names and values that CloudFront adds to requests it sends to the origin.
 
         default
@@ -191,10 +195,11 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         stability
         :stability: experimental
         """
-        return self._values.get("custom_headers")
+        result = self._values.get("custom_headers")
+        return result
 
     @builtins.property
-    def origin_path(self) -> typing.Optional[str]:
+    def origin_path(self) -> typing.Optional[builtins.str]:
         """An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
 
         Must begin, but not end, with '/' (e.g., '/production/images').
@@ -205,7 +210,8 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         stability
         :stability: experimental
         """
-        return self._values.get("origin_path")
+        result = self._values.get("origin_path")
+        return result
 
     @builtins.property
     def http_port(self) -> typing.Optional[jsii.Number]:
@@ -217,7 +223,8 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         stability
         :stability: experimental
         """
-        return self._values.get("http_port")
+        result = self._values.get("http_port")
+        return result
 
     @builtins.property
     def https_port(self) -> typing.Optional[jsii.Number]:
@@ -229,7 +236,8 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         stability
         :stability: experimental
         """
-        return self._values.get("https_port")
+        result = self._values.get("https_port")
+        return result
 
     @builtins.property
     def keepalive_timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -243,7 +251,8 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         stability
         :stability: experimental
         """
-        return self._values.get("keepalive_timeout")
+        result = self._values.get("keepalive_timeout")
+        return result
 
     @builtins.property
     def protocol_policy(self) -> typing.Optional[_OriginProtocolPolicy_d2d28ec7]:
@@ -255,7 +264,8 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         stability
         :stability: experimental
         """
-        return self._values.get("protocol_policy")
+        result = self._values.get("protocol_policy")
+        return result
 
     @builtins.property
     def read_timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -269,12 +279,13 @@ class HttpOriginProps(_OriginProps_3ddcc1c8):
         stability
         :stability: experimental
         """
-        return self._values.get("read_timeout")
+        result = self._values.get("read_timeout")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -305,8 +316,8 @@ class LoadBalancerV2Origin(
         read_timeout: typing.Optional[_Duration_5170c158] = None,
         connection_attempts: typing.Optional[jsii.Number] = None,
         connection_timeout: typing.Optional[_Duration_5170c158] = None,
-        custom_headers: typing.Optional[typing.Mapping[str, str]] = None,
-        origin_path: typing.Optional[str] = None,
+        custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        origin_path: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param load_balancer: -
@@ -359,8 +370,8 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         *,
         connection_attempts: typing.Optional[jsii.Number] = None,
         connection_timeout: typing.Optional[_Duration_5170c158] = None,
-        custom_headers: typing.Optional[typing.Mapping[str, str]] = None,
-        origin_path: typing.Optional[str] = None,
+        custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        origin_path: typing.Optional[builtins.str] = None,
         http_port: typing.Optional[jsii.Number] = None,
         https_port: typing.Optional[jsii.Number] = None,
         keepalive_timeout: typing.Optional[_Duration_5170c158] = None,
@@ -382,7 +393,7 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if connection_attempts is not None:
             self._values["connection_attempts"] = connection_attempts
         if connection_timeout is not None:
@@ -414,7 +425,8 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         stability
         :stability: experimental
         """
-        return self._values.get("connection_attempts")
+        result = self._values.get("connection_attempts")
+        return result
 
     @builtins.property
     def connection_timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -428,10 +440,13 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         stability
         :stability: experimental
         """
-        return self._values.get("connection_timeout")
+        result = self._values.get("connection_timeout")
+        return result
 
     @builtins.property
-    def custom_headers(self) -> typing.Optional[typing.Mapping[str, str]]:
+    def custom_headers(
+        self,
+    ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         """A list of HTTP header names and values that CloudFront adds to requests it sends to the origin.
 
         default
@@ -440,10 +455,11 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         stability
         :stability: experimental
         """
-        return self._values.get("custom_headers")
+        result = self._values.get("custom_headers")
+        return result
 
     @builtins.property
-    def origin_path(self) -> typing.Optional[str]:
+    def origin_path(self) -> typing.Optional[builtins.str]:
         """An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
 
         Must begin, but not end, with '/' (e.g., '/production/images').
@@ -454,7 +470,8 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         stability
         :stability: experimental
         """
-        return self._values.get("origin_path")
+        result = self._values.get("origin_path")
+        return result
 
     @builtins.property
     def http_port(self) -> typing.Optional[jsii.Number]:
@@ -466,7 +483,8 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         stability
         :stability: experimental
         """
-        return self._values.get("http_port")
+        result = self._values.get("http_port")
+        return result
 
     @builtins.property
     def https_port(self) -> typing.Optional[jsii.Number]:
@@ -478,7 +496,8 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         stability
         :stability: experimental
         """
-        return self._values.get("https_port")
+        result = self._values.get("https_port")
+        return result
 
     @builtins.property
     def keepalive_timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -492,7 +511,8 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         stability
         :stability: experimental
         """
-        return self._values.get("keepalive_timeout")
+        result = self._values.get("keepalive_timeout")
+        return result
 
     @builtins.property
     def protocol_policy(self) -> typing.Optional[_OriginProtocolPolicy_d2d28ec7]:
@@ -504,7 +524,8 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         stability
         :stability: experimental
         """
-        return self._values.get("protocol_policy")
+        result = self._values.get("protocol_policy")
+        return result
 
     @builtins.property
     def read_timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -518,12 +539,13 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         stability
         :stability: experimental
         """
-        return self._values.get("read_timeout")
+        result = self._values.get("read_timeout")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -571,7 +593,10 @@ class OriginGroup(
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, scope: _Construct_f50a3f53, *, origin_id: str
+        self,
+        scope: _Construct_f50a3f53,
+        *,
+        origin_id: builtins.str,
     ) -> _OriginBindConfig_86e63cf0:
         """The method called when a given Origin is added (for the first time) to a Distribution.
 
@@ -612,7 +637,7 @@ class OriginGroupProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "fallback_origin": fallback_origin,
             "primary_origin": primary_origin,
         }
@@ -626,7 +651,9 @@ class OriginGroupProps:
         stability
         :stability: experimental
         """
-        return self._values.get("fallback_origin")
+        result = self._values.get("fallback_origin")
+        assert result is not None, "Required property 'fallback_origin' is missing"
+        return result
 
     @builtins.property
     def primary_origin(self) -> _IOrigin_ceac1980:
@@ -635,7 +662,9 @@ class OriginGroupProps:
         stability
         :stability: experimental
         """
-        return self._values.get("primary_origin")
+        result = self._values.get("primary_origin")
+        assert result is not None, "Required property 'primary_origin' is missing"
+        return result
 
     @builtins.property
     def fallback_status_codes(self) -> typing.Optional[typing.List[jsii.Number]]:
@@ -647,12 +676,13 @@ class OriginGroupProps:
         stability
         :stability: experimental
         """
-        return self._values.get("fallback_status_codes")
+        result = self._values.get("fallback_status_codes")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -677,7 +707,10 @@ class S3Origin(
     """
 
     def __init__(
-        self, bucket: _IBucket_25bad983, *, origin_path: typing.Optional[str] = None
+        self,
+        bucket: _IBucket_25bad983,
+        *,
+        origin_path: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param bucket: -
@@ -692,7 +725,10 @@ class S3Origin(
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, scope: _Construct_f50a3f53, *, origin_id: str
+        self,
+        scope: _Construct_f50a3f53,
+        *,
+        origin_id: builtins.str,
     ) -> _OriginBindConfig_86e63cf0:
         """The method called when a given Origin is added (for the first time) to a Distribution.
 
@@ -713,7 +749,7 @@ class S3Origin(
     name_mapping={"origin_path": "originPath"},
 )
 class S3OriginProps:
-    def __init__(self, *, origin_path: typing.Optional[str] = None) -> None:
+    def __init__(self, *, origin_path: typing.Optional[builtins.str] = None) -> None:
         """Properties to use to customize an S3 Origin.
 
         :param origin_path: An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. Must begin, but not end, with '/' (e.g., '/production/images'). Default: '/'
@@ -721,12 +757,12 @@ class S3OriginProps:
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if origin_path is not None:
             self._values["origin_path"] = origin_path
 
     @builtins.property
-    def origin_path(self) -> typing.Optional[str]:
+    def origin_path(self) -> typing.Optional[builtins.str]:
         """An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
 
         Must begin, but not end, with '/' (e.g., '/production/images').
@@ -737,12 +773,13 @@ class S3OriginProps:
         stability
         :stability: experimental
         """
-        return self._values.get("origin_path")
+        result = self._values.get("origin_path")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
