@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -41,12 +41,12 @@ class CfnProfilingGroup(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        profiling_group_name: str,
+        profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
         anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]]]] = None,
-        compute_platform: typing.Optional[str] = None,
+        compute_platform: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::CodeGuruProfiler::ProfilingGroup``.
@@ -82,34 +82,35 @@ class CfnProfilingGroup(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::CodeGuruProfiler::ProfilingGroup.Tags``.
@@ -119,7 +120,7 @@ class CfnProfilingGroup(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="agentPermissions")
     def agent_permissions(self) -> typing.Any:
         """``AWS::CodeGuruProfiler::ProfilingGroup.AgentPermissions``.
@@ -129,13 +130,13 @@ class CfnProfilingGroup(
         """
         return jsii.get(self, "agentPermissions")
 
-    @agent_permissions.setter
+    @agent_permissions.setter # type: ignore
     def agent_permissions(self, value: typing.Any) -> None:
         jsii.set(self, "agentPermissions", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="profilingGroupName")
-    def profiling_group_name(self) -> str:
+    def profiling_group_name(self) -> builtins.str:
         """``AWS::CodeGuruProfiler::ProfilingGroup.ProfilingGroupName``.
 
         see
@@ -143,11 +144,11 @@ class CfnProfilingGroup(
         """
         return jsii.get(self, "profilingGroupName")
 
-    @profiling_group_name.setter
-    def profiling_group_name(self, value: str) -> None:
+    @profiling_group_name.setter # type: ignore
+    def profiling_group_name(self, value: builtins.str) -> None:
         jsii.set(self, "profilingGroupName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="anomalyDetectionNotificationConfiguration")
     def anomaly_detection_notification_configuration(
         self,
@@ -159,16 +160,16 @@ class CfnProfilingGroup(
         """
         return jsii.get(self, "anomalyDetectionNotificationConfiguration")
 
-    @anomaly_detection_notification_configuration.setter
+    @anomaly_detection_notification_configuration.setter # type: ignore
     def anomaly_detection_notification_configuration(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "anomalyDetectionNotificationConfiguration", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="computePlatform")
-    def compute_platform(self) -> typing.Optional[str]:
+    def compute_platform(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform``.
 
         see
@@ -176,8 +177,8 @@ class CfnProfilingGroup(
         """
         return jsii.get(self, "computePlatform")
 
-    @compute_platform.setter
-    def compute_platform(self, value: typing.Optional[str]) -> None:
+    @compute_platform.setter # type: ignore
+    def compute_platform(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "computePlatform", value)
 
     @jsii.data_type(
@@ -187,7 +188,10 @@ class CfnProfilingGroup(
     )
     class ChannelProperty:
         def __init__(
-            self, *, channel_uri: str, channel_id: typing.Optional[str] = None
+            self,
+            *,
+            channel_uri: builtins.str,
+            channel_id: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param channel_uri: ``CfnProfilingGroup.ChannelProperty.channelUri``.
@@ -196,34 +200,37 @@ class CfnProfilingGroup(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-channel.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "channel_uri": channel_uri,
             }
             if channel_id is not None:
                 self._values["channel_id"] = channel_id
 
         @builtins.property
-        def channel_uri(self) -> str:
+        def channel_uri(self) -> builtins.str:
             """``CfnProfilingGroup.ChannelProperty.channelUri``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-channel.html#cfn-codeguruprofiler-profilinggroup-channel-channeluri
             """
-            return self._values.get("channel_uri")
+            result = self._values.get("channel_uri")
+            assert result is not None, "Required property 'channel_uri' is missing"
+            return result
 
         @builtins.property
-        def channel_id(self) -> typing.Optional[str]:
+        def channel_id(self) -> typing.Optional[builtins.str]:
             """``CfnProfilingGroup.ChannelProperty.channelId``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-channel.html#cfn-codeguruprofiler-profilinggroup-channel-channelid
             """
-            return self._values.get("channel_id")
+            result = self._values.get("channel_id")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -247,10 +254,10 @@ class CfnProfilingGroupProps:
     def __init__(
         self,
         *,
-        profiling_group_name: str,
+        profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
         anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e]]]] = None,
-        compute_platform: typing.Optional[str] = None,
+        compute_platform: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::CodeGuruProfiler::ProfilingGroup``.
@@ -264,7 +271,7 @@ class CfnProfilingGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "profiling_group_name": profiling_group_name,
         }
         if agent_permissions is not None:
@@ -277,13 +284,15 @@ class CfnProfilingGroupProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def profiling_group_name(self) -> str:
+    def profiling_group_name(self) -> builtins.str:
         """``AWS::CodeGuruProfiler::ProfilingGroup.ProfilingGroupName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-profilinggroupname
         """
-        return self._values.get("profiling_group_name")
+        result = self._values.get("profiling_group_name")
+        assert result is not None, "Required property 'profiling_group_name' is missing"
+        return result
 
     @builtins.property
     def agent_permissions(self) -> typing.Any:
@@ -292,7 +301,8 @@ class CfnProfilingGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-agentpermissions
         """
-        return self._values.get("agent_permissions")
+        result = self._values.get("agent_permissions")
+        return result
 
     @builtins.property
     def anomaly_detection_notification_configuration(
@@ -303,16 +313,18 @@ class CfnProfilingGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-anomalydetectionnotificationconfiguration
         """
-        return self._values.get("anomaly_detection_notification_configuration")
+        result = self._values.get("anomaly_detection_notification_configuration")
+        return result
 
     @builtins.property
-    def compute_platform(self) -> typing.Optional[str]:
+    def compute_platform(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-computeplatform
         """
-        return self._values.get("compute_platform")
+        result = self._values.get("compute_platform")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -321,12 +333,13 @@ class CfnProfilingGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -358,7 +371,7 @@ class ComputePlatform(enum.Enum):
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_codeguruprofiler.IProfilingGroup")
-class IProfilingGroup(_IResource_72f7ee7e, jsii.compat.Protocol):
+class IProfilingGroup(_IResource_72f7ee7e, typing_extensions.Protocol):
     """IResource represents a Profiling Group.
 
     stability
@@ -369,9 +382,9 @@ class IProfilingGroup(_IResource_72f7ee7e, jsii.compat.Protocol):
     def __jsii_proxy_class__():
         return _IProfilingGroupProxy
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="profilingGroupName")
-    def profiling_group_name(self) -> str:
+    def profiling_group_name(self) -> builtins.str:
         """A name for the profiling group.
 
         stability
@@ -414,18 +427,20 @@ class IProfilingGroup(_IResource_72f7ee7e, jsii.compat.Protocol):
         ...
 
 
-class _IProfilingGroupProxy(jsii.proxy_for(_IResource_72f7ee7e)):
+class _IProfilingGroupProxy(
+    jsii.proxy_for(_IResource_72f7ee7e) # type: ignore
+):
     """IResource represents a Profiling Group.
 
     stability
     :stability: experimental
     """
 
-    __jsii_type__ = "monocdk-experiment.aws_codeguruprofiler.IProfilingGroup"
+    __jsii_type__: typing.ClassVar[str] = "monocdk-experiment.aws_codeguruprofiler.IProfilingGroup"
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="profilingGroupName")
-    def profiling_group_name(self) -> str:
+    def profiling_group_name(self) -> builtins.str:
         """A name for the profiling group.
 
         stability
@@ -483,10 +498,10 @@ class ProfilingGroup(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         compute_platform: typing.Optional["ComputePlatform"] = None,
-        profiling_group_name: typing.Optional[str] = None,
+        profiling_group_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param scope: -
@@ -507,7 +522,10 @@ class ProfilingGroup(
     @jsii.member(jsii_name="fromProfilingGroupArn")
     @builtins.classmethod
     def from_profiling_group_arn(
-        cls, scope: _Construct_f50a3f53, id: str, profiling_group_arn: str
+        cls,
+        scope: _Construct_f50a3f53,
+        id: builtins.str,
+        profiling_group_arn: builtins.str,
     ) -> "IProfilingGroup":
         """Import an existing Profiling Group provided an ARN.
 
@@ -523,7 +541,10 @@ class ProfilingGroup(
     @jsii.member(jsii_name="fromProfilingGroupName")
     @builtins.classmethod
     def from_profiling_group_name(
-        cls, scope: _Construct_f50a3f53, id: str, profiling_group_name: str
+        cls,
+        scope: _Construct_f50a3f53,
+        id: builtins.str,
+        profiling_group_name: builtins.str,
     ) -> "IProfilingGroup":
         """Import an existing Profiling Group provided a Profiling Group Name.
 
@@ -568,9 +589,9 @@ class ProfilingGroup(
         """
         return jsii.invoke(self, "grantRead", [grantee])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="profilingGroupArn")
-    def profiling_group_arn(self) -> str:
+    def profiling_group_arn(self) -> builtins.str:
         """The ARN of the Profiling Group.
 
         stability
@@ -580,9 +601,9 @@ class ProfilingGroup(
         """
         return jsii.get(self, "profilingGroupArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="profilingGroupName")
-    def profiling_group_name(self) -> str:
+    def profiling_group_name(self) -> builtins.str:
         """The name of the Profiling Group.
 
         stability
@@ -606,7 +627,7 @@ class ProfilingGroupProps:
         self,
         *,
         compute_platform: typing.Optional["ComputePlatform"] = None,
-        profiling_group_name: typing.Optional[str] = None,
+        profiling_group_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for creating a new Profiling Group.
 
@@ -616,7 +637,7 @@ class ProfilingGroupProps:
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if compute_platform is not None:
             self._values["compute_platform"] = compute_platform
         if profiling_group_name is not None:
@@ -632,10 +653,11 @@ class ProfilingGroupProps:
         stability
         :stability: experimental
         """
-        return self._values.get("compute_platform")
+        result = self._values.get("compute_platform")
+        return result
 
     @builtins.property
-    def profiling_group_name(self) -> typing.Optional[str]:
+    def profiling_group_name(self) -> typing.Optional[builtins.str]:
         """A name for the profiling group.
 
         default
@@ -644,12 +666,13 @@ class ProfilingGroupProps:
         stability
         :stability: experimental
         """
-        return self._values.get("profiling_group_name")
+        result = self._values.get("profiling_group_name")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
