@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -40,15 +40,15 @@ class CfnGitHubRepository(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        repository_access_token: str,
-        repository_name: str,
-        repository_owner: str,
+        repository_access_token: builtins.str,
+        repository_name: builtins.str,
+        repository_owner: builtins.str,
         code: typing.Optional[typing.Union["CodeProperty", _IResolvable_9ceae33e]] = None,
-        enable_issues: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        is_private: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        repository_description: typing.Optional[str] = None,
+        enable_issues: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        is_private: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        repository_description: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::CodeStar::GitHubRepository``.
 
@@ -87,27 +87,28 @@ class CfnGitHubRepository(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="repositoryAccessToken")
-    def repository_access_token(self) -> str:
+    def repository_access_token(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryAccessToken``.
 
         see
@@ -115,13 +116,13 @@ class CfnGitHubRepository(
         """
         return jsii.get(self, "repositoryAccessToken")
 
-    @repository_access_token.setter
-    def repository_access_token(self, value: str) -> None:
+    @repository_access_token.setter # type: ignore
+    def repository_access_token(self, value: builtins.str) -> None:
         jsii.set(self, "repositoryAccessToken", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="repositoryName")
-    def repository_name(self) -> str:
+    def repository_name(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryName``.
 
         see
@@ -129,13 +130,13 @@ class CfnGitHubRepository(
         """
         return jsii.get(self, "repositoryName")
 
-    @repository_name.setter
-    def repository_name(self, value: str) -> None:
+    @repository_name.setter # type: ignore
+    def repository_name(self, value: builtins.str) -> None:
         jsii.set(self, "repositoryName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="repositoryOwner")
-    def repository_owner(self) -> str:
+    def repository_owner(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryOwner``.
 
         see
@@ -143,11 +144,11 @@ class CfnGitHubRepository(
         """
         return jsii.get(self, "repositoryOwner")
 
-    @repository_owner.setter
-    def repository_owner(self, value: str) -> None:
+    @repository_owner.setter # type: ignore
+    def repository_owner(self, value: builtins.str) -> None:
         jsii.set(self, "repositoryOwner", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="code")
     def code(
         self,
@@ -159,18 +160,18 @@ class CfnGitHubRepository(
         """
         return jsii.get(self, "code")
 
-    @code.setter
+    @code.setter # type: ignore
     def code(
         self,
         value: typing.Optional[typing.Union["CodeProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "code", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="enableIssues")
     def enable_issues(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::CodeStar::GitHubRepository.EnableIssues``.
 
         see
@@ -178,15 +179,18 @@ class CfnGitHubRepository(
         """
         return jsii.get(self, "enableIssues")
 
-    @enable_issues.setter
+    @enable_issues.setter # type: ignore
     def enable_issues(
-        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "enableIssues", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="isPrivate")
-    def is_private(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def is_private(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::CodeStar::GitHubRepository.IsPrivate``.
 
         see
@@ -194,15 +198,16 @@ class CfnGitHubRepository(
         """
         return jsii.get(self, "isPrivate")
 
-    @is_private.setter
+    @is_private.setter # type: ignore
     def is_private(
-        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "isPrivate", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="repositoryDescription")
-    def repository_description(self) -> typing.Optional[str]:
+    def repository_description(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeStar::GitHubRepository.RepositoryDescription``.
 
         see
@@ -210,8 +215,8 @@ class CfnGitHubRepository(
         """
         return jsii.get(self, "repositoryDescription")
 
-    @repository_description.setter
-    def repository_description(self, value: typing.Optional[str]) -> None:
+    @repository_description.setter # type: ignore
+    def repository_description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "repositoryDescription", value)
 
     @jsii.data_type(
@@ -231,7 +236,7 @@ class CfnGitHubRepository(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-code.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "s3": s3,
             }
 
@@ -244,12 +249,14 @@ class CfnGitHubRepository(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-code.html#cfn-codestar-githubrepository-code-s3
             """
-            return self._values.get("s3")
+            result = self._values.get("s3")
+            assert result is not None, "Required property 's3' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -268,7 +275,11 @@ class CfnGitHubRepository(
     )
     class S3Property:
         def __init__(
-            self, *, bucket: str, key: str, object_version: typing.Optional[str] = None
+            self,
+            *,
+            bucket: builtins.str,
+            key: builtins.str,
+            object_version: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param bucket: ``CfnGitHubRepository.S3Property.Bucket``.
@@ -278,7 +289,7 @@ class CfnGitHubRepository(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-s3.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "bucket": bucket,
                 "key": key,
             }
@@ -286,36 +297,41 @@ class CfnGitHubRepository(
                 self._values["object_version"] = object_version
 
         @builtins.property
-        def bucket(self) -> str:
+        def bucket(self) -> builtins.str:
             """``CfnGitHubRepository.S3Property.Bucket``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-s3.html#cfn-codestar-githubrepository-s3-bucket
             """
-            return self._values.get("bucket")
+            result = self._values.get("bucket")
+            assert result is not None, "Required property 'bucket' is missing"
+            return result
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnGitHubRepository.S3Property.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-s3.html#cfn-codestar-githubrepository-s3-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def object_version(self) -> typing.Optional[str]:
+        def object_version(self) -> typing.Optional[builtins.str]:
             """``CfnGitHubRepository.S3Property.ObjectVersion``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-s3.html#cfn-codestar-githubrepository-s3-objectversion
             """
-            return self._values.get("object_version")
+            result = self._values.get("object_version")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -341,13 +357,13 @@ class CfnGitHubRepositoryProps:
     def __init__(
         self,
         *,
-        repository_access_token: str,
-        repository_name: str,
-        repository_owner: str,
+        repository_access_token: builtins.str,
+        repository_name: builtins.str,
+        repository_owner: builtins.str,
         code: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_9ceae33e]] = None,
-        enable_issues: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        is_private: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        repository_description: typing.Optional[str] = None,
+        enable_issues: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        is_private: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        repository_description: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::CodeStar::GitHubRepository``.
 
@@ -362,7 +378,7 @@ class CfnGitHubRepositoryProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "repository_access_token": repository_access_token,
             "repository_name": repository_name,
             "repository_owner": repository_owner,
@@ -377,31 +393,37 @@ class CfnGitHubRepositoryProps:
             self._values["repository_description"] = repository_description
 
     @builtins.property
-    def repository_access_token(self) -> str:
+    def repository_access_token(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryAccessToken``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositoryaccesstoken
         """
-        return self._values.get("repository_access_token")
+        result = self._values.get("repository_access_token")
+        assert result is not None, "Required property 'repository_access_token' is missing"
+        return result
 
     @builtins.property
-    def repository_name(self) -> str:
+    def repository_name(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositoryname
         """
-        return self._values.get("repository_name")
+        result = self._values.get("repository_name")
+        assert result is not None, "Required property 'repository_name' is missing"
+        return result
 
     @builtins.property
-    def repository_owner(self) -> str:
+    def repository_owner(self) -> builtins.str:
         """``AWS::CodeStar::GitHubRepository.RepositoryOwner``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositoryowner
         """
-        return self._values.get("repository_owner")
+        result = self._values.get("repository_owner")
+        assert result is not None, "Required property 'repository_owner' is missing"
+        return result
 
     @builtins.property
     def code(
@@ -412,41 +434,47 @@ class CfnGitHubRepositoryProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-code
         """
-        return self._values.get("code")
+        result = self._values.get("code")
+        return result
 
     @builtins.property
     def enable_issues(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::CodeStar::GitHubRepository.EnableIssues``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-enableissues
         """
-        return self._values.get("enable_issues")
+        result = self._values.get("enable_issues")
+        return result
 
     @builtins.property
-    def is_private(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def is_private(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::CodeStar::GitHubRepository.IsPrivate``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-isprivate
         """
-        return self._values.get("is_private")
+        result = self._values.get("is_private")
+        return result
 
     @builtins.property
-    def repository_description(self) -> typing.Optional[str]:
+    def repository_description(self) -> typing.Optional[builtins.str]:
         """``AWS::CodeStar::GitHubRepository.RepositoryDescription``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-repositorydescription
         """
-        return self._values.get("repository_description")
+        result = self._values.get("repository_description")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -476,12 +504,12 @@ class GitHubRepositoryProps:
         *,
         access_token: _SecretValue_99478b8b,
         contents_bucket: _IBucket_25bad983,
-        contents_key: str,
-        owner: str,
-        repository_name: str,
-        contents_s3_version: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
-        enable_issues: typing.Optional[bool] = None,
+        contents_key: builtins.str,
+        owner: builtins.str,
+        repository_name: builtins.str,
+        contents_s3_version: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
+        enable_issues: typing.Optional[builtins.bool] = None,
         visibility: typing.Optional["RepositoryVisibility"] = None,
     ) -> None:
         """Construction properties of {@link GitHubRepository}.
@@ -499,7 +527,7 @@ class GitHubRepositoryProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "access_token": access_token,
             "contents_bucket": contents_bucket,
             "contents_key": contents_key,
@@ -522,7 +550,9 @@ class GitHubRepositoryProps:
         stability
         :stability: experimental
         """
-        return self._values.get("access_token")
+        result = self._values.get("access_token")
+        assert result is not None, "Required property 'access_token' is missing"
+        return result
 
     @builtins.property
     def contents_bucket(self) -> _IBucket_25bad983:
@@ -531,19 +561,23 @@ class GitHubRepositoryProps:
         stability
         :stability: experimental
         """
-        return self._values.get("contents_bucket")
+        result = self._values.get("contents_bucket")
+        assert result is not None, "Required property 'contents_bucket' is missing"
+        return result
 
     @builtins.property
-    def contents_key(self) -> str:
+    def contents_key(self) -> builtins.str:
         """The S3 object key or file name for the ZIP file.
 
         stability
         :stability: experimental
         """
-        return self._values.get("contents_key")
+        result = self._values.get("contents_key")
+        assert result is not None, "Required property 'contents_key' is missing"
+        return result
 
     @builtins.property
-    def owner(self) -> str:
+    def owner(self) -> builtins.str:
         """The GitHub user name for the owner of the GitHub repository to be created.
 
         If this
@@ -552,19 +586,23 @@ class GitHubRepositoryProps:
         stability
         :stability: experimental
         """
-        return self._values.get("owner")
+        result = self._values.get("owner")
+        assert result is not None, "Required property 'owner' is missing"
+        return result
 
     @builtins.property
-    def repository_name(self) -> str:
+    def repository_name(self) -> builtins.str:
         """The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
 
         stability
         :stability: experimental
         """
-        return self._values.get("repository_name")
+        result = self._values.get("repository_name")
+        assert result is not None, "Required property 'repository_name' is missing"
+        return result
 
     @builtins.property
-    def contents_s3_version(self) -> typing.Optional[str]:
+    def contents_s3_version(self) -> typing.Optional[builtins.str]:
         """The object version of the ZIP file, if versioning is enabled for the Amazon S3 bucket.
 
         default
@@ -573,10 +611,11 @@ class GitHubRepositoryProps:
         stability
         :stability: experimental
         """
-        return self._values.get("contents_s3_version")
+        result = self._values.get("contents_s3_version")
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """A comment or description about the new repository.
 
         This description is displayed in GitHub after the repository
@@ -588,10 +627,11 @@ class GitHubRepositoryProps:
         stability
         :stability: experimental
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def enable_issues(self) -> typing.Optional[bool]:
+    def enable_issues(self) -> typing.Optional[builtins.bool]:
         """Indicates whether to enable issues for the GitHub repository.
 
         You can use GitHub issues to track information
@@ -603,7 +643,8 @@ class GitHubRepositoryProps:
         stability
         :stability: experimental
         """
-        return self._values.get("enable_issues")
+        result = self._values.get("enable_issues")
+        return result
 
     @builtins.property
     def visibility(self) -> typing.Optional["RepositoryVisibility"]:
@@ -618,12 +659,13 @@ class GitHubRepositoryProps:
         stability
         :stability: experimental
         """
-        return self._values.get("visibility")
+        result = self._values.get("visibility")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -633,7 +675,7 @@ class GitHubRepositoryProps:
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_codestar.IGitHubRepository")
-class IGitHubRepository(_IResource_72f7ee7e, jsii.compat.Protocol):
+class IGitHubRepository(_IResource_72f7ee7e, typing_extensions.Protocol):
     """GitHubRepository resource interface.
 
     stability
@@ -644,9 +686,9 @@ class IGitHubRepository(_IResource_72f7ee7e, jsii.compat.Protocol):
     def __jsii_proxy_class__():
         return _IGitHubRepositoryProxy
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="owner")
-    def owner(self) -> str:
+    def owner(self) -> builtins.str:
         """the repository owner.
 
         stability
@@ -654,9 +696,9 @@ class IGitHubRepository(_IResource_72f7ee7e, jsii.compat.Protocol):
         """
         ...
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="repo")
-    def repo(self) -> str:
+    def repo(self) -> builtins.str:
         """the repository name.
 
         stability
@@ -665,18 +707,20 @@ class IGitHubRepository(_IResource_72f7ee7e, jsii.compat.Protocol):
         ...
 
 
-class _IGitHubRepositoryProxy(jsii.proxy_for(_IResource_72f7ee7e)):
+class _IGitHubRepositoryProxy(
+    jsii.proxy_for(_IResource_72f7ee7e) # type: ignore
+):
     """GitHubRepository resource interface.
 
     stability
     :stability: experimental
     """
 
-    __jsii_type__ = "monocdk-experiment.aws_codestar.IGitHubRepository"
+    __jsii_type__: typing.ClassVar[str] = "monocdk-experiment.aws_codestar.IGitHubRepository"
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="owner")
-    def owner(self) -> str:
+    def owner(self) -> builtins.str:
         """the repository owner.
 
         stability
@@ -684,9 +728,9 @@ class _IGitHubRepositoryProxy(jsii.proxy_for(_IResource_72f7ee7e)):
         """
         return jsii.get(self, "owner")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="repo")
-    def repo(self) -> str:
+    def repo(self) -> builtins.str:
         """the repository name.
 
         stability
@@ -732,16 +776,16 @@ class GitHubRepository(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         access_token: _SecretValue_99478b8b,
         contents_bucket: _IBucket_25bad983,
-        contents_key: str,
-        owner: str,
-        repository_name: str,
-        contents_s3_version: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
-        enable_issues: typing.Optional[bool] = None,
+        contents_key: builtins.str,
+        owner: builtins.str,
+        repository_name: builtins.str,
+        contents_s3_version: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
+        enable_issues: typing.Optional[builtins.bool] = None,
         visibility: typing.Optional["RepositoryVisibility"] = None,
     ) -> None:
         """
@@ -774,9 +818,9 @@ class GitHubRepository(
 
         jsii.create(GitHubRepository, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="owner")
-    def owner(self) -> str:
+    def owner(self) -> builtins.str:
         """the repository owner.
 
         stability
@@ -784,9 +828,9 @@ class GitHubRepository(
         """
         return jsii.get(self, "owner")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="repo")
-    def repo(self) -> str:
+    def repo(self) -> builtins.str:
         """the repository name.
 
         stability
