@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -37,20 +37,20 @@ class CfnCluster(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        iam_role_arn: str,
-        node_type: str,
+        iam_role_arn: builtins.str,
+        node_type: builtins.str,
         replication_factor: jsii.Number,
-        availability_zones: typing.Optional[typing.List[str]] = None,
-        cluster_name: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
-        notification_topic_arn: typing.Optional[str] = None,
-        parameter_group_name: typing.Optional[str] = None,
-        preferred_maintenance_window: typing.Optional[str] = None,
-        security_group_ids: typing.Optional[typing.List[str]] = None,
+        availability_zones: typing.Optional[typing.List[builtins.str]] = None,
+        cluster_name: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
+        notification_topic_arn: typing.Optional[builtins.str] = None,
+        parameter_group_name: typing.Optional[builtins.str] = None,
+        preferred_maintenance_window: typing.Optional[builtins.str] = None,
+        security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
         sse_specification: typing.Optional[typing.Union["SSESpecificationProperty", _IResolvable_9ceae33e]] = None,
-        subnet_group_name: typing.Optional[str] = None,
+        subnet_group_name: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
         """Create a new ``AWS::DAX::Cluster``.
@@ -102,43 +102,44 @@ class CfnCluster(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrClusterDiscoveryEndpoint")
-    def attr_cluster_discovery_endpoint(self) -> str:
+    def attr_cluster_discovery_endpoint(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: ClusterDiscoveryEndpoint
         """
         return jsii.get(self, "attrClusterDiscoveryEndpoint")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::DAX::Cluster.Tags``.
@@ -148,9 +149,9 @@ class CfnCluster(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="iamRoleArn")
-    def iam_role_arn(self) -> str:
+    def iam_role_arn(self) -> builtins.str:
         """``AWS::DAX::Cluster.IAMRoleARN``.
 
         see
@@ -158,13 +159,13 @@ class CfnCluster(
         """
         return jsii.get(self, "iamRoleArn")
 
-    @iam_role_arn.setter
-    def iam_role_arn(self, value: str) -> None:
+    @iam_role_arn.setter # type: ignore
+    def iam_role_arn(self, value: builtins.str) -> None:
         jsii.set(self, "iamRoleArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="nodeType")
-    def node_type(self) -> str:
+    def node_type(self) -> builtins.str:
         """``AWS::DAX::Cluster.NodeType``.
 
         see
@@ -172,11 +173,11 @@ class CfnCluster(
         """
         return jsii.get(self, "nodeType")
 
-    @node_type.setter
-    def node_type(self, value: str) -> None:
+    @node_type.setter # type: ignore
+    def node_type(self, value: builtins.str) -> None:
         jsii.set(self, "nodeType", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="replicationFactor")
     def replication_factor(self) -> jsii.Number:
         """``AWS::DAX::Cluster.ReplicationFactor``.
@@ -186,13 +187,13 @@ class CfnCluster(
         """
         return jsii.get(self, "replicationFactor")
 
-    @replication_factor.setter
+    @replication_factor.setter # type: ignore
     def replication_factor(self, value: jsii.Number) -> None:
         jsii.set(self, "replicationFactor", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="availabilityZones")
-    def availability_zones(self) -> typing.Optional[typing.List[str]]:
+    def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.AvailabilityZones``.
 
         see
@@ -200,13 +201,16 @@ class CfnCluster(
         """
         return jsii.get(self, "availabilityZones")
 
-    @availability_zones.setter
-    def availability_zones(self, value: typing.Optional[typing.List[str]]) -> None:
+    @availability_zones.setter # type: ignore
+    def availability_zones(
+        self,
+        value: typing.Optional[typing.List[builtins.str]],
+    ) -> None:
         jsii.set(self, "availabilityZones", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="clusterName")
-    def cluster_name(self) -> typing.Optional[str]:
+    def cluster_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ClusterName``.
 
         see
@@ -214,13 +218,13 @@ class CfnCluster(
         """
         return jsii.get(self, "clusterName")
 
-    @cluster_name.setter
-    def cluster_name(self, value: typing.Optional[str]) -> None:
+    @cluster_name.setter # type: ignore
+    def cluster_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "clusterName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.Description``.
 
         see
@@ -228,13 +232,13 @@ class CfnCluster(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="notificationTopicArn")
-    def notification_topic_arn(self) -> typing.Optional[str]:
+    def notification_topic_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.NotificationTopicARN``.
 
         see
@@ -242,13 +246,13 @@ class CfnCluster(
         """
         return jsii.get(self, "notificationTopicArn")
 
-    @notification_topic_arn.setter
-    def notification_topic_arn(self, value: typing.Optional[str]) -> None:
+    @notification_topic_arn.setter # type: ignore
+    def notification_topic_arn(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "notificationTopicArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="parameterGroupName")
-    def parameter_group_name(self) -> typing.Optional[str]:
+    def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ParameterGroupName``.
 
         see
@@ -256,13 +260,13 @@ class CfnCluster(
         """
         return jsii.get(self, "parameterGroupName")
 
-    @parameter_group_name.setter
-    def parameter_group_name(self, value: typing.Optional[str]) -> None:
+    @parameter_group_name.setter # type: ignore
+    def parameter_group_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "parameterGroupName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="preferredMaintenanceWindow")
-    def preferred_maintenance_window(self) -> typing.Optional[str]:
+    def preferred_maintenance_window(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.PreferredMaintenanceWindow``.
 
         see
@@ -270,13 +274,16 @@ class CfnCluster(
         """
         return jsii.get(self, "preferredMaintenanceWindow")
 
-    @preferred_maintenance_window.setter
-    def preferred_maintenance_window(self, value: typing.Optional[str]) -> None:
+    @preferred_maintenance_window.setter # type: ignore
+    def preferred_maintenance_window(
+        self,
+        value: typing.Optional[builtins.str],
+    ) -> None:
         jsii.set(self, "preferredMaintenanceWindow", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="securityGroupIds")
-    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
+    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.SecurityGroupIds``.
 
         see
@@ -284,11 +291,14 @@ class CfnCluster(
         """
         return jsii.get(self, "securityGroupIds")
 
-    @security_group_ids.setter
-    def security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
+    @security_group_ids.setter # type: ignore
+    def security_group_ids(
+        self,
+        value: typing.Optional[typing.List[builtins.str]],
+    ) -> None:
         jsii.set(self, "securityGroupIds", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="sseSpecification")
     def sse_specification(
         self,
@@ -300,16 +310,16 @@ class CfnCluster(
         """
         return jsii.get(self, "sseSpecification")
 
-    @sse_specification.setter
+    @sse_specification.setter # type: ignore
     def sse_specification(
         self,
         value: typing.Optional[typing.Union["SSESpecificationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "sseSpecification", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="subnetGroupName")
-    def subnet_group_name(self) -> typing.Optional[str]:
+    def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.SubnetGroupName``.
 
         see
@@ -317,8 +327,8 @@ class CfnCluster(
         """
         return jsii.get(self, "subnetGroupName")
 
-    @subnet_group_name.setter
-    def subnet_group_name(self, value: typing.Optional[str]) -> None:
+    @subnet_group_name.setter # type: ignore
+    def subnet_group_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "subnetGroupName", value)
 
     @jsii.data_type(
@@ -330,7 +340,7 @@ class CfnCluster(
         def __init__(
             self,
             *,
-            sse_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            sse_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param sse_enabled: ``CfnCluster.SSESpecificationProperty.SSEEnabled``.
@@ -338,25 +348,26 @@ class CfnCluster(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dax-cluster-ssespecification.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if sse_enabled is not None:
                 self._values["sse_enabled"] = sse_enabled
 
         @builtins.property
         def sse_enabled(
             self,
-        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
             """``CfnCluster.SSESpecificationProperty.SSEEnabled``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dax-cluster-ssespecification.html#cfn-dax-cluster-ssespecification-sseenabled
             """
-            return self._values.get("sse_enabled")
+            result = self._values.get("sse_enabled")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -388,18 +399,18 @@ class CfnClusterProps:
     def __init__(
         self,
         *,
-        iam_role_arn: str,
-        node_type: str,
+        iam_role_arn: builtins.str,
+        node_type: builtins.str,
         replication_factor: jsii.Number,
-        availability_zones: typing.Optional[typing.List[str]] = None,
-        cluster_name: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
-        notification_topic_arn: typing.Optional[str] = None,
-        parameter_group_name: typing.Optional[str] = None,
-        preferred_maintenance_window: typing.Optional[str] = None,
-        security_group_ids: typing.Optional[typing.List[str]] = None,
+        availability_zones: typing.Optional[typing.List[builtins.str]] = None,
+        cluster_name: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
+        notification_topic_arn: typing.Optional[builtins.str] = None,
+        parameter_group_name: typing.Optional[builtins.str] = None,
+        preferred_maintenance_window: typing.Optional[builtins.str] = None,
+        security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
         sse_specification: typing.Optional[typing.Union["CfnCluster.SSESpecificationProperty", _IResolvable_9ceae33e]] = None,
-        subnet_group_name: typing.Optional[str] = None,
+        subnet_group_name: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
         """Properties for defining a ``AWS::DAX::Cluster``.
@@ -421,7 +432,7 @@ class CfnClusterProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "iam_role_arn": iam_role_arn,
             "node_type": node_type,
             "replication_factor": replication_factor,
@@ -448,22 +459,26 @@ class CfnClusterProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def iam_role_arn(self) -> str:
+    def iam_role_arn(self) -> builtins.str:
         """``AWS::DAX::Cluster.IAMRoleARN``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-iamrolearn
         """
-        return self._values.get("iam_role_arn")
+        result = self._values.get("iam_role_arn")
+        assert result is not None, "Required property 'iam_role_arn' is missing"
+        return result
 
     @builtins.property
-    def node_type(self) -> str:
+    def node_type(self) -> builtins.str:
         """``AWS::DAX::Cluster.NodeType``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-nodetype
         """
-        return self._values.get("node_type")
+        result = self._values.get("node_type")
+        assert result is not None, "Required property 'node_type' is missing"
+        return result
 
     @builtins.property
     def replication_factor(self) -> jsii.Number:
@@ -472,70 +487,79 @@ class CfnClusterProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-replicationfactor
         """
-        return self._values.get("replication_factor")
+        result = self._values.get("replication_factor")
+        assert result is not None, "Required property 'replication_factor' is missing"
+        return result
 
     @builtins.property
-    def availability_zones(self) -> typing.Optional[typing.List[str]]:
+    def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.AvailabilityZones``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-availabilityzones
         """
-        return self._values.get("availability_zones")
+        result = self._values.get("availability_zones")
+        return result
 
     @builtins.property
-    def cluster_name(self) -> typing.Optional[str]:
+    def cluster_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ClusterName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-clustername
         """
-        return self._values.get("cluster_name")
+        result = self._values.get("cluster_name")
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def notification_topic_arn(self) -> typing.Optional[str]:
+    def notification_topic_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.NotificationTopicARN``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-notificationtopicarn
         """
-        return self._values.get("notification_topic_arn")
+        result = self._values.get("notification_topic_arn")
+        return result
 
     @builtins.property
-    def parameter_group_name(self) -> typing.Optional[str]:
+    def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ParameterGroupName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-parametergroupname
         """
-        return self._values.get("parameter_group_name")
+        result = self._values.get("parameter_group_name")
+        return result
 
     @builtins.property
-    def preferred_maintenance_window(self) -> typing.Optional[str]:
+    def preferred_maintenance_window(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.PreferredMaintenanceWindow``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-preferredmaintenancewindow
         """
-        return self._values.get("preferred_maintenance_window")
+        result = self._values.get("preferred_maintenance_window")
+        return result
 
     @builtins.property
-    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
+    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.SecurityGroupIds``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-securitygroupids
         """
-        return self._values.get("security_group_ids")
+        result = self._values.get("security_group_ids")
+        return result
 
     @builtins.property
     def sse_specification(
@@ -546,16 +570,18 @@ class CfnClusterProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-ssespecification
         """
-        return self._values.get("sse_specification")
+        result = self._values.get("sse_specification")
+        return result
 
     @builtins.property
-    def subnet_group_name(self) -> typing.Optional[str]:
+    def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.SubnetGroupName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-subnetgroupname
         """
-        return self._values.get("subnet_group_name")
+        result = self._values.get("subnet_group_name")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Any:
@@ -564,12 +590,13 @@ class CfnClusterProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -595,10 +622,10 @@ class CfnParameterGroup(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        description: typing.Optional[str] = None,
-        parameter_group_name: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        parameter_group_name: typing.Optional[builtins.str] = None,
         parameter_name_values: typing.Any = None,
     ) -> None:
         """Create a new ``AWS::DAX::ParameterGroup``.
@@ -630,25 +657,26 @@ class CfnParameterGroup(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="parameterNameValues")
     def parameter_name_values(self) -> typing.Any:
         """``AWS::DAX::ParameterGroup.ParameterNameValues``.
@@ -658,13 +686,13 @@ class CfnParameterGroup(
         """
         return jsii.get(self, "parameterNameValues")
 
-    @parameter_name_values.setter
+    @parameter_name_values.setter # type: ignore
     def parameter_name_values(self, value: typing.Any) -> None:
         jsii.set(self, "parameterNameValues", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.Description``.
 
         see
@@ -672,13 +700,13 @@ class CfnParameterGroup(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="parameterGroupName")
-    def parameter_group_name(self) -> typing.Optional[str]:
+    def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.ParameterGroupName``.
 
         see
@@ -686,8 +714,8 @@ class CfnParameterGroup(
         """
         return jsii.get(self, "parameterGroupName")
 
-    @parameter_group_name.setter
-    def parameter_group_name(self, value: typing.Optional[str]) -> None:
+    @parameter_group_name.setter # type: ignore
+    def parameter_group_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "parameterGroupName", value)
 
 
@@ -704,8 +732,8 @@ class CfnParameterGroupProps:
     def __init__(
         self,
         *,
-        description: typing.Optional[str] = None,
-        parameter_group_name: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        parameter_group_name: typing.Optional[builtins.str] = None,
         parameter_name_values: typing.Any = None,
     ) -> None:
         """Properties for defining a ``AWS::DAX::ParameterGroup``.
@@ -717,7 +745,7 @@ class CfnParameterGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if description is not None:
             self._values["description"] = description
         if parameter_group_name is not None:
@@ -726,22 +754,24 @@ class CfnParameterGroupProps:
             self._values["parameter_name_values"] = parameter_name_values
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def parameter_group_name(self) -> typing.Optional[str]:
+    def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.ParameterGroupName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parametergroupname
         """
-        return self._values.get("parameter_group_name")
+        result = self._values.get("parameter_group_name")
+        return result
 
     @builtins.property
     def parameter_name_values(self) -> typing.Any:
@@ -750,12 +780,13 @@ class CfnParameterGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parameternamevalues
         """
-        return self._values.get("parameter_name_values")
+        result = self._values.get("parameter_name_values")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -781,11 +812,11 @@ class CfnSubnetGroup(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        subnet_ids: typing.List[str],
-        description: typing.Optional[str] = None,
-        subnet_group_name: typing.Optional[str] = None,
+        subnet_ids: typing.List[builtins.str],
+        description: typing.Optional[builtins.str] = None,
+        subnet_group_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::DAX::SubnetGroup``.
 
@@ -816,27 +847,28 @@ class CfnSubnetGroup(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="subnetIds")
-    def subnet_ids(self) -> typing.List[str]:
+    def subnet_ids(self) -> typing.List[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetIds``.
 
         see
@@ -844,13 +876,13 @@ class CfnSubnetGroup(
         """
         return jsii.get(self, "subnetIds")
 
-    @subnet_ids.setter
-    def subnet_ids(self, value: typing.List[str]) -> None:
+    @subnet_ids.setter # type: ignore
+    def subnet_ids(self, value: typing.List[builtins.str]) -> None:
         jsii.set(self, "subnetIds", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.Description``.
 
         see
@@ -858,13 +890,13 @@ class CfnSubnetGroup(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="subnetGroupName")
-    def subnet_group_name(self) -> typing.Optional[str]:
+    def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetGroupName``.
 
         see
@@ -872,8 +904,8 @@ class CfnSubnetGroup(
         """
         return jsii.get(self, "subnetGroupName")
 
-    @subnet_group_name.setter
-    def subnet_group_name(self, value: typing.Optional[str]) -> None:
+    @subnet_group_name.setter # type: ignore
+    def subnet_group_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "subnetGroupName", value)
 
 
@@ -890,9 +922,9 @@ class CfnSubnetGroupProps:
     def __init__(
         self,
         *,
-        subnet_ids: typing.List[str],
-        description: typing.Optional[str] = None,
-        subnet_group_name: typing.Optional[str] = None,
+        subnet_ids: typing.List[builtins.str],
+        description: typing.Optional[builtins.str] = None,
+        subnet_group_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::DAX::SubnetGroup``.
 
@@ -903,7 +935,7 @@ class CfnSubnetGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "subnet_ids": subnet_ids,
         }
         if description is not None:
@@ -912,36 +944,40 @@ class CfnSubnetGroupProps:
             self._values["subnet_group_name"] = subnet_group_name
 
     @builtins.property
-    def subnet_ids(self) -> typing.List[str]:
+    def subnet_ids(self) -> typing.List[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetIds``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetids
         """
-        return self._values.get("subnet_ids")
+        result = self._values.get("subnet_ids")
+        assert result is not None, "Required property 'subnet_ids' is missing"
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def subnet_group_name(self) -> typing.Optional[str]:
+    def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetGroupName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetgroupname
         """
-        return self._values.get("subnet_group_name")
+        result = self._values.get("subnet_group_name")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
