@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,10 +36,10 @@ class CfnDiscoverer(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        source_arn: str,
-        description: typing.Optional[str] = None,
+        source_arn: builtins.str,
+        description: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List["TagsEntryProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::EventSchemas::Discoverer``.
@@ -69,43 +69,44 @@ class CfnDiscoverer(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrDiscovererArn")
-    def attr_discoverer_arn(self) -> str:
+    def attr_discoverer_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: DiscovererArn
         """
         return jsii.get(self, "attrDiscovererArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrDiscovererId")
-    def attr_discoverer_id(self) -> str:
+    def attr_discoverer_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: DiscovererId
         """
         return jsii.get(self, "attrDiscovererId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::EventSchemas::Discoverer.Tags``.
@@ -115,9 +116,9 @@ class CfnDiscoverer(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="sourceArn")
-    def source_arn(self) -> str:
+    def source_arn(self) -> builtins.str:
         """``AWS::EventSchemas::Discoverer.SourceArn``.
 
         see
@@ -125,13 +126,13 @@ class CfnDiscoverer(
         """
         return jsii.get(self, "sourceArn")
 
-    @source_arn.setter
-    def source_arn(self, value: str) -> None:
+    @source_arn.setter # type: ignore
+    def source_arn(self, value: builtins.str) -> None:
         jsii.set(self, "sourceArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Discoverer.Description``.
 
         see
@@ -139,8 +140,8 @@ class CfnDiscoverer(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
     @jsii.data_type(
@@ -149,7 +150,7 @@ class CfnDiscoverer(
         name_mapping={"key": "key", "value": "value"},
     )
     class TagsEntryProperty:
-        def __init__(self, *, key: str, value: str) -> None:
+        def __init__(self, *, key: builtins.str, value: builtins.str) -> None:
             """
             :param key: ``CfnDiscoverer.TagsEntryProperty.Key``.
             :param value: ``CfnDiscoverer.TagsEntryProperty.Value``.
@@ -157,33 +158,37 @@ class CfnDiscoverer(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-discoverer-tagsentry.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
                 "value": value,
             }
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnDiscoverer.TagsEntryProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-discoverer-tagsentry.html#cfn-eventschemas-discoverer-tagsentry-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def value(self) -> str:
+        def value(self) -> builtins.str:
             """``CfnDiscoverer.TagsEntryProperty.Value``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-discoverer-tagsentry.html#cfn-eventschemas-discoverer-tagsentry-value
             """
-            return self._values.get("value")
+            result = self._values.get("value")
+            assert result is not None, "Required property 'value' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -205,8 +210,8 @@ class CfnDiscovererProps:
     def __init__(
         self,
         *,
-        source_arn: str,
-        description: typing.Optional[str] = None,
+        source_arn: builtins.str,
+        description: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List["CfnDiscoverer.TagsEntryProperty"]] = None,
     ) -> None:
         """Properties for defining a ``AWS::EventSchemas::Discoverer``.
@@ -218,7 +223,7 @@ class CfnDiscovererProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "source_arn": source_arn,
         }
         if description is not None:
@@ -227,22 +232,25 @@ class CfnDiscovererProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def source_arn(self) -> str:
+    def source_arn(self) -> builtins.str:
         """``AWS::EventSchemas::Discoverer.SourceArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-sourcearn
         """
-        return self._values.get("source_arn")
+        result = self._values.get("source_arn")
+        assert result is not None, "Required property 'source_arn' is missing"
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Discoverer.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List["CfnDiscoverer.TagsEntryProperty"]]:
@@ -251,12 +259,13 @@ class CfnDiscovererProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -282,10 +291,10 @@ class CfnRegistry(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        description: typing.Optional[str] = None,
-        registry_name: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        registry_name: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List["TagsEntryProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::EventSchemas::Registry``.
@@ -315,43 +324,44 @@ class CfnRegistry(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrRegistryArn")
-    def attr_registry_arn(self) -> str:
+    def attr_registry_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: RegistryArn
         """
         return jsii.get(self, "attrRegistryArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrRegistryName")
-    def attr_registry_name(self) -> str:
+    def attr_registry_name(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: RegistryName
         """
         return jsii.get(self, "attrRegistryName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::EventSchemas::Registry.Tags``.
@@ -361,9 +371,9 @@ class CfnRegistry(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Registry.Description``.
 
         see
@@ -371,13 +381,13 @@ class CfnRegistry(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="registryName")
-    def registry_name(self) -> typing.Optional[str]:
+    def registry_name(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Registry.RegistryName``.
 
         see
@@ -385,8 +395,8 @@ class CfnRegistry(
         """
         return jsii.get(self, "registryName")
 
-    @registry_name.setter
-    def registry_name(self, value: typing.Optional[str]) -> None:
+    @registry_name.setter # type: ignore
+    def registry_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "registryName", value)
 
     @jsii.data_type(
@@ -395,7 +405,7 @@ class CfnRegistry(
         name_mapping={"key": "key", "value": "value"},
     )
     class TagsEntryProperty:
-        def __init__(self, *, key: str, value: str) -> None:
+        def __init__(self, *, key: builtins.str, value: builtins.str) -> None:
             """
             :param key: ``CfnRegistry.TagsEntryProperty.Key``.
             :param value: ``CfnRegistry.TagsEntryProperty.Value``.
@@ -403,33 +413,37 @@ class CfnRegistry(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-registry-tagsentry.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
                 "value": value,
             }
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnRegistry.TagsEntryProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-registry-tagsentry.html#cfn-eventschemas-registry-tagsentry-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def value(self) -> str:
+        def value(self) -> builtins.str:
             """``CfnRegistry.TagsEntryProperty.Value``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-registry-tagsentry.html#cfn-eventschemas-registry-tagsentry-value
             """
-            return self._values.get("value")
+            result = self._values.get("value")
+            assert result is not None, "Required property 'value' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -455,11 +469,11 @@ class CfnRegistryPolicy(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         policy: typing.Any,
-        registry_name: str,
-        revision_id: typing.Optional[str] = None,
+        registry_name: builtins.str,
+        revision_id: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::EventSchemas::RegistryPolicy``.
 
@@ -488,34 +502,35 @@ class CfnRegistryPolicy(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrId")
-    def attr_id(self) -> str:
+    def attr_id(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Id
         """
         return jsii.get(self, "attrId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="policy")
     def policy(self) -> typing.Any:
         """``AWS::EventSchemas::RegistryPolicy.Policy``.
@@ -525,13 +540,13 @@ class CfnRegistryPolicy(
         """
         return jsii.get(self, "policy")
 
-    @policy.setter
+    @policy.setter # type: ignore
     def policy(self, value: typing.Any) -> None:
         jsii.set(self, "policy", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="registryName")
-    def registry_name(self) -> str:
+    def registry_name(self) -> builtins.str:
         """``AWS::EventSchemas::RegistryPolicy.RegistryName``.
 
         see
@@ -539,13 +554,13 @@ class CfnRegistryPolicy(
         """
         return jsii.get(self, "registryName")
 
-    @registry_name.setter
-    def registry_name(self, value: str) -> None:
+    @registry_name.setter # type: ignore
+    def registry_name(self, value: builtins.str) -> None:
         jsii.set(self, "registryName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="revisionId")
-    def revision_id(self) -> typing.Optional[str]:
+    def revision_id(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::RegistryPolicy.RevisionId``.
 
         see
@@ -553,8 +568,8 @@ class CfnRegistryPolicy(
         """
         return jsii.get(self, "revisionId")
 
-    @revision_id.setter
-    def revision_id(self, value: typing.Optional[str]) -> None:
+    @revision_id.setter # type: ignore
+    def revision_id(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "revisionId", value)
 
 
@@ -572,8 +587,8 @@ class CfnRegistryPolicyProps:
         self,
         *,
         policy: typing.Any,
-        registry_name: str,
-        revision_id: typing.Optional[str] = None,
+        registry_name: builtins.str,
+        revision_id: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::EventSchemas::RegistryPolicy``.
 
@@ -584,7 +599,7 @@ class CfnRegistryPolicyProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "policy": policy,
             "registry_name": registry_name,
         }
@@ -598,30 +613,35 @@ class CfnRegistryPolicyProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-policy
         """
-        return self._values.get("policy")
+        result = self._values.get("policy")
+        assert result is not None, "Required property 'policy' is missing"
+        return result
 
     @builtins.property
-    def registry_name(self) -> str:
+    def registry_name(self) -> builtins.str:
         """``AWS::EventSchemas::RegistryPolicy.RegistryName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-registryname
         """
-        return self._values.get("registry_name")
+        result = self._values.get("registry_name")
+        assert result is not None, "Required property 'registry_name' is missing"
+        return result
 
     @builtins.property
-    def revision_id(self) -> typing.Optional[str]:
+    def revision_id(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::RegistryPolicy.RevisionId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-revisionid
         """
-        return self._values.get("revision_id")
+        result = self._values.get("revision_id")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -643,8 +663,8 @@ class CfnRegistryProps:
     def __init__(
         self,
         *,
-        description: typing.Optional[str] = None,
-        registry_name: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        registry_name: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List["CfnRegistry.TagsEntryProperty"]] = None,
     ) -> None:
         """Properties for defining a ``AWS::EventSchemas::Registry``.
@@ -656,7 +676,7 @@ class CfnRegistryProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if description is not None:
             self._values["description"] = description
         if registry_name is not None:
@@ -665,22 +685,24 @@ class CfnRegistryProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Registry.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def registry_name(self) -> typing.Optional[str]:
+    def registry_name(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Registry.RegistryName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-registryname
         """
-        return self._values.get("registry_name")
+        result = self._values.get("registry_name")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List["CfnRegistry.TagsEntryProperty"]]:
@@ -689,12 +711,13 @@ class CfnRegistryProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -720,13 +743,13 @@ class CfnSchema(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        content: str,
-        registry_name: str,
-        type: str,
-        description: typing.Optional[str] = None,
-        schema_name: typing.Optional[str] = None,
+        content: builtins.str,
+        registry_name: builtins.str,
+        type: builtins.str,
+        description: typing.Optional[builtins.str] = None,
+        schema_name: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List["TagsEntryProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::EventSchemas::Schema``.
@@ -764,52 +787,53 @@ class CfnSchema(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrSchemaArn")
-    def attr_schema_arn(self) -> str:
+    def attr_schema_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: SchemaArn
         """
         return jsii.get(self, "attrSchemaArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrSchemaName")
-    def attr_schema_name(self) -> str:
+    def attr_schema_name(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: SchemaName
         """
         return jsii.get(self, "attrSchemaName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrSchemaVersion")
-    def attr_schema_version(self) -> str:
+    def attr_schema_version(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: SchemaVersion
         """
         return jsii.get(self, "attrSchemaVersion")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::EventSchemas::Schema.Tags``.
@@ -819,9 +843,9 @@ class CfnSchema(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="content")
-    def content(self) -> str:
+    def content(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.Content``.
 
         see
@@ -829,13 +853,13 @@ class CfnSchema(
         """
         return jsii.get(self, "content")
 
-    @content.setter
-    def content(self, value: str) -> None:
+    @content.setter # type: ignore
+    def content(self, value: builtins.str) -> None:
         jsii.set(self, "content", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="registryName")
-    def registry_name(self) -> str:
+    def registry_name(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.RegistryName``.
 
         see
@@ -843,13 +867,13 @@ class CfnSchema(
         """
         return jsii.get(self, "registryName")
 
-    @registry_name.setter
-    def registry_name(self, value: str) -> None:
+    @registry_name.setter # type: ignore
+    def registry_name(self, value: builtins.str) -> None:
         jsii.set(self, "registryName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="type")
-    def type(self) -> str:
+    def type(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.Type``.
 
         see
@@ -857,13 +881,13 @@ class CfnSchema(
         """
         return jsii.get(self, "type")
 
-    @type.setter
-    def type(self, value: str) -> None:
+    @type.setter # type: ignore
+    def type(self, value: builtins.str) -> None:
         jsii.set(self, "type", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Schema.Description``.
 
         see
@@ -871,13 +895,13 @@ class CfnSchema(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="schemaName")
-    def schema_name(self) -> typing.Optional[str]:
+    def schema_name(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Schema.SchemaName``.
 
         see
@@ -885,8 +909,8 @@ class CfnSchema(
         """
         return jsii.get(self, "schemaName")
 
-    @schema_name.setter
-    def schema_name(self, value: typing.Optional[str]) -> None:
+    @schema_name.setter # type: ignore
+    def schema_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "schemaName", value)
 
     @jsii.data_type(
@@ -895,7 +919,7 @@ class CfnSchema(
         name_mapping={"key": "key", "value": "value"},
     )
     class TagsEntryProperty:
-        def __init__(self, *, key: str, value: str) -> None:
+        def __init__(self, *, key: builtins.str, value: builtins.str) -> None:
             """
             :param key: ``CfnSchema.TagsEntryProperty.Key``.
             :param value: ``CfnSchema.TagsEntryProperty.Value``.
@@ -903,33 +927,37 @@ class CfnSchema(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-schema-tagsentry.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
                 "value": value,
             }
 
         @builtins.property
-        def key(self) -> str:
+        def key(self) -> builtins.str:
             """``CfnSchema.TagsEntryProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-schema-tagsentry.html#cfn-eventschemas-schema-tagsentry-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return result
 
         @builtins.property
-        def value(self) -> str:
+        def value(self) -> builtins.str:
             """``CfnSchema.TagsEntryProperty.Value``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-schema-tagsentry.html#cfn-eventschemas-schema-tagsentry-value
             """
-            return self._values.get("value")
+            result = self._values.get("value")
+            assert result is not None, "Required property 'value' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -954,11 +982,11 @@ class CfnSchemaProps:
     def __init__(
         self,
         *,
-        content: str,
-        registry_name: str,
-        type: str,
-        description: typing.Optional[str] = None,
-        schema_name: typing.Optional[str] = None,
+        content: builtins.str,
+        registry_name: builtins.str,
+        type: builtins.str,
+        description: typing.Optional[builtins.str] = None,
+        schema_name: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.List["CfnSchema.TagsEntryProperty"]] = None,
     ) -> None:
         """Properties for defining a ``AWS::EventSchemas::Schema``.
@@ -973,7 +1001,7 @@ class CfnSchemaProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "content": content,
             "registry_name": registry_name,
             "type": type,
@@ -986,49 +1014,57 @@ class CfnSchemaProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def content(self) -> str:
+    def content(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.Content``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-content
         """
-        return self._values.get("content")
+        result = self._values.get("content")
+        assert result is not None, "Required property 'content' is missing"
+        return result
 
     @builtins.property
-    def registry_name(self) -> str:
+    def registry_name(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.RegistryName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-registryname
         """
-        return self._values.get("registry_name")
+        result = self._values.get("registry_name")
+        assert result is not None, "Required property 'registry_name' is missing"
+        return result
 
     @builtins.property
-    def type(self) -> str:
+    def type(self) -> builtins.str:
         """``AWS::EventSchemas::Schema.Type``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-type
         """
-        return self._values.get("type")
+        result = self._values.get("type")
+        assert result is not None, "Required property 'type' is missing"
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Schema.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def schema_name(self) -> typing.Optional[str]:
+    def schema_name(self) -> typing.Optional[builtins.str]:
         """``AWS::EventSchemas::Schema.SchemaName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-schemaname
         """
-        return self._values.get("schema_name")
+        result = self._values.get("schema_name")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List["CfnSchema.TagsEntryProperty"]]:
@@ -1037,12 +1073,13 @@ class CfnSchemaProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
