@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -43,10 +43,10 @@ class CfnStream(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         shard_count: jsii.Number,
-        name: typing.Optional[str] = None,
+        name: typing.Optional[builtins.str] = None,
         retention_period_hours: typing.Optional[jsii.Number] = None,
         stream_encryption: typing.Optional[typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
@@ -84,34 +84,35 @@ class CfnStream(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::Kinesis::Stream.Tags``.
@@ -121,7 +122,7 @@ class CfnStream(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="shardCount")
     def shard_count(self) -> jsii.Number:
         """``AWS::Kinesis::Stream.ShardCount``.
@@ -131,13 +132,13 @@ class CfnStream(
         """
         return jsii.get(self, "shardCount")
 
-    @shard_count.setter
+    @shard_count.setter # type: ignore
     def shard_count(self, value: jsii.Number) -> None:
         jsii.set(self, "shardCount", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Kinesis::Stream.Name``.
 
         see
@@ -145,11 +146,11 @@ class CfnStream(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: typing.Optional[str]) -> None:
+    @name.setter # type: ignore
+    def name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="retentionPeriodHours")
     def retention_period_hours(self) -> typing.Optional[jsii.Number]:
         """``AWS::Kinesis::Stream.RetentionPeriodHours``.
@@ -159,11 +160,11 @@ class CfnStream(
         """
         return jsii.get(self, "retentionPeriodHours")
 
-    @retention_period_hours.setter
+    @retention_period_hours.setter # type: ignore
     def retention_period_hours(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "retentionPeriodHours", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="streamEncryption")
     def stream_encryption(
         self,
@@ -175,7 +176,7 @@ class CfnStream(
         """
         return jsii.get(self, "streamEncryption")
 
-    @stream_encryption.setter
+    @stream_encryption.setter # type: ignore
     def stream_encryption(
         self,
         value: typing.Optional[typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]],
@@ -188,7 +189,12 @@ class CfnStream(
         name_mapping={"encryption_type": "encryptionType", "key_id": "keyId"},
     )
     class StreamEncryptionProperty:
-        def __init__(self, *, encryption_type: str, key_id: str) -> None:
+        def __init__(
+            self,
+            *,
+            encryption_type: builtins.str,
+            key_id: builtins.str,
+        ) -> None:
             """
             :param encryption_type: ``CfnStream.StreamEncryptionProperty.EncryptionType``.
             :param key_id: ``CfnStream.StreamEncryptionProperty.KeyId``.
@@ -196,33 +202,37 @@ class CfnStream(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesis-stream-streamencryption.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "encryption_type": encryption_type,
                 "key_id": key_id,
             }
 
         @builtins.property
-        def encryption_type(self) -> str:
+        def encryption_type(self) -> builtins.str:
             """``CfnStream.StreamEncryptionProperty.EncryptionType``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesis-stream-streamencryption.html#cfn-kinesis-stream-streamencryption-encryptiontype
             """
-            return self._values.get("encryption_type")
+            result = self._values.get("encryption_type")
+            assert result is not None, "Required property 'encryption_type' is missing"
+            return result
 
         @builtins.property
-        def key_id(self) -> str:
+        def key_id(self) -> builtins.str:
             """``CfnStream.StreamEncryptionProperty.KeyId``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesis-stream-streamencryption.html#cfn-kinesis-stream-streamencryption-keyid
             """
-            return self._values.get("key_id")
+            result = self._values.get("key_id")
+            assert result is not None, "Required property 'key_id' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -248,10 +258,10 @@ class CfnStreamConsumer(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        consumer_name: str,
-        stream_arn: str,
+        consumer_name: builtins.str,
+        stream_arn: builtins.str,
     ) -> None:
         """Create a new ``AWS::Kinesis::StreamConsumer``.
 
@@ -279,72 +289,73 @@ class CfnStreamConsumer(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrConsumerArn")
-    def attr_consumer_arn(self) -> str:
+    def attr_consumer_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: ConsumerARN
         """
         return jsii.get(self, "attrConsumerArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrConsumerCreationTimestamp")
-    def attr_consumer_creation_timestamp(self) -> str:
+    def attr_consumer_creation_timestamp(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: ConsumerCreationTimestamp
         """
         return jsii.get(self, "attrConsumerCreationTimestamp")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrConsumerName")
-    def attr_consumer_name(self) -> str:
+    def attr_consumer_name(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: ConsumerName
         """
         return jsii.get(self, "attrConsumerName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrConsumerStatus")
-    def attr_consumer_status(self) -> str:
+    def attr_consumer_status(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: ConsumerStatus
         """
         return jsii.get(self, "attrConsumerStatus")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrStreamArn")
-    def attr_stream_arn(self) -> str:
+    def attr_stream_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: StreamARN
         """
         return jsii.get(self, "attrStreamArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="consumerName")
-    def consumer_name(self) -> str:
+    def consumer_name(self) -> builtins.str:
         """``AWS::Kinesis::StreamConsumer.ConsumerName``.
 
         see
@@ -352,13 +363,13 @@ class CfnStreamConsumer(
         """
         return jsii.get(self, "consumerName")
 
-    @consumer_name.setter
-    def consumer_name(self, value: str) -> None:
+    @consumer_name.setter # type: ignore
+    def consumer_name(self, value: builtins.str) -> None:
         jsii.set(self, "consumerName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="streamArn")
-    def stream_arn(self) -> str:
+    def stream_arn(self) -> builtins.str:
         """``AWS::Kinesis::StreamConsumer.StreamARN``.
 
         see
@@ -366,8 +377,8 @@ class CfnStreamConsumer(
         """
         return jsii.get(self, "streamArn")
 
-    @stream_arn.setter
-    def stream_arn(self, value: str) -> None:
+    @stream_arn.setter # type: ignore
+    def stream_arn(self, value: builtins.str) -> None:
         jsii.set(self, "streamArn", value)
 
 
@@ -377,7 +388,12 @@ class CfnStreamConsumer(
     name_mapping={"consumer_name": "consumerName", "stream_arn": "streamArn"},
 )
 class CfnStreamConsumerProps:
-    def __init__(self, *, consumer_name: str, stream_arn: str) -> None:
+    def __init__(
+        self,
+        *,
+        consumer_name: builtins.str,
+        stream_arn: builtins.str,
+    ) -> None:
         """Properties for defining a ``AWS::Kinesis::StreamConsumer``.
 
         :param consumer_name: ``AWS::Kinesis::StreamConsumer.ConsumerName``.
@@ -386,33 +402,37 @@ class CfnStreamConsumerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "consumer_name": consumer_name,
             "stream_arn": stream_arn,
         }
 
     @builtins.property
-    def consumer_name(self) -> str:
+    def consumer_name(self) -> builtins.str:
         """``AWS::Kinesis::StreamConsumer.ConsumerName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html#cfn-kinesis-streamconsumer-consumername
         """
-        return self._values.get("consumer_name")
+        result = self._values.get("consumer_name")
+        assert result is not None, "Required property 'consumer_name' is missing"
+        return result
 
     @builtins.property
-    def stream_arn(self) -> str:
+    def stream_arn(self) -> builtins.str:
         """``AWS::Kinesis::StreamConsumer.StreamARN``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html#cfn-kinesis-streamconsumer-streamarn
         """
-        return self._values.get("stream_arn")
+        result = self._values.get("stream_arn")
+        assert result is not None, "Required property 'stream_arn' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -437,7 +457,7 @@ class CfnStreamProps:
         self,
         *,
         shard_count: jsii.Number,
-        name: typing.Optional[str] = None,
+        name: typing.Optional[builtins.str] = None,
         retention_period_hours: typing.Optional[jsii.Number] = None,
         stream_encryption: typing.Optional[typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
@@ -453,7 +473,7 @@ class CfnStreamProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "shard_count": shard_count,
         }
         if name is not None:
@@ -472,16 +492,19 @@ class CfnStreamProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-shardcount
         """
-        return self._values.get("shard_count")
+        result = self._values.get("shard_count")
+        assert result is not None, "Required property 'shard_count' is missing"
+        return result
 
     @builtins.property
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::Kinesis::Stream.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        return result
 
     @builtins.property
     def retention_period_hours(self) -> typing.Optional[jsii.Number]:
@@ -490,7 +513,8 @@ class CfnStreamProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-retentionperiodhours
         """
-        return self._values.get("retention_period_hours")
+        result = self._values.get("retention_period_hours")
+        return result
 
     @builtins.property
     def stream_encryption(
@@ -501,7 +525,8 @@ class CfnStreamProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-streamencryption
         """
-        return self._values.get("stream_encryption")
+        result = self._values.get("stream_encryption")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -510,12 +535,13 @@ class CfnStreamProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -525,7 +551,7 @@ class CfnStreamProps:
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_kinesis.IStream")
-class IStream(_IResource_72f7ee7e, jsii.compat.Protocol):
+class IStream(_IResource_72f7ee7e, typing_extensions.Protocol):
     """A Kinesis Stream.
 
     stability
@@ -536,9 +562,9 @@ class IStream(_IResource_72f7ee7e, jsii.compat.Protocol):
     def __jsii_proxy_class__():
         return _IStreamProxy
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="streamArn")
-    def stream_arn(self) -> str:
+    def stream_arn(self) -> builtins.str:
         """The ARN of the stream.
 
         stability
@@ -548,9 +574,9 @@ class IStream(_IResource_72f7ee7e, jsii.compat.Protocol):
         """
         ...
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="streamName")
-    def stream_name(self) -> str:
+    def stream_name(self) -> builtins.str:
         """The name of the stream.
 
         stability
@@ -560,7 +586,7 @@ class IStream(_IResource_72f7ee7e, jsii.compat.Protocol):
         """
         ...
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="encryptionKey")
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
         """Optional KMS encryption key associated with this stream.
@@ -571,7 +597,11 @@ class IStream(_IResource_72f7ee7e, jsii.compat.Protocol):
         ...
 
     @jsii.member(jsii_name="grant")
-    def grant(self, grantee: _IGrantable_0fcfc53a, *actions: str) -> _Grant_96af6d2d:
+    def grant(
+        self,
+        grantee: _IGrantable_0fcfc53a,
+        *actions: builtins.str,
+    ) -> _Grant_96af6d2d:
         """Grant the indicated permissions on this stream to the provided IAM principal.
 
         :param grantee: -
@@ -625,18 +655,20 @@ class IStream(_IResource_72f7ee7e, jsii.compat.Protocol):
         ...
 
 
-class _IStreamProxy(jsii.proxy_for(_IResource_72f7ee7e)):
+class _IStreamProxy(
+    jsii.proxy_for(_IResource_72f7ee7e) # type: ignore
+):
     """A Kinesis Stream.
 
     stability
     :stability: experimental
     """
 
-    __jsii_type__ = "monocdk-experiment.aws_kinesis.IStream"
+    __jsii_type__: typing.ClassVar[str] = "monocdk-experiment.aws_kinesis.IStream"
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="streamArn")
-    def stream_arn(self) -> str:
+    def stream_arn(self) -> builtins.str:
         """The ARN of the stream.
 
         stability
@@ -646,9 +678,9 @@ class _IStreamProxy(jsii.proxy_for(_IResource_72f7ee7e)):
         """
         return jsii.get(self, "streamArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="streamName")
-    def stream_name(self) -> str:
+    def stream_name(self) -> builtins.str:
         """The name of the stream.
 
         stability
@@ -658,7 +690,7 @@ class _IStreamProxy(jsii.proxy_for(_IResource_72f7ee7e)):
         """
         return jsii.get(self, "streamName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="encryptionKey")
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
         """Optional KMS encryption key associated with this stream.
@@ -669,7 +701,11 @@ class _IStreamProxy(jsii.proxy_for(_IResource_72f7ee7e)):
         return jsii.get(self, "encryptionKey")
 
     @jsii.member(jsii_name="grant")
-    def grant(self, grantee: _IGrantable_0fcfc53a, *actions: str) -> _Grant_96af6d2d:
+    def grant(
+        self,
+        grantee: _IGrantable_0fcfc53a,
+        *actions: builtins.str,
+    ) -> _Grant_96af6d2d:
         """Grant the indicated permissions on this stream to the provided IAM principal.
 
         :param grantee: -
@@ -740,13 +776,13 @@ class Stream(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         encryption: typing.Optional["StreamEncryption"] = None,
         encryption_key: typing.Optional[_IKey_3336c79d] = None,
         retention_period: typing.Optional[_Duration_5170c158] = None,
         shard_count: typing.Optional[jsii.Number] = None,
-        stream_name: typing.Optional[str] = None,
+        stream_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param scope: -
@@ -773,7 +809,10 @@ class Stream(
     @jsii.member(jsii_name="fromStreamArn")
     @builtins.classmethod
     def from_stream_arn(
-        cls, scope: _Construct_f50a3f53, id: str, stream_arn: str
+        cls,
+        scope: _Construct_f50a3f53,
+        id: builtins.str,
+        stream_arn: builtins.str,
     ) -> "IStream":
         """Import an existing Kinesis Stream provided an ARN.
 
@@ -791,9 +830,9 @@ class Stream(
     def from_stream_attributes(
         cls,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        stream_arn: str,
+        stream_arn: builtins.str,
         encryption_key: typing.Optional[_IKey_3336c79d] = None,
     ) -> "IStream":
         """Creates a Stream construct that represents an external stream.
@@ -811,7 +850,11 @@ class Stream(
         return jsii.sinvoke(cls, "fromStreamAttributes", [scope, id, attrs])
 
     @jsii.member(jsii_name="grant")
-    def grant(self, grantee: _IGrantable_0fcfc53a, *actions: str) -> _Grant_96af6d2d:
+    def grant(
+        self,
+        grantee: _IGrantable_0fcfc53a,
+        *actions: builtins.str,
+    ) -> _Grant_96af6d2d:
         """Grant the indicated permissions on this stream to the given IAM principal (Role/Group/User).
 
         :param grantee: -
@@ -864,9 +907,9 @@ class Stream(
         """
         return jsii.invoke(self, "grantWrite", [grantee])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="streamArn")
-    def stream_arn(self) -> str:
+    def stream_arn(self) -> builtins.str:
         """The ARN of the stream.
 
         stability
@@ -874,9 +917,9 @@ class Stream(
         """
         return jsii.get(self, "streamArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="streamName")
-    def stream_name(self) -> str:
+    def stream_name(self) -> builtins.str:
         """The name of the stream.
 
         stability
@@ -884,7 +927,7 @@ class Stream(
         """
         return jsii.get(self, "streamName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="encryptionKey")
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
         """Optional KMS encryption key associated with this stream.
@@ -904,7 +947,7 @@ class StreamAttributes:
     def __init__(
         self,
         *,
-        stream_arn: str,
+        stream_arn: builtins.str,
         encryption_key: typing.Optional[_IKey_3336c79d] = None,
     ) -> None:
         """A reference to a stream.
@@ -919,20 +962,22 @@ class StreamAttributes:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "stream_arn": stream_arn,
         }
         if encryption_key is not None:
             self._values["encryption_key"] = encryption_key
 
     @builtins.property
-    def stream_arn(self) -> str:
+    def stream_arn(self) -> builtins.str:
         """The ARN of the stream.
 
         stability
         :stability: experimental
         """
-        return self._values.get("stream_arn")
+        result = self._values.get("stream_arn")
+        assert result is not None, "Required property 'stream_arn' is missing"
+        return result
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
@@ -944,12 +989,13 @@ class StreamAttributes:
         stability
         :stability: experimental
         """
-        return self._values.get("encryption_key")
+        result = self._values.get("encryption_key")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -1007,7 +1053,7 @@ class StreamProps:
         encryption_key: typing.Optional[_IKey_3336c79d] = None,
         retention_period: typing.Optional[_Duration_5170c158] = None,
         shard_count: typing.Optional[jsii.Number] = None,
-        stream_name: typing.Optional[str] = None,
+        stream_name: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for a Kinesis Stream.
 
@@ -1020,7 +1066,7 @@ class StreamProps:
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if encryption is not None:
             self._values["encryption"] = encryption
         if encryption_key is not None:
@@ -1049,7 +1095,8 @@ class StreamProps:
         stability
         :stability: experimental
         """
-        return self._values.get("encryption")
+        result = self._values.get("encryption")
+        return result
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
@@ -1067,7 +1114,8 @@ class StreamProps:
         stability
         :stability: experimental
         """
-        return self._values.get("encryption_key")
+        result = self._values.get("encryption_key")
+        return result
 
     @builtins.property
     def retention_period(self) -> typing.Optional[_Duration_5170c158]:
@@ -1079,7 +1127,8 @@ class StreamProps:
         stability
         :stability: experimental
         """
-        return self._values.get("retention_period")
+        result = self._values.get("retention_period")
+        return result
 
     @builtins.property
     def shard_count(self) -> typing.Optional[jsii.Number]:
@@ -1091,10 +1140,11 @@ class StreamProps:
         stability
         :stability: experimental
         """
-        return self._values.get("shard_count")
+        result = self._values.get("shard_count")
+        return result
 
     @builtins.property
-    def stream_name(self) -> typing.Optional[str]:
+    def stream_name(self) -> typing.Optional[builtins.str]:
         """Enforces a particular physical stream name.
 
         default
@@ -1103,12 +1153,13 @@ class StreamProps:
         stability
         :stability: experimental
         """
-        return self._values.get("stream_name")
+        result = self._values.get("stream_name")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
