@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -52,17 +52,17 @@ class ApiEventSource(
 
     def __init__(
         self,
-        method: str,
-        path: str,
+        method: builtins.str,
+        path: builtins.str,
         *,
-        api_key_required: typing.Optional[bool] = None,
-        authorization_scopes: typing.Optional[typing.List[str]] = None,
+        api_key_required: typing.Optional[builtins.bool] = None,
+        authorization_scopes: typing.Optional[typing.List[builtins.str]] = None,
         authorization_type: typing.Optional[_AuthorizationType_2cb72e24] = None,
         authorizer: typing.Optional[_IAuthorizer_fd7d6200] = None,
         method_responses: typing.Optional[typing.List[_MethodResponse_fdda6847]] = None,
-        operation_name: typing.Optional[str] = None,
-        request_models: typing.Optional[typing.Mapping[str, _IModel_13fecd8f]] = None,
-        request_parameters: typing.Optional[typing.Mapping[str, bool]] = None,
+        operation_name: typing.Optional[builtins.str] = None,
+        request_models: typing.Optional[typing.Mapping[builtins.str, _IModel_13fecd8f]] = None,
+        request_parameters: typing.Optional[typing.Mapping[builtins.str, builtins.bool]] = None,
         request_validator: typing.Optional[_IRequestValidator_f057dc3b] = None,
         request_validator_options: typing.Optional[_RequestValidatorOptions_7a8ad269] = None,
     ) -> None:
@@ -151,7 +151,7 @@ class S3EventSource(
         """
         return jsii.invoke(self, "bind", [target])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="bucket")
     def bucket(self) -> _Bucket_abb659b1:
         """
@@ -180,7 +180,7 @@ class S3EventSourceProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "events": events,
         }
         if filters is not None:
@@ -193,7 +193,9 @@ class S3EventSourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("events")
+        result = self._values.get("events")
+        assert result is not None, "Required property 'events' is missing"
+        return result
 
     @builtins.property
     def filters(self) -> typing.Optional[typing.List[_NotificationKeyFilter_c547ae3c]]:
@@ -206,12 +208,13 @@ class S3EventSourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("filters")
+        result = self._values.get("filters")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -288,7 +291,7 @@ class SnsEventSource(
         """
         return jsii.invoke(self, "bind", [target])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="topic")
     def topic(self) -> _ITopic_ef0ebe0e:
         """
@@ -374,9 +377,9 @@ class SqsEventSource(
         """
         return jsii.invoke(self, "bind", [target])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="eventSourceMappingId")
-    def event_source_mapping_id(self) -> str:
+    def event_source_mapping_id(self) -> builtins.str:
         """The identifier for this EventSourceMapping.
 
         stability
@@ -384,7 +387,7 @@ class SqsEventSource(
         """
         return jsii.get(self, "eventSourceMappingId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="queue")
     def queue(self) -> _IQueue_b743f559:
         """
@@ -407,7 +410,7 @@ class SqsEventSourceProps:
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if batch_size is not None:
             self._values["batch_size"] = batch_size
 
@@ -426,12 +429,13 @@ class SqsEventSourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("batch_size")
+        result = self._values.get("batch_size")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -460,7 +464,7 @@ class StreamEventSource(
         *,
         starting_position: _StartingPosition_98f65751,
         batch_size: typing.Optional[jsii.Number] = None,
-        bisect_batch_on_error: typing.Optional[bool] = None,
+        bisect_batch_on_error: typing.Optional[builtins.bool] = None,
         max_batching_window: typing.Optional[_Duration_5170c158] = None,
         max_record_age: typing.Optional[_Duration_5170c158] = None,
         on_failure: typing.Optional[_IEventSourceDlq_64554172] = None,
@@ -509,10 +513,10 @@ class StreamEventSource(
     def _enrich_mapping_options(
         self,
         *,
-        event_source_arn: str,
+        event_source_arn: builtins.str,
         batch_size: typing.Optional[jsii.Number] = None,
-        bisect_batch_on_error: typing.Optional[bool] = None,
-        enabled: typing.Optional[bool] = None,
+        bisect_batch_on_error: typing.Optional[builtins.bool] = None,
+        enabled: typing.Optional[builtins.bool] = None,
         max_batching_window: typing.Optional[_Duration_5170c158] = None,
         max_record_age: typing.Optional[_Duration_5170c158] = None,
         on_failure: typing.Optional[_IEventSourceDlq_64554172] = None,
@@ -550,7 +554,7 @@ class StreamEventSource(
 
         return jsii.invoke(self, "enrichMappingOptions", [options])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="props")
     def _props(self) -> "StreamEventSourceProps":
         """
@@ -593,7 +597,7 @@ class StreamEventSourceProps:
         *,
         starting_position: _StartingPosition_98f65751,
         batch_size: typing.Optional[jsii.Number] = None,
-        bisect_batch_on_error: typing.Optional[bool] = None,
+        bisect_batch_on_error: typing.Optional[builtins.bool] = None,
         max_batching_window: typing.Optional[_Duration_5170c158] = None,
         max_record_age: typing.Optional[_Duration_5170c158] = None,
         on_failure: typing.Optional[_IEventSourceDlq_64554172] = None,
@@ -614,7 +618,7 @@ class StreamEventSourceProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "starting_position": starting_position,
         }
         if batch_size is not None:
@@ -639,7 +643,9 @@ class StreamEventSourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("starting_position")
+        result = self._values.get("starting_position")
+        assert result is not None, "Required property 'starting_position' is missing"
+        return result
 
     @builtins.property
     def batch_size(self) -> typing.Optional[jsii.Number]:
@@ -662,10 +668,11 @@ class StreamEventSourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("batch_size")
+        result = self._values.get("batch_size")
+        return result
 
     @builtins.property
-    def bisect_batch_on_error(self) -> typing.Optional[bool]:
+    def bisect_batch_on_error(self) -> typing.Optional[builtins.bool]:
         """If the function returns an error, split the batch in two and retry.
 
         default
@@ -674,7 +681,8 @@ class StreamEventSourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("bisect_batch_on_error")
+        result = self._values.get("bisect_batch_on_error")
+        return result
 
     @builtins.property
     def max_batching_window(self) -> typing.Optional[_Duration_5170c158]:
@@ -688,7 +696,8 @@ class StreamEventSourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("max_batching_window")
+        result = self._values.get("max_batching_window")
+        return result
 
     @builtins.property
     def max_record_age(self) -> typing.Optional[_Duration_5170c158]:
@@ -705,7 +714,8 @@ class StreamEventSourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("max_record_age")
+        result = self._values.get("max_record_age")
+        return result
 
     @builtins.property
     def on_failure(self) -> typing.Optional[_IEventSourceDlq_64554172]:
@@ -717,7 +727,8 @@ class StreamEventSourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("on_failure")
+        result = self._values.get("on_failure")
+        return result
 
     @builtins.property
     def parallelization_factor(self) -> typing.Optional[jsii.Number]:
@@ -734,7 +745,8 @@ class StreamEventSourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("parallelization_factor")
+        result = self._values.get("parallelization_factor")
+        return result
 
     @builtins.property
     def retry_attempts(self) -> typing.Optional[jsii.Number]:
@@ -746,12 +758,13 @@ class StreamEventSourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("retry_attempts")
+        result = self._values.get("retry_attempts")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -777,7 +790,7 @@ class DynamoEventSource(
         *,
         starting_position: _StartingPosition_98f65751,
         batch_size: typing.Optional[jsii.Number] = None,
-        bisect_batch_on_error: typing.Optional[bool] = None,
+        bisect_batch_on_error: typing.Optional[builtins.bool] = None,
         max_batching_window: typing.Optional[_Duration_5170c158] = None,
         max_record_age: typing.Optional[_Duration_5170c158] = None,
         on_failure: typing.Optional[_IEventSourceDlq_64554172] = None,
@@ -822,9 +835,9 @@ class DynamoEventSource(
         """
         return jsii.invoke(self, "bind", [target])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="eventSourceMappingId")
-    def event_source_mapping_id(self) -> str:
+    def event_source_mapping_id(self) -> builtins.str:
         """The identifier for this EventSourceMapping.
 
         stability
@@ -853,7 +866,7 @@ class DynamoEventSourceProps(StreamEventSourceProps):
         *,
         starting_position: _StartingPosition_98f65751,
         batch_size: typing.Optional[jsii.Number] = None,
-        bisect_batch_on_error: typing.Optional[bool] = None,
+        bisect_batch_on_error: typing.Optional[builtins.bool] = None,
         max_batching_window: typing.Optional[_Duration_5170c158] = None,
         max_record_age: typing.Optional[_Duration_5170c158] = None,
         on_failure: typing.Optional[_IEventSourceDlq_64554172] = None,
@@ -873,7 +886,7 @@ class DynamoEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "starting_position": starting_position,
         }
         if batch_size is not None:
@@ -898,7 +911,9 @@ class DynamoEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("starting_position")
+        result = self._values.get("starting_position")
+        assert result is not None, "Required property 'starting_position' is missing"
+        return result
 
     @builtins.property
     def batch_size(self) -> typing.Optional[jsii.Number]:
@@ -921,10 +936,11 @@ class DynamoEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("batch_size")
+        result = self._values.get("batch_size")
+        return result
 
     @builtins.property
-    def bisect_batch_on_error(self) -> typing.Optional[bool]:
+    def bisect_batch_on_error(self) -> typing.Optional[builtins.bool]:
         """If the function returns an error, split the batch in two and retry.
 
         default
@@ -933,7 +949,8 @@ class DynamoEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("bisect_batch_on_error")
+        result = self._values.get("bisect_batch_on_error")
+        return result
 
     @builtins.property
     def max_batching_window(self) -> typing.Optional[_Duration_5170c158]:
@@ -947,7 +964,8 @@ class DynamoEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("max_batching_window")
+        result = self._values.get("max_batching_window")
+        return result
 
     @builtins.property
     def max_record_age(self) -> typing.Optional[_Duration_5170c158]:
@@ -964,7 +982,8 @@ class DynamoEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("max_record_age")
+        result = self._values.get("max_record_age")
+        return result
 
     @builtins.property
     def on_failure(self) -> typing.Optional[_IEventSourceDlq_64554172]:
@@ -976,7 +995,8 @@ class DynamoEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("on_failure")
+        result = self._values.get("on_failure")
+        return result
 
     @builtins.property
     def parallelization_factor(self) -> typing.Optional[jsii.Number]:
@@ -993,7 +1013,8 @@ class DynamoEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("parallelization_factor")
+        result = self._values.get("parallelization_factor")
+        return result
 
     @builtins.property
     def retry_attempts(self) -> typing.Optional[jsii.Number]:
@@ -1005,12 +1026,13 @@ class DynamoEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("retry_attempts")
+        result = self._values.get("retry_attempts")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -1036,7 +1058,7 @@ class KinesisEventSource(
         *,
         starting_position: _StartingPosition_98f65751,
         batch_size: typing.Optional[jsii.Number] = None,
-        bisect_batch_on_error: typing.Optional[bool] = None,
+        bisect_batch_on_error: typing.Optional[builtins.bool] = None,
         max_batching_window: typing.Optional[_Duration_5170c158] = None,
         max_record_age: typing.Optional[_Duration_5170c158] = None,
         on_failure: typing.Optional[_IEventSourceDlq_64554172] = None,
@@ -1081,9 +1103,9 @@ class KinesisEventSource(
         """
         return jsii.invoke(self, "bind", [target])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="eventSourceMappingId")
-    def event_source_mapping_id(self) -> str:
+    def event_source_mapping_id(self) -> builtins.str:
         """The identifier for this EventSourceMapping.
 
         stability
@@ -1091,7 +1113,7 @@ class KinesisEventSource(
         """
         return jsii.get(self, "eventSourceMappingId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="stream")
     def stream(self) -> _IStream_c7ff3ed6:
         """
@@ -1121,7 +1143,7 @@ class KinesisEventSourceProps(StreamEventSourceProps):
         *,
         starting_position: _StartingPosition_98f65751,
         batch_size: typing.Optional[jsii.Number] = None,
-        bisect_batch_on_error: typing.Optional[bool] = None,
+        bisect_batch_on_error: typing.Optional[builtins.bool] = None,
         max_batching_window: typing.Optional[_Duration_5170c158] = None,
         max_record_age: typing.Optional[_Duration_5170c158] = None,
         on_failure: typing.Optional[_IEventSourceDlq_64554172] = None,
@@ -1141,7 +1163,7 @@ class KinesisEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "starting_position": starting_position,
         }
         if batch_size is not None:
@@ -1166,7 +1188,9 @@ class KinesisEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("starting_position")
+        result = self._values.get("starting_position")
+        assert result is not None, "Required property 'starting_position' is missing"
+        return result
 
     @builtins.property
     def batch_size(self) -> typing.Optional[jsii.Number]:
@@ -1189,10 +1213,11 @@ class KinesisEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("batch_size")
+        result = self._values.get("batch_size")
+        return result
 
     @builtins.property
-    def bisect_batch_on_error(self) -> typing.Optional[bool]:
+    def bisect_batch_on_error(self) -> typing.Optional[builtins.bool]:
         """If the function returns an error, split the batch in two and retry.
 
         default
@@ -1201,7 +1226,8 @@ class KinesisEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("bisect_batch_on_error")
+        result = self._values.get("bisect_batch_on_error")
+        return result
 
     @builtins.property
     def max_batching_window(self) -> typing.Optional[_Duration_5170c158]:
@@ -1215,7 +1241,8 @@ class KinesisEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("max_batching_window")
+        result = self._values.get("max_batching_window")
+        return result
 
     @builtins.property
     def max_record_age(self) -> typing.Optional[_Duration_5170c158]:
@@ -1232,7 +1259,8 @@ class KinesisEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("max_record_age")
+        result = self._values.get("max_record_age")
+        return result
 
     @builtins.property
     def on_failure(self) -> typing.Optional[_IEventSourceDlq_64554172]:
@@ -1244,7 +1272,8 @@ class KinesisEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("on_failure")
+        result = self._values.get("on_failure")
+        return result
 
     @builtins.property
     def parallelization_factor(self) -> typing.Optional[jsii.Number]:
@@ -1261,7 +1290,8 @@ class KinesisEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("parallelization_factor")
+        result = self._values.get("parallelization_factor")
+        return result
 
     @builtins.property
     def retry_attempts(self) -> typing.Optional[jsii.Number]:
@@ -1273,12 +1303,13 @@ class KinesisEventSourceProps(StreamEventSourceProps):
         stability
         :stability: experimental
         """
-        return self._values.get("retry_attempts")
+        result = self._values.get("retry_attempts")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
