@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -37,17 +37,17 @@ class CfnJobTemplate(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         settings_json: typing.Any,
         acceleration_settings: typing.Optional[typing.Union["AccelerationSettingsProperty", _IResolvable_9ceae33e]] = None,
-        category: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
+        category: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
         hop_destinations: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["HopDestinationProperty", _IResolvable_9ceae33e]]]] = None,
-        name: typing.Optional[str] = None,
+        name: typing.Optional[builtins.str] = None,
         priority: typing.Optional[jsii.Number] = None,
-        queue: typing.Optional[str] = None,
-        status_update_interval: typing.Optional[str] = None,
+        queue: typing.Optional[builtins.str] = None,
+        status_update_interval: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
         """Create a new ``AWS::MediaConvert::JobTemplate``.
@@ -93,43 +93,44 @@ class CfnJobTemplate(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrName")
-    def attr_name(self) -> str:
+    def attr_name(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Name
         """
         return jsii.get(self, "attrName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::MediaConvert::JobTemplate.Tags``.
@@ -139,7 +140,7 @@ class CfnJobTemplate(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="settingsJson")
     def settings_json(self) -> typing.Any:
         """``AWS::MediaConvert::JobTemplate.SettingsJson``.
@@ -149,11 +150,11 @@ class CfnJobTemplate(
         """
         return jsii.get(self, "settingsJson")
 
-    @settings_json.setter
+    @settings_json.setter # type: ignore
     def settings_json(self, value: typing.Any) -> None:
         jsii.set(self, "settingsJson", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="accelerationSettings")
     def acceleration_settings(
         self,
@@ -165,16 +166,16 @@ class CfnJobTemplate(
         """
         return jsii.get(self, "accelerationSettings")
 
-    @acceleration_settings.setter
+    @acceleration_settings.setter # type: ignore
     def acceleration_settings(
         self,
         value: typing.Optional[typing.Union["AccelerationSettingsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "accelerationSettings", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="category")
-    def category(self) -> typing.Optional[str]:
+    def category(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Category``.
 
         see
@@ -182,13 +183,13 @@ class CfnJobTemplate(
         """
         return jsii.get(self, "category")
 
-    @category.setter
-    def category(self, value: typing.Optional[str]) -> None:
+    @category.setter # type: ignore
+    def category(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "category", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Description``.
 
         see
@@ -196,11 +197,11 @@ class CfnJobTemplate(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="hopDestinations")
     def hop_destinations(
         self,
@@ -212,16 +213,16 @@ class CfnJobTemplate(
         """
         return jsii.get(self, "hopDestinations")
 
-    @hop_destinations.setter
+    @hop_destinations.setter # type: ignore
     def hop_destinations(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["HopDestinationProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "hopDestinations", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Name``.
 
         see
@@ -229,11 +230,11 @@ class CfnJobTemplate(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: typing.Optional[str]) -> None:
+    @name.setter # type: ignore
+    def name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="priority")
     def priority(self) -> typing.Optional[jsii.Number]:
         """``AWS::MediaConvert::JobTemplate.Priority``.
@@ -243,13 +244,13 @@ class CfnJobTemplate(
         """
         return jsii.get(self, "priority")
 
-    @priority.setter
+    @priority.setter # type: ignore
     def priority(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "priority", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="queue")
-    def queue(self) -> typing.Optional[str]:
+    def queue(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Queue``.
 
         see
@@ -257,13 +258,13 @@ class CfnJobTemplate(
         """
         return jsii.get(self, "queue")
 
-    @queue.setter
-    def queue(self, value: typing.Optional[str]) -> None:
+    @queue.setter # type: ignore
+    def queue(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "queue", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="statusUpdateInterval")
-    def status_update_interval(self) -> typing.Optional[str]:
+    def status_update_interval(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.StatusUpdateInterval``.
 
         see
@@ -271,8 +272,8 @@ class CfnJobTemplate(
         """
         return jsii.get(self, "statusUpdateInterval")
 
-    @status_update_interval.setter
-    def status_update_interval(self, value: typing.Optional[str]) -> None:
+    @status_update_interval.setter # type: ignore
+    def status_update_interval(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "statusUpdateInterval", value)
 
     @jsii.data_type(
@@ -281,30 +282,32 @@ class CfnJobTemplate(
         name_mapping={"mode": "mode"},
     )
     class AccelerationSettingsProperty:
-        def __init__(self, *, mode: str) -> None:
+        def __init__(self, *, mode: builtins.str) -> None:
             """
             :param mode: ``CfnJobTemplate.AccelerationSettingsProperty.Mode``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-accelerationsettings.html
             """
-            self._values = {
+            self._values: typing.Dict[str, typing.Any] = {
                 "mode": mode,
             }
 
         @builtins.property
-        def mode(self) -> str:
+        def mode(self) -> builtins.str:
             """``CfnJobTemplate.AccelerationSettingsProperty.Mode``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-accelerationsettings.html#cfn-mediaconvert-jobtemplate-accelerationsettings-mode
             """
-            return self._values.get("mode")
+            result = self._values.get("mode")
+            assert result is not None, "Required property 'mode' is missing"
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -326,7 +329,7 @@ class CfnJobTemplate(
             self,
             *,
             priority: typing.Optional[jsii.Number] = None,
-            queue: typing.Optional[str] = None,
+            queue: typing.Optional[builtins.str] = None,
             wait_minutes: typing.Optional[jsii.Number] = None,
         ) -> None:
             """
@@ -337,7 +340,7 @@ class CfnJobTemplate(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-hopdestination.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if priority is not None:
                 self._values["priority"] = priority
             if queue is not None:
@@ -352,16 +355,18 @@ class CfnJobTemplate(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-hopdestination.html#cfn-mediaconvert-jobtemplate-hopdestination-priority
             """
-            return self._values.get("priority")
+            result = self._values.get("priority")
+            return result
 
         @builtins.property
-        def queue(self) -> typing.Optional[str]:
+        def queue(self) -> typing.Optional[builtins.str]:
             """``CfnJobTemplate.HopDestinationProperty.Queue``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-hopdestination.html#cfn-mediaconvert-jobtemplate-hopdestination-queue
             """
-            return self._values.get("queue")
+            result = self._values.get("queue")
+            return result
 
         @builtins.property
         def wait_minutes(self) -> typing.Optional[jsii.Number]:
@@ -370,12 +375,13 @@ class CfnJobTemplate(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-hopdestination.html#cfn-mediaconvert-jobtemplate-hopdestination-waitminutes
             """
-            return self._values.get("wait_minutes")
+            result = self._values.get("wait_minutes")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -406,13 +412,13 @@ class CfnJobTemplateProps:
         *,
         settings_json: typing.Any,
         acceleration_settings: typing.Optional[typing.Union["CfnJobTemplate.AccelerationSettingsProperty", _IResolvable_9ceae33e]] = None,
-        category: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
+        category: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
         hop_destinations: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnJobTemplate.HopDestinationProperty", _IResolvable_9ceae33e]]]] = None,
-        name: typing.Optional[str] = None,
+        name: typing.Optional[builtins.str] = None,
         priority: typing.Optional[jsii.Number] = None,
-        queue: typing.Optional[str] = None,
-        status_update_interval: typing.Optional[str] = None,
+        queue: typing.Optional[builtins.str] = None,
+        status_update_interval: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
         """Properties for defining a ``AWS::MediaConvert::JobTemplate``.
@@ -431,7 +437,7 @@ class CfnJobTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "settings_json": settings_json,
         }
         if acceleration_settings is not None:
@@ -460,7 +466,9 @@ class CfnJobTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-settingsjson
         """
-        return self._values.get("settings_json")
+        result = self._values.get("settings_json")
+        assert result is not None, "Required property 'settings_json' is missing"
+        return result
 
     @builtins.property
     def acceleration_settings(
@@ -471,25 +479,28 @@ class CfnJobTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-accelerationsettings
         """
-        return self._values.get("acceleration_settings")
+        result = self._values.get("acceleration_settings")
+        return result
 
     @builtins.property
-    def category(self) -> typing.Optional[str]:
+    def category(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Category``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-category
         """
-        return self._values.get("category")
+        result = self._values.get("category")
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
     def hop_destinations(
@@ -500,16 +511,18 @@ class CfnJobTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-hopdestinations
         """
-        return self._values.get("hop_destinations")
+        result = self._values.get("hop_destinations")
+        return result
 
     @builtins.property
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        return result
 
     @builtins.property
     def priority(self) -> typing.Optional[jsii.Number]:
@@ -518,25 +531,28 @@ class CfnJobTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-priority
         """
-        return self._values.get("priority")
+        result = self._values.get("priority")
+        return result
 
     @builtins.property
-    def queue(self) -> typing.Optional[str]:
+    def queue(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.Queue``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-queue
         """
-        return self._values.get("queue")
+        result = self._values.get("queue")
+        return result
 
     @builtins.property
-    def status_update_interval(self) -> typing.Optional[str]:
+    def status_update_interval(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::JobTemplate.StatusUpdateInterval``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-statusupdateinterval
         """
-        return self._values.get("status_update_interval")
+        result = self._values.get("status_update_interval")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Any:
@@ -545,12 +561,13 @@ class CfnJobTemplateProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -576,12 +593,12 @@ class CfnPreset(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         settings_json: typing.Any,
-        category: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
-        name: typing.Optional[str] = None,
+        category: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
+        name: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
         """Create a new ``AWS::MediaConvert::Preset``.
@@ -617,43 +634,44 @@ class CfnPreset(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrName")
-    def attr_name(self) -> str:
+    def attr_name(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Name
         """
         return jsii.get(self, "attrName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::MediaConvert::Preset.Tags``.
@@ -663,7 +681,7 @@ class CfnPreset(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="settingsJson")
     def settings_json(self) -> typing.Any:
         """``AWS::MediaConvert::Preset.SettingsJson``.
@@ -673,13 +691,13 @@ class CfnPreset(
         """
         return jsii.get(self, "settingsJson")
 
-    @settings_json.setter
+    @settings_json.setter # type: ignore
     def settings_json(self, value: typing.Any) -> None:
         jsii.set(self, "settingsJson", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="category")
-    def category(self) -> typing.Optional[str]:
+    def category(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Category``.
 
         see
@@ -687,13 +705,13 @@ class CfnPreset(
         """
         return jsii.get(self, "category")
 
-    @category.setter
-    def category(self, value: typing.Optional[str]) -> None:
+    @category.setter # type: ignore
+    def category(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "category", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Description``.
 
         see
@@ -701,13 +719,13 @@ class CfnPreset(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Name``.
 
         see
@@ -715,8 +733,8 @@ class CfnPreset(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: typing.Optional[str]) -> None:
+    @name.setter # type: ignore
+    def name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "name", value)
 
 
@@ -736,9 +754,9 @@ class CfnPresetProps:
         self,
         *,
         settings_json: typing.Any,
-        category: typing.Optional[str] = None,
-        description: typing.Optional[str] = None,
-        name: typing.Optional[str] = None,
+        category: typing.Optional[builtins.str] = None,
+        description: typing.Optional[builtins.str] = None,
+        name: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
         """Properties for defining a ``AWS::MediaConvert::Preset``.
@@ -752,7 +770,7 @@ class CfnPresetProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "settings_json": settings_json,
         }
         if category is not None:
@@ -771,34 +789,39 @@ class CfnPresetProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-settingsjson
         """
-        return self._values.get("settings_json")
+        result = self._values.get("settings_json")
+        assert result is not None, "Required property 'settings_json' is missing"
+        return result
 
     @builtins.property
-    def category(self) -> typing.Optional[str]:
+    def category(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Category``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-category
         """
-        return self._values.get("category")
+        result = self._values.get("category")
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Preset.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Any:
@@ -807,12 +830,13 @@ class CfnPresetProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -838,12 +862,12 @@ class CfnQueue(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        description: typing.Optional[str] = None,
-        name: typing.Optional[str] = None,
-        pricing_plan: typing.Optional[str] = None,
-        status: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        name: typing.Optional[builtins.str] = None,
+        pricing_plan: typing.Optional[builtins.str] = None,
+        status: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
         """Create a new ``AWS::MediaConvert::Queue``.
@@ -879,43 +903,44 @@ class CfnQueue(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrName")
-    def attr_name(self) -> str:
+    def attr_name(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Name
         """
         return jsii.get(self, "attrName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::MediaConvert::Queue.Tags``.
@@ -925,9 +950,9 @@ class CfnQueue(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Description``.
 
         see
@@ -935,13 +960,13 @@ class CfnQueue(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Name``.
 
         see
@@ -949,13 +974,13 @@ class CfnQueue(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: typing.Optional[str]) -> None:
+    @name.setter # type: ignore
+    def name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="pricingPlan")
-    def pricing_plan(self) -> typing.Optional[str]:
+    def pricing_plan(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.PricingPlan``.
 
         see
@@ -963,13 +988,13 @@ class CfnQueue(
         """
         return jsii.get(self, "pricingPlan")
 
-    @pricing_plan.setter
-    def pricing_plan(self, value: typing.Optional[str]) -> None:
+    @pricing_plan.setter # type: ignore
+    def pricing_plan(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "pricingPlan", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="status")
-    def status(self) -> typing.Optional[str]:
+    def status(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Status``.
 
         see
@@ -977,8 +1002,8 @@ class CfnQueue(
         """
         return jsii.get(self, "status")
 
-    @status.setter
-    def status(self, value: typing.Optional[str]) -> None:
+    @status.setter # type: ignore
+    def status(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "status", value)
 
 
@@ -997,10 +1022,10 @@ class CfnQueueProps:
     def __init__(
         self,
         *,
-        description: typing.Optional[str] = None,
-        name: typing.Optional[str] = None,
-        pricing_plan: typing.Optional[str] = None,
-        status: typing.Optional[str] = None,
+        description: typing.Optional[builtins.str] = None,
+        name: typing.Optional[builtins.str] = None,
+        pricing_plan: typing.Optional[builtins.str] = None,
+        status: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
         """Properties for defining a ``AWS::MediaConvert::Queue``.
@@ -1014,7 +1039,7 @@ class CfnQueueProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if description is not None:
             self._values["description"] = description
         if name is not None:
@@ -1027,40 +1052,44 @@ class CfnQueueProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
-    def name(self) -> typing.Optional[str]:
+    def name(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        return result
 
     @builtins.property
-    def pricing_plan(self) -> typing.Optional[str]:
+    def pricing_plan(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.PricingPlan``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-pricingplan
         """
-        return self._values.get("pricing_plan")
+        result = self._values.get("pricing_plan")
+        return result
 
     @builtins.property
-    def status(self) -> typing.Optional[str]:
+    def status(self) -> typing.Optional[builtins.str]:
         """``AWS::MediaConvert::Queue.Status``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-status
         """
-        return self._values.get("status")
+        result = self._values.get("status")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Any:
@@ -1069,12 +1098,13 @@ class CfnQueueProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
