@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -38,28 +38,28 @@ class CfnServer(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        instance_profile_arn: str,
-        instance_type: str,
-        service_role_arn: str,
-        associate_public_ip_address: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        backup_id: typing.Optional[str] = None,
+        instance_profile_arn: builtins.str,
+        instance_type: builtins.str,
+        service_role_arn: builtins.str,
+        associate_public_ip_address: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        backup_id: typing.Optional[builtins.str] = None,
         backup_retention_count: typing.Optional[jsii.Number] = None,
-        custom_certificate: typing.Optional[str] = None,
-        custom_domain: typing.Optional[str] = None,
-        custom_private_key: typing.Optional[str] = None,
-        disable_automated_backup: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        engine: typing.Optional[str] = None,
+        custom_certificate: typing.Optional[builtins.str] = None,
+        custom_domain: typing.Optional[builtins.str] = None,
+        custom_private_key: typing.Optional[builtins.str] = None,
+        disable_automated_backup: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        engine: typing.Optional[builtins.str] = None,
         engine_attributes: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EngineAttributeProperty", _IResolvable_9ceae33e]]]] = None,
-        engine_model: typing.Optional[str] = None,
-        engine_version: typing.Optional[str] = None,
-        key_pair: typing.Optional[str] = None,
-        preferred_backup_window: typing.Optional[str] = None,
-        preferred_maintenance_window: typing.Optional[str] = None,
-        security_group_ids: typing.Optional[typing.List[str]] = None,
-        server_name: typing.Optional[str] = None,
-        subnet_ids: typing.Optional[typing.List[str]] = None,
+        engine_model: typing.Optional[builtins.str] = None,
+        engine_version: typing.Optional[builtins.str] = None,
+        key_pair: typing.Optional[builtins.str] = None,
+        preferred_backup_window: typing.Optional[builtins.str] = None,
+        preferred_maintenance_window: typing.Optional[builtins.str] = None,
+        security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
+        server_name: typing.Optional[builtins.str] = None,
+        subnet_ids: typing.Optional[typing.List[builtins.str]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::OpsWorksCM::Server``.
@@ -127,43 +127,53 @@ class CfnServer(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrEndpoint")
-    def attr_endpoint(self) -> str:
+    def attr_endpoint(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Endpoint
         """
         return jsii.get(self, "attrEndpoint")
 
-    @builtins.property
+    @builtins.property # type: ignore
+    @jsii.member(jsii_name="attrId")
+    def attr_id(self) -> builtins.str:
+        """
+        cloudformationAttribute:
+        :cloudformationAttribute:: Id
+        """
+        return jsii.get(self, "attrId")
+
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::OpsWorksCM::Server.Tags``.
@@ -173,9 +183,9 @@ class CfnServer(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="instanceProfileArn")
-    def instance_profile_arn(self) -> str:
+    def instance_profile_arn(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.InstanceProfileArn``.
 
         see
@@ -183,13 +193,13 @@ class CfnServer(
         """
         return jsii.get(self, "instanceProfileArn")
 
-    @instance_profile_arn.setter
-    def instance_profile_arn(self, value: str) -> None:
+    @instance_profile_arn.setter # type: ignore
+    def instance_profile_arn(self, value: builtins.str) -> None:
         jsii.set(self, "instanceProfileArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="instanceType")
-    def instance_type(self) -> str:
+    def instance_type(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.InstanceType``.
 
         see
@@ -197,13 +207,13 @@ class CfnServer(
         """
         return jsii.get(self, "instanceType")
 
-    @instance_type.setter
-    def instance_type(self, value: str) -> None:
+    @instance_type.setter # type: ignore
+    def instance_type(self, value: builtins.str) -> None:
         jsii.set(self, "instanceType", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="serviceRoleArn")
-    def service_role_arn(self) -> str:
+    def service_role_arn(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.ServiceRoleArn``.
 
         see
@@ -211,15 +221,15 @@ class CfnServer(
         """
         return jsii.get(self, "serviceRoleArn")
 
-    @service_role_arn.setter
-    def service_role_arn(self, value: str) -> None:
+    @service_role_arn.setter # type: ignore
+    def service_role_arn(self, value: builtins.str) -> None:
         jsii.set(self, "serviceRoleArn", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="associatePublicIpAddress")
     def associate_public_ip_address(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::OpsWorksCM::Server.AssociatePublicIpAddress``.
 
         see
@@ -227,15 +237,16 @@ class CfnServer(
         """
         return jsii.get(self, "associatePublicIpAddress")
 
-    @associate_public_ip_address.setter
+    @associate_public_ip_address.setter # type: ignore
     def associate_public_ip_address(
-        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "associatePublicIpAddress", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="backupId")
-    def backup_id(self) -> typing.Optional[str]:
+    def backup_id(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.BackupId``.
 
         see
@@ -243,11 +254,11 @@ class CfnServer(
         """
         return jsii.get(self, "backupId")
 
-    @backup_id.setter
-    def backup_id(self, value: typing.Optional[str]) -> None:
+    @backup_id.setter # type: ignore
+    def backup_id(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "backupId", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="backupRetentionCount")
     def backup_retention_count(self) -> typing.Optional[jsii.Number]:
         """``AWS::OpsWorksCM::Server.BackupRetentionCount``.
@@ -257,13 +268,13 @@ class CfnServer(
         """
         return jsii.get(self, "backupRetentionCount")
 
-    @backup_retention_count.setter
+    @backup_retention_count.setter # type: ignore
     def backup_retention_count(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "backupRetentionCount", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="customCertificate")
-    def custom_certificate(self) -> typing.Optional[str]:
+    def custom_certificate(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomCertificate``.
 
         see
@@ -271,13 +282,13 @@ class CfnServer(
         """
         return jsii.get(self, "customCertificate")
 
-    @custom_certificate.setter
-    def custom_certificate(self, value: typing.Optional[str]) -> None:
+    @custom_certificate.setter # type: ignore
+    def custom_certificate(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "customCertificate", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="customDomain")
-    def custom_domain(self) -> typing.Optional[str]:
+    def custom_domain(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomDomain``.
 
         see
@@ -285,13 +296,13 @@ class CfnServer(
         """
         return jsii.get(self, "customDomain")
 
-    @custom_domain.setter
-    def custom_domain(self, value: typing.Optional[str]) -> None:
+    @custom_domain.setter # type: ignore
+    def custom_domain(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "customDomain", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="customPrivateKey")
-    def custom_private_key(self) -> typing.Optional[str]:
+    def custom_private_key(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomPrivateKey``.
 
         see
@@ -299,15 +310,15 @@ class CfnServer(
         """
         return jsii.get(self, "customPrivateKey")
 
-    @custom_private_key.setter
-    def custom_private_key(self, value: typing.Optional[str]) -> None:
+    @custom_private_key.setter # type: ignore
+    def custom_private_key(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "customPrivateKey", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="disableAutomatedBackup")
     def disable_automated_backup(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::OpsWorksCM::Server.DisableAutomatedBackup``.
 
         see
@@ -315,15 +326,16 @@ class CfnServer(
         """
         return jsii.get(self, "disableAutomatedBackup")
 
-    @disable_automated_backup.setter
+    @disable_automated_backup.setter # type: ignore
     def disable_automated_backup(
-        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "disableAutomatedBackup", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="engine")
-    def engine(self) -> typing.Optional[str]:
+    def engine(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.Engine``.
 
         see
@@ -331,11 +343,11 @@ class CfnServer(
         """
         return jsii.get(self, "engine")
 
-    @engine.setter
-    def engine(self, value: typing.Optional[str]) -> None:
+    @engine.setter # type: ignore
+    def engine(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "engine", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="engineAttributes")
     def engine_attributes(
         self,
@@ -347,16 +359,16 @@ class CfnServer(
         """
         return jsii.get(self, "engineAttributes")
 
-    @engine_attributes.setter
+    @engine_attributes.setter # type: ignore
     def engine_attributes(
         self,
         value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EngineAttributeProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "engineAttributes", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="engineModel")
-    def engine_model(self) -> typing.Optional[str]:
+    def engine_model(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.EngineModel``.
 
         see
@@ -364,13 +376,13 @@ class CfnServer(
         """
         return jsii.get(self, "engineModel")
 
-    @engine_model.setter
-    def engine_model(self, value: typing.Optional[str]) -> None:
+    @engine_model.setter # type: ignore
+    def engine_model(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "engineModel", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="engineVersion")
-    def engine_version(self) -> typing.Optional[str]:
+    def engine_version(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.EngineVersion``.
 
         see
@@ -378,13 +390,13 @@ class CfnServer(
         """
         return jsii.get(self, "engineVersion")
 
-    @engine_version.setter
-    def engine_version(self, value: typing.Optional[str]) -> None:
+    @engine_version.setter # type: ignore
+    def engine_version(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "engineVersion", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="keyPair")
-    def key_pair(self) -> typing.Optional[str]:
+    def key_pair(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.KeyPair``.
 
         see
@@ -392,13 +404,13 @@ class CfnServer(
         """
         return jsii.get(self, "keyPair")
 
-    @key_pair.setter
-    def key_pair(self, value: typing.Optional[str]) -> None:
+    @key_pair.setter # type: ignore
+    def key_pair(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "keyPair", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="preferredBackupWindow")
-    def preferred_backup_window(self) -> typing.Optional[str]:
+    def preferred_backup_window(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.PreferredBackupWindow``.
 
         see
@@ -406,13 +418,13 @@ class CfnServer(
         """
         return jsii.get(self, "preferredBackupWindow")
 
-    @preferred_backup_window.setter
-    def preferred_backup_window(self, value: typing.Optional[str]) -> None:
+    @preferred_backup_window.setter # type: ignore
+    def preferred_backup_window(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "preferredBackupWindow", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="preferredMaintenanceWindow")
-    def preferred_maintenance_window(self) -> typing.Optional[str]:
+    def preferred_maintenance_window(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.PreferredMaintenanceWindow``.
 
         see
@@ -420,13 +432,16 @@ class CfnServer(
         """
         return jsii.get(self, "preferredMaintenanceWindow")
 
-    @preferred_maintenance_window.setter
-    def preferred_maintenance_window(self, value: typing.Optional[str]) -> None:
+    @preferred_maintenance_window.setter # type: ignore
+    def preferred_maintenance_window(
+        self,
+        value: typing.Optional[builtins.str],
+    ) -> None:
         jsii.set(self, "preferredMaintenanceWindow", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="securityGroupIds")
-    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
+    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::OpsWorksCM::Server.SecurityGroupIds``.
 
         see
@@ -434,13 +449,16 @@ class CfnServer(
         """
         return jsii.get(self, "securityGroupIds")
 
-    @security_group_ids.setter
-    def security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
+    @security_group_ids.setter # type: ignore
+    def security_group_ids(
+        self,
+        value: typing.Optional[typing.List[builtins.str]],
+    ) -> None:
         jsii.set(self, "securityGroupIds", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="serverName")
-    def server_name(self) -> typing.Optional[str]:
+    def server_name(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.ServerName``.
 
         see
@@ -448,13 +466,13 @@ class CfnServer(
         """
         return jsii.get(self, "serverName")
 
-    @server_name.setter
-    def server_name(self, value: typing.Optional[str]) -> None:
+    @server_name.setter # type: ignore
+    def server_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "serverName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="subnetIds")
-    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
+    def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::OpsWorksCM::Server.SubnetIds``.
 
         see
@@ -462,8 +480,8 @@ class CfnServer(
         """
         return jsii.get(self, "subnetIds")
 
-    @subnet_ids.setter
-    def subnet_ids(self, value: typing.Optional[typing.List[str]]) -> None:
+    @subnet_ids.setter # type: ignore
+    def subnet_ids(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
         jsii.set(self, "subnetIds", value)
 
     @jsii.data_type(
@@ -475,8 +493,8 @@ class CfnServer(
         def __init__(
             self,
             *,
-            name: typing.Optional[str] = None,
-            value: typing.Optional[str] = None,
+            name: typing.Optional[builtins.str] = None,
+            value: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param name: ``CfnServer.EngineAttributeProperty.Name``.
@@ -485,34 +503,36 @@ class CfnServer(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opsworkscm-server-engineattribute.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if name is not None:
                 self._values["name"] = name
             if value is not None:
                 self._values["value"] = value
 
         @builtins.property
-        def name(self) -> typing.Optional[str]:
+        def name(self) -> typing.Optional[builtins.str]:
             """``CfnServer.EngineAttributeProperty.Name``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opsworkscm-server-engineattribute.html#cfn-opsworkscm-server-engineattribute-name
             """
-            return self._values.get("name")
+            result = self._values.get("name")
+            return result
 
         @builtins.property
-        def value(self) -> typing.Optional[str]:
+        def value(self) -> typing.Optional[builtins.str]:
             """``CfnServer.EngineAttributeProperty.Value``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opsworkscm-server-engineattribute.html#cfn-opsworkscm-server-engineattribute-value
             """
-            return self._values.get("value")
+            result = self._values.get("value")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -552,26 +572,26 @@ class CfnServerProps:
     def __init__(
         self,
         *,
-        instance_profile_arn: str,
-        instance_type: str,
-        service_role_arn: str,
-        associate_public_ip_address: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        backup_id: typing.Optional[str] = None,
+        instance_profile_arn: builtins.str,
+        instance_type: builtins.str,
+        service_role_arn: builtins.str,
+        associate_public_ip_address: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        backup_id: typing.Optional[builtins.str] = None,
         backup_retention_count: typing.Optional[jsii.Number] = None,
-        custom_certificate: typing.Optional[str] = None,
-        custom_domain: typing.Optional[str] = None,
-        custom_private_key: typing.Optional[str] = None,
-        disable_automated_backup: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        engine: typing.Optional[str] = None,
+        custom_certificate: typing.Optional[builtins.str] = None,
+        custom_domain: typing.Optional[builtins.str] = None,
+        custom_private_key: typing.Optional[builtins.str] = None,
+        disable_automated_backup: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        engine: typing.Optional[builtins.str] = None,
         engine_attributes: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnServer.EngineAttributeProperty", _IResolvable_9ceae33e]]]] = None,
-        engine_model: typing.Optional[str] = None,
-        engine_version: typing.Optional[str] = None,
-        key_pair: typing.Optional[str] = None,
-        preferred_backup_window: typing.Optional[str] = None,
-        preferred_maintenance_window: typing.Optional[str] = None,
-        security_group_ids: typing.Optional[typing.List[str]] = None,
-        server_name: typing.Optional[str] = None,
-        subnet_ids: typing.Optional[typing.List[str]] = None,
+        engine_model: typing.Optional[builtins.str] = None,
+        engine_version: typing.Optional[builtins.str] = None,
+        key_pair: typing.Optional[builtins.str] = None,
+        preferred_backup_window: typing.Optional[builtins.str] = None,
+        preferred_maintenance_window: typing.Optional[builtins.str] = None,
+        security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
+        server_name: typing.Optional[builtins.str] = None,
+        subnet_ids: typing.Optional[typing.List[builtins.str]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::OpsWorksCM::Server``.
@@ -601,7 +621,7 @@ class CfnServerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "instance_profile_arn": instance_profile_arn,
             "instance_type": instance_type,
             "service_role_arn": service_role_arn,
@@ -644,51 +664,59 @@ class CfnServerProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def instance_profile_arn(self) -> str:
+    def instance_profile_arn(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.InstanceProfileArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-instanceprofilearn
         """
-        return self._values.get("instance_profile_arn")
+        result = self._values.get("instance_profile_arn")
+        assert result is not None, "Required property 'instance_profile_arn' is missing"
+        return result
 
     @builtins.property
-    def instance_type(self) -> str:
+    def instance_type(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.InstanceType``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-instancetype
         """
-        return self._values.get("instance_type")
+        result = self._values.get("instance_type")
+        assert result is not None, "Required property 'instance_type' is missing"
+        return result
 
     @builtins.property
-    def service_role_arn(self) -> str:
+    def service_role_arn(self) -> builtins.str:
         """``AWS::OpsWorksCM::Server.ServiceRoleArn``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-servicerolearn
         """
-        return self._values.get("service_role_arn")
+        result = self._values.get("service_role_arn")
+        assert result is not None, "Required property 'service_role_arn' is missing"
+        return result
 
     @builtins.property
     def associate_public_ip_address(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::OpsWorksCM::Server.AssociatePublicIpAddress``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-associatepublicipaddress
         """
-        return self._values.get("associate_public_ip_address")
+        result = self._values.get("associate_public_ip_address")
+        return result
 
     @builtins.property
-    def backup_id(self) -> typing.Optional[str]:
+    def backup_id(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.BackupId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-backupid
         """
-        return self._values.get("backup_id")
+        result = self._values.get("backup_id")
+        return result
 
     @builtins.property
     def backup_retention_count(self) -> typing.Optional[jsii.Number]:
@@ -697,54 +725,60 @@ class CfnServerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-backupretentioncount
         """
-        return self._values.get("backup_retention_count")
+        result = self._values.get("backup_retention_count")
+        return result
 
     @builtins.property
-    def custom_certificate(self) -> typing.Optional[str]:
+    def custom_certificate(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomCertificate``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-customcertificate
         """
-        return self._values.get("custom_certificate")
+        result = self._values.get("custom_certificate")
+        return result
 
     @builtins.property
-    def custom_domain(self) -> typing.Optional[str]:
+    def custom_domain(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomDomain``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-customdomain
         """
-        return self._values.get("custom_domain")
+        result = self._values.get("custom_domain")
+        return result
 
     @builtins.property
-    def custom_private_key(self) -> typing.Optional[str]:
+    def custom_private_key(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.CustomPrivateKey``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-customprivatekey
         """
-        return self._values.get("custom_private_key")
+        result = self._values.get("custom_private_key")
+        return result
 
     @builtins.property
     def disable_automated_backup(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::OpsWorksCM::Server.DisableAutomatedBackup``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-disableautomatedbackup
         """
-        return self._values.get("disable_automated_backup")
+        result = self._values.get("disable_automated_backup")
+        return result
 
     @builtins.property
-    def engine(self) -> typing.Optional[str]:
+    def engine(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.Engine``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-engine
         """
-        return self._values.get("engine")
+        result = self._values.get("engine")
+        return result
 
     @builtins.property
     def engine_attributes(
@@ -755,79 +789,88 @@ class CfnServerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-engineattributes
         """
-        return self._values.get("engine_attributes")
+        result = self._values.get("engine_attributes")
+        return result
 
     @builtins.property
-    def engine_model(self) -> typing.Optional[str]:
+    def engine_model(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.EngineModel``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-enginemodel
         """
-        return self._values.get("engine_model")
+        result = self._values.get("engine_model")
+        return result
 
     @builtins.property
-    def engine_version(self) -> typing.Optional[str]:
+    def engine_version(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.EngineVersion``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-engineversion
         """
-        return self._values.get("engine_version")
+        result = self._values.get("engine_version")
+        return result
 
     @builtins.property
-    def key_pair(self) -> typing.Optional[str]:
+    def key_pair(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.KeyPair``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-keypair
         """
-        return self._values.get("key_pair")
+        result = self._values.get("key_pair")
+        return result
 
     @builtins.property
-    def preferred_backup_window(self) -> typing.Optional[str]:
+    def preferred_backup_window(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.PreferredBackupWindow``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-preferredbackupwindow
         """
-        return self._values.get("preferred_backup_window")
+        result = self._values.get("preferred_backup_window")
+        return result
 
     @builtins.property
-    def preferred_maintenance_window(self) -> typing.Optional[str]:
+    def preferred_maintenance_window(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.PreferredMaintenanceWindow``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-preferredmaintenancewindow
         """
-        return self._values.get("preferred_maintenance_window")
+        result = self._values.get("preferred_maintenance_window")
+        return result
 
     @builtins.property
-    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
+    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::OpsWorksCM::Server.SecurityGroupIds``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-securitygroupids
         """
-        return self._values.get("security_group_ids")
+        result = self._values.get("security_group_ids")
+        return result
 
     @builtins.property
-    def server_name(self) -> typing.Optional[str]:
+    def server_name(self) -> typing.Optional[builtins.str]:
         """``AWS::OpsWorksCM::Server.ServerName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-servername
         """
-        return self._values.get("server_name")
+        result = self._values.get("server_name")
+        return result
 
     @builtins.property
-    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
+    def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::OpsWorksCM::Server.SubnetIds``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-subnetids
         """
-        return self._values.get("subnet_ids")
+        result = self._values.get("subnet_ids")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -836,12 +879,13 @@ class CfnServerProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworkscm-server.html#cfn-opsworkscm-server-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
