@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -37,10 +37,10 @@ class CfnGroup(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        name: str,
-        description: typing.Optional[str] = None,
+        name: builtins.str,
+        description: typing.Optional[builtins.str] = None,
         resource_query: typing.Optional[typing.Union["ResourceQueryProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Any = None,
     ) -> None:
@@ -75,34 +75,35 @@ class CfnGroup(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="attrArn")
-    def attr_arn(self) -> str:
+    def attr_arn(self) -> builtins.str:
         """
         cloudformationAttribute:
         :cloudformationAttribute:: Arn
         """
         return jsii.get(self, "attrArn")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::ResourceGroups::Group.Tags``.
@@ -112,9 +113,9 @@ class CfnGroup(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::ResourceGroups::Group.Name``.
 
         see
@@ -122,13 +123,13 @@ class CfnGroup(
         """
         return jsii.get(self, "name")
 
-    @name.setter
-    def name(self, value: str) -> None:
+    @name.setter # type: ignore
+    def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="description")
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::ResourceGroups::Group.Description``.
 
         see
@@ -136,11 +137,11 @@ class CfnGroup(
         """
         return jsii.get(self, "description")
 
-    @description.setter
-    def description(self, value: typing.Optional[str]) -> None:
+    @description.setter # type: ignore
+    def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="resourceQuery")
     def resource_query(
         self,
@@ -152,7 +153,7 @@ class CfnGroup(
         """
         return jsii.get(self, "resourceQuery")
 
-    @resource_query.setter
+    @resource_query.setter # type: ignore
     def resource_query(
         self,
         value: typing.Optional[typing.Union["ResourceQueryProperty", _IResolvable_9ceae33e]],
@@ -172,8 +173,8 @@ class CfnGroup(
         def __init__(
             self,
             *,
-            resource_type_filters: typing.Optional[typing.List[str]] = None,
-            stack_identifier: typing.Optional[str] = None,
+            resource_type_filters: typing.Optional[typing.List[builtins.str]] = None,
+            stack_identifier: typing.Optional[builtins.str] = None,
             tag_filters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnGroup.TagFilterProperty", _IResolvable_9ceae33e]]]] = None,
         ) -> None:
             """
@@ -184,7 +185,7 @@ class CfnGroup(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourcegroups-group-query.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if resource_type_filters is not None:
                 self._values["resource_type_filters"] = resource_type_filters
             if stack_identifier is not None:
@@ -193,22 +194,24 @@ class CfnGroup(
                 self._values["tag_filters"] = tag_filters
 
         @builtins.property
-        def resource_type_filters(self) -> typing.Optional[typing.List[str]]:
+        def resource_type_filters(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnGroup.QueryProperty.ResourceTypeFilters``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourcegroups-group-query.html#cfn-resourcegroups-group-query-resourcetypefilters
             """
-            return self._values.get("resource_type_filters")
+            result = self._values.get("resource_type_filters")
+            return result
 
         @builtins.property
-        def stack_identifier(self) -> typing.Optional[str]:
+        def stack_identifier(self) -> typing.Optional[builtins.str]:
             """``CfnGroup.QueryProperty.StackIdentifier``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourcegroups-group-query.html#cfn-resourcegroups-group-query-stackidentifier
             """
-            return self._values.get("stack_identifier")
+            result = self._values.get("stack_identifier")
+            return result
 
         @builtins.property
         def tag_filters(
@@ -219,12 +222,13 @@ class CfnGroup(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourcegroups-group-query.html#cfn-resourcegroups-group-query-tagfilters
             """
-            return self._values.get("tag_filters")
+            result = self._values.get("tag_filters")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -242,7 +246,7 @@ class CfnGroup(
             self,
             *,
             query: typing.Optional[typing.Union["CfnGroup.QueryProperty", _IResolvable_9ceae33e]] = None,
-            type: typing.Optional[str] = None,
+            type: typing.Optional[builtins.str] = None,
         ) -> None:
             """
             :param query: ``CfnGroup.ResourceQueryProperty.Query``.
@@ -251,7 +255,7 @@ class CfnGroup(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourcegroups-group-resourcequery.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if query is not None:
                 self._values["query"] = query
             if type is not None:
@@ -266,21 +270,23 @@ class CfnGroup(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourcegroups-group-resourcequery.html#cfn-resourcegroups-group-resourcequery-query
             """
-            return self._values.get("query")
+            result = self._values.get("query")
+            return result
 
         @builtins.property
-        def type(self) -> typing.Optional[str]:
+        def type(self) -> typing.Optional[builtins.str]:
             """``CfnGroup.ResourceQueryProperty.Type``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourcegroups-group-resourcequery.html#cfn-resourcegroups-group-resourcequery-type
             """
-            return self._values.get("type")
+            result = self._values.get("type")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -297,8 +303,8 @@ class CfnGroup(
         def __init__(
             self,
             *,
-            key: typing.Optional[str] = None,
-            values: typing.Optional[typing.List[str]] = None,
+            key: typing.Optional[builtins.str] = None,
+            values: typing.Optional[typing.List[builtins.str]] = None,
         ) -> None:
             """
             :param key: ``CfnGroup.TagFilterProperty.Key``.
@@ -307,34 +313,36 @@ class CfnGroup(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourcegroups-group-tagfilter.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if key is not None:
                 self._values["key"] = key
             if values is not None:
                 self._values["values"] = values
 
         @builtins.property
-        def key(self) -> typing.Optional[str]:
+        def key(self) -> typing.Optional[builtins.str]:
             """``CfnGroup.TagFilterProperty.Key``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourcegroups-group-tagfilter.html#cfn-resourcegroups-group-tagfilter-key
             """
-            return self._values.get("key")
+            result = self._values.get("key")
+            return result
 
         @builtins.property
-        def values(self) -> typing.Optional[typing.List[str]]:
+        def values(self) -> typing.Optional[typing.List[builtins.str]]:
             """``CfnGroup.TagFilterProperty.Values``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resourcegroups-group-tagfilter.html#cfn-resourcegroups-group-tagfilter-values
             """
-            return self._values.get("values")
+            result = self._values.get("values")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -357,8 +365,8 @@ class CfnGroupProps:
     def __init__(
         self,
         *,
-        name: str,
-        description: typing.Optional[str] = None,
+        name: builtins.str,
+        description: typing.Optional[builtins.str] = None,
         resource_query: typing.Optional[typing.Union["CfnGroup.ResourceQueryProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Any = None,
     ) -> None:
@@ -372,7 +380,7 @@ class CfnGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-resourcegroups-group.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "name": name,
         }
         if description is not None:
@@ -383,22 +391,25 @@ class CfnGroupProps:
             self._values["tags"] = tags
 
     @builtins.property
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """``AWS::ResourceGroups::Group.Name``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-resourcegroups-group.html#cfn-resourcegroups-group-name
         """
-        return self._values.get("name")
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return result
 
     @builtins.property
-    def description(self) -> typing.Optional[str]:
+    def description(self) -> typing.Optional[builtins.str]:
         """``AWS::ResourceGroups::Group.Description``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-resourcegroups-group.html#cfn-resourcegroups-group-description
         """
-        return self._values.get("description")
+        result = self._values.get("description")
+        return result
 
     @builtins.property
     def resource_query(
@@ -409,7 +420,8 @@ class CfnGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-resourcegroups-group.html#cfn-resourcegroups-group-resourcequery
         """
-        return self._values.get("resource_query")
+        result = self._values.get("resource_query")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Any:
@@ -418,12 +430,13 @@ class CfnGroupProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-resourcegroups-group.html#cfn-resourcegroups-group-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
