@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -148,7 +148,7 @@ class CloudFrontTarget(
 
     @jsii.member(jsii_name="getHostedZoneId")
     @builtins.classmethod
-    def get_hosted_zone_id(cls, scope: _IConstruct_db0cc7e3) -> str:
+    def get_hosted_zone_id(cls, scope: _IConstruct_db0cc7e3) -> builtins.str:
         """Get the hosted zone id for the current scope.
 
         :param scope: - scope in which this resource is defined.
@@ -169,9 +169,9 @@ class CloudFrontTarget(
         """
         return jsii.invoke(self, "bind", [_record])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CLOUDFRONT_ZONE_ID")
-    def CLOUDFRONT_ZONE_ID(cls) -> str:
+    def CLOUDFRONT_ZONE_ID(cls) -> builtins.str:
         """The hosted zone Id if using an alias record in Route53.
 
         This value never changes.
