@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -40,14 +40,14 @@ class Asset(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        path: str,
+        path: builtins.str,
         readers: typing.Optional[typing.List[_IGrantable_0fcfc53a]] = None,
-        source_hash: typing.Optional[str] = None,
-        exclude: typing.Optional[typing.List[str]] = None,
+        source_hash: typing.Optional[builtins.str] = None,
+        exclude: typing.Optional[typing.List[builtins.str]] = None,
         follow: typing.Optional[_FollowMode_f74e7125] = None,
-        asset_hash: typing.Optional[str] = None,
+        asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_16f7047a] = None,
         bundling: typing.Optional[_BundlingOptions_0cab5223] = None,
     ) -> None:
@@ -81,7 +81,9 @@ class Asset(
 
     @jsii.member(jsii_name="addResourceMetadata")
     def add_resource_metadata(
-        self, resource: _CfnResource_7760e8e4, resource_property: str
+        self,
+        resource: _CfnResource_7760e8e4,
+        resource_property: builtins.str,
     ) -> None:
         """Adds CloudFormation template metadata to the specified resource with information that indicates which resource property is mapped to this local asset.
 
@@ -113,9 +115,9 @@ class Asset(
         """
         return jsii.invoke(self, "grantRead", [grantee])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="assetHash")
-    def asset_hash(self) -> str:
+    def asset_hash(self) -> builtins.str:
         """A hash of this asset, which is available at construction time.
 
         As this is a plain string, it
@@ -127,9 +129,9 @@ class Asset(
         """
         return jsii.get(self, "assetHash")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="assetPath")
-    def asset_path(self) -> str:
+    def asset_path(self) -> builtins.str:
         """The path to the asset (stringinfied token).
 
         If asset staging is disabled, this will just be the original path.
@@ -140,7 +142,7 @@ class Asset(
         """
         return jsii.get(self, "assetPath")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="bucket")
     def bucket(self) -> _IBucket_25bad983:
         """The S3 bucket in which this asset resides.
@@ -150,9 +152,9 @@ class Asset(
         """
         return jsii.get(self, "bucket")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="httpUrl")
-    def http_url(self) -> str:
+    def http_url(self) -> builtins.str:
         """Attribute which represents the S3 HTTP URL of this asset.
 
         stability
@@ -165,9 +167,9 @@ class Asset(
         """
         return jsii.get(self, "httpUrl")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="isZipArchive")
-    def is_zip_archive(self) -> bool:
+    def is_zip_archive(self) -> builtins.bool:
         """Indicates if this asset is a zip archive.
 
         Allows constructs to ensure that the
@@ -178,9 +180,9 @@ class Asset(
         """
         return jsii.get(self, "isZipArchive")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="s3BucketName")
-    def s3_bucket_name(self) -> str:
+    def s3_bucket_name(self) -> builtins.str:
         """Attribute that represents the name of the bucket this asset exists in.
 
         stability
@@ -188,9 +190,9 @@ class Asset(
         """
         return jsii.get(self, "s3BucketName")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="s3ObjectKey")
-    def s3_object_key(self) -> str:
+    def s3_object_key(self) -> builtins.str:
         """Attribute which represents the S3 object key of this asset.
 
         stability
@@ -198,9 +200,9 @@ class Asset(
         """
         return jsii.get(self, "s3ObjectKey")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="s3ObjectUrl")
-    def s3_object_url(self) -> str:
+    def s3_object_url(self) -> builtins.str:
         """Attribute which represents the S3 URL of this asset.
 
         stability
@@ -213,9 +215,9 @@ class Asset(
         """
         return jsii.get(self, "s3ObjectUrl")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="s3Url")
-    def s3_url(self) -> str:
+    def s3_url(self) -> builtins.str:
         """Attribute which represents the S3 URL of this asset.
 
         deprecated
@@ -226,9 +228,9 @@ class Asset(
         """
         return jsii.get(self, "s3Url")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="sourceHash")
-    def source_hash(self) -> str:
+    def source_hash(self) -> builtins.str:
         """A cryptographic hash of the asset.
 
         deprecated
@@ -257,13 +259,13 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
     def __init__(
         self,
         *,
-        exclude: typing.Optional[typing.List[str]] = None,
+        exclude: typing.Optional[typing.List[builtins.str]] = None,
         follow: typing.Optional[_FollowMode_f74e7125] = None,
-        asset_hash: typing.Optional[str] = None,
+        asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_16f7047a] = None,
         bundling: typing.Optional[_BundlingOptions_0cab5223] = None,
         readers: typing.Optional[typing.List[_IGrantable_0fcfc53a]] = None,
-        source_hash: typing.Optional[str] = None,
+        source_hash: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
@@ -279,7 +281,7 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         """
         if isinstance(bundling, dict):
             bundling = _BundlingOptions_0cab5223(**bundling)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if exclude is not None:
             self._values["exclude"] = exclude
         if follow is not None:
@@ -296,7 +298,7 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
             self._values["source_hash"] = source_hash
 
     @builtins.property
-    def exclude(self) -> typing.Optional[typing.List[str]]:
+    def exclude(self) -> typing.Optional[typing.List[builtins.str]]:
         """Glob patterns to exclude from the copy.
 
         default
@@ -305,7 +307,8 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: deprecated
         """
-        return self._values.get("exclude")
+        result = self._values.get("exclude")
+        return result
 
     @builtins.property
     def follow(self) -> typing.Optional[_FollowMode_f74e7125]:
@@ -317,10 +320,11 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: deprecated
         """
-        return self._values.get("follow")
+        result = self._values.get("follow")
+        return result
 
     @builtins.property
-    def asset_hash(self) -> typing.Optional[str]:
+    def asset_hash(self) -> typing.Optional[builtins.str]:
         """Specify a custom hash for this asset.
 
         If ``assetHashType`` is set it must
@@ -340,7 +344,8 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: experimental
         """
-        return self._values.get("asset_hash")
+        result = self._values.get("asset_hash")
+        return result
 
     @builtins.property
     def asset_hash_type(self) -> typing.Optional[_AssetHashType_16f7047a]:
@@ -358,7 +363,8 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: experimental
         """
-        return self._values.get("asset_hash_type")
+        result = self._values.get("asset_hash_type")
+        return result
 
     @builtins.property
     def bundling(self) -> typing.Optional[_BundlingOptions_0cab5223]:
@@ -378,7 +384,8 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: experimental
         """
-        return self._values.get("bundling")
+        result = self._values.get("bundling")
+        return result
 
     @builtins.property
     def readers(self) -> typing.Optional[typing.List[_IGrantable_0fcfc53a]]:
@@ -392,10 +399,11 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: experimental
         """
-        return self._values.get("readers")
+        result = self._values.get("readers")
+        return result
 
     @builtins.property
-    def source_hash(self) -> typing.Optional[str]:
+    def source_hash(self) -> typing.Optional[builtins.str]:
         """Custom hash to use when identifying the specific version of the asset.
 
         For consistency,
@@ -420,12 +428,13 @@ class AssetOptions(_CopyOptions_65085089, _AssetOptions_b07b0eef):
         stability
         :stability: deprecated
         """
-        return self._values.get("source_hash")
+        result = self._values.get("source_hash")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -452,14 +461,14 @@ class AssetProps(AssetOptions):
     def __init__(
         self,
         *,
-        exclude: typing.Optional[typing.List[str]] = None,
+        exclude: typing.Optional[typing.List[builtins.str]] = None,
         follow: typing.Optional[_FollowMode_f74e7125] = None,
-        asset_hash: typing.Optional[str] = None,
+        asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_16f7047a] = None,
         bundling: typing.Optional[_BundlingOptions_0cab5223] = None,
         readers: typing.Optional[typing.List[_IGrantable_0fcfc53a]] = None,
-        source_hash: typing.Optional[str] = None,
-        path: str,
+        source_hash: typing.Optional[builtins.str] = None,
+        path: builtins.str,
     ) -> None:
         """
         :param exclude: Glob patterns to exclude from the copy. Default: nothing is excluded
@@ -476,7 +485,7 @@ class AssetProps(AssetOptions):
         """
         if isinstance(bundling, dict):
             bundling = _BundlingOptions_0cab5223(**bundling)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "path": path,
         }
         if exclude is not None:
@@ -495,7 +504,7 @@ class AssetProps(AssetOptions):
             self._values["source_hash"] = source_hash
 
     @builtins.property
-    def exclude(self) -> typing.Optional[typing.List[str]]:
+    def exclude(self) -> typing.Optional[typing.List[builtins.str]]:
         """Glob patterns to exclude from the copy.
 
         default
@@ -504,7 +513,8 @@ class AssetProps(AssetOptions):
         stability
         :stability: deprecated
         """
-        return self._values.get("exclude")
+        result = self._values.get("exclude")
+        return result
 
     @builtins.property
     def follow(self) -> typing.Optional[_FollowMode_f74e7125]:
@@ -516,10 +526,11 @@ class AssetProps(AssetOptions):
         stability
         :stability: deprecated
         """
-        return self._values.get("follow")
+        result = self._values.get("follow")
+        return result
 
     @builtins.property
-    def asset_hash(self) -> typing.Optional[str]:
+    def asset_hash(self) -> typing.Optional[builtins.str]:
         """Specify a custom hash for this asset.
 
         If ``assetHashType`` is set it must
@@ -539,7 +550,8 @@ class AssetProps(AssetOptions):
         stability
         :stability: experimental
         """
-        return self._values.get("asset_hash")
+        result = self._values.get("asset_hash")
+        return result
 
     @builtins.property
     def asset_hash_type(self) -> typing.Optional[_AssetHashType_16f7047a]:
@@ -557,7 +569,8 @@ class AssetProps(AssetOptions):
         stability
         :stability: experimental
         """
-        return self._values.get("asset_hash_type")
+        result = self._values.get("asset_hash_type")
+        return result
 
     @builtins.property
     def bundling(self) -> typing.Optional[_BundlingOptions_0cab5223]:
@@ -577,7 +590,8 @@ class AssetProps(AssetOptions):
         stability
         :stability: experimental
         """
-        return self._values.get("bundling")
+        result = self._values.get("bundling")
+        return result
 
     @builtins.property
     def readers(self) -> typing.Optional[typing.List[_IGrantable_0fcfc53a]]:
@@ -591,10 +605,11 @@ class AssetProps(AssetOptions):
         stability
         :stability: experimental
         """
-        return self._values.get("readers")
+        result = self._values.get("readers")
+        return result
 
     @builtins.property
-    def source_hash(self) -> typing.Optional[str]:
+    def source_hash(self) -> typing.Optional[builtins.str]:
         """Custom hash to use when identifying the specific version of the asset.
 
         For consistency,
@@ -619,10 +634,11 @@ class AssetProps(AssetOptions):
         stability
         :stability: deprecated
         """
-        return self._values.get("source_hash")
+        result = self._values.get("source_hash")
+        return result
 
     @builtins.property
-    def path(self) -> str:
+    def path(self) -> builtins.str:
         """The disk location of the asset.
 
         The path should refer to one of the following:
@@ -633,12 +649,14 @@ class AssetProps(AssetOptions):
         stability
         :stability: experimental
         """
-        return self._values.get("path")
+        result = self._values.get("path")
+        assert result is not None, "Required property 'path' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
