@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -37,29 +37,29 @@ class BucketDeployment(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         destination_bucket: _IBucket_25bad983,
         sources: typing.List["ISource"],
         cache_control: typing.Optional[typing.List["CacheControl"]] = None,
-        content_disposition: typing.Optional[str] = None,
-        content_encoding: typing.Optional[str] = None,
-        content_language: typing.Optional[str] = None,
-        content_type: typing.Optional[str] = None,
-        destination_key_prefix: typing.Optional[str] = None,
+        content_disposition: typing.Optional[builtins.str] = None,
+        content_encoding: typing.Optional[builtins.str] = None,
+        content_language: typing.Optional[builtins.str] = None,
+        content_type: typing.Optional[builtins.str] = None,
+        destination_key_prefix: typing.Optional[builtins.str] = None,
         distribution: typing.Optional[_IDistribution_0af1f2d0] = None,
-        distribution_paths: typing.Optional[typing.List[str]] = None,
+        distribution_paths: typing.Optional[typing.List[builtins.str]] = None,
         expires: typing.Optional[_Expiration_a422b4f1] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
         metadata: typing.Optional["UserDefinedObjectMetadata"] = None,
-        prune: typing.Optional[bool] = None,
-        retain_on_delete: typing.Optional[bool] = None,
+        prune: typing.Optional[builtins.bool] = None,
+        retain_on_delete: typing.Optional[builtins.bool] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
         server_side_encryption: typing.Optional["ServerSideEncryption"] = None,
-        server_side_encryption_aws_kms_key_id: typing.Optional[str] = None,
-        server_side_encryption_customer_algorithm: typing.Optional[str] = None,
+        server_side_encryption_aws_kms_key_id: typing.Optional[builtins.str] = None,
+        server_side_encryption_customer_algorithm: typing.Optional[builtins.str] = None,
         storage_class: typing.Optional["StorageClass"] = None,
-        website_redirect_location: typing.Optional[str] = None,
+        website_redirect_location: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param scope: -
@@ -150,24 +150,24 @@ class BucketDeploymentProps:
         destination_bucket: _IBucket_25bad983,
         sources: typing.List["ISource"],
         cache_control: typing.Optional[typing.List["CacheControl"]] = None,
-        content_disposition: typing.Optional[str] = None,
-        content_encoding: typing.Optional[str] = None,
-        content_language: typing.Optional[str] = None,
-        content_type: typing.Optional[str] = None,
-        destination_key_prefix: typing.Optional[str] = None,
+        content_disposition: typing.Optional[builtins.str] = None,
+        content_encoding: typing.Optional[builtins.str] = None,
+        content_language: typing.Optional[builtins.str] = None,
+        content_type: typing.Optional[builtins.str] = None,
+        destination_key_prefix: typing.Optional[builtins.str] = None,
         distribution: typing.Optional[_IDistribution_0af1f2d0] = None,
-        distribution_paths: typing.Optional[typing.List[str]] = None,
+        distribution_paths: typing.Optional[typing.List[builtins.str]] = None,
         expires: typing.Optional[_Expiration_a422b4f1] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
         metadata: typing.Optional["UserDefinedObjectMetadata"] = None,
-        prune: typing.Optional[bool] = None,
-        retain_on_delete: typing.Optional[bool] = None,
+        prune: typing.Optional[builtins.bool] = None,
+        retain_on_delete: typing.Optional[builtins.bool] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
         server_side_encryption: typing.Optional["ServerSideEncryption"] = None,
-        server_side_encryption_aws_kms_key_id: typing.Optional[str] = None,
-        server_side_encryption_customer_algorithm: typing.Optional[str] = None,
+        server_side_encryption_aws_kms_key_id: typing.Optional[builtins.str] = None,
+        server_side_encryption_customer_algorithm: typing.Optional[builtins.str] = None,
         storage_class: typing.Optional["StorageClass"] = None,
-        website_redirect_location: typing.Optional[str] = None,
+        website_redirect_location: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param destination_bucket: The S3 bucket to sync the contents of the zip file to.
@@ -197,7 +197,7 @@ class BucketDeploymentProps:
         """
         if isinstance(metadata, dict):
             metadata = UserDefinedObjectMetadata(**metadata)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "destination_bucket": destination_bucket,
             "sources": sources,
         }
@@ -247,7 +247,9 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("destination_bucket")
+        result = self._values.get("destination_bucket")
+        assert result is not None, "Required property 'destination_bucket' is missing"
+        return result
 
     @builtins.property
     def sources(self) -> typing.List["ISource"]:
@@ -256,7 +258,9 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("sources")
+        result = self._values.get("sources")
+        assert result is not None, "Required property 'sources' is missing"
+        return result
 
     @builtins.property
     def cache_control(self) -> typing.Optional[typing.List["CacheControl"]]:
@@ -270,10 +274,11 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("cache_control")
+        result = self._values.get("cache_control")
+        return result
 
     @builtins.property
-    def content_disposition(self) -> typing.Optional[str]:
+    def content_disposition(self) -> typing.Optional[builtins.str]:
         """System-defined cache-disposition metadata to be set on all objects in the deployment.
 
         default
@@ -284,10 +289,11 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("content_disposition")
+        result = self._values.get("content_disposition")
+        return result
 
     @builtins.property
-    def content_encoding(self) -> typing.Optional[str]:
+    def content_encoding(self) -> typing.Optional[builtins.str]:
         """System-defined content-encoding metadata to be set on all objects in the deployment.
 
         default
@@ -298,10 +304,11 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("content_encoding")
+        result = self._values.get("content_encoding")
+        return result
 
     @builtins.property
-    def content_language(self) -> typing.Optional[str]:
+    def content_language(self) -> typing.Optional[builtins.str]:
         """System-defined content-language metadata to be set on all objects in the deployment.
 
         default
@@ -312,10 +319,11 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("content_language")
+        result = self._values.get("content_language")
+        return result
 
     @builtins.property
-    def content_type(self) -> typing.Optional[str]:
+    def content_type(self) -> typing.Optional[builtins.str]:
         """System-defined content-type metadata to be set on all objects in the deployment.
 
         default
@@ -326,10 +334,11 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("content_type")
+        result = self._values.get("content_type")
+        return result
 
     @builtins.property
-    def destination_key_prefix(self) -> typing.Optional[str]:
+    def destination_key_prefix(self) -> typing.Optional[builtins.str]:
         """Key prefix in the destination bucket.
 
         default
@@ -338,7 +347,8 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("destination_key_prefix")
+        result = self._values.get("destination_key_prefix")
+        return result
 
     @builtins.property
     def distribution(self) -> typing.Optional[_IDistribution_0af1f2d0]:
@@ -353,10 +363,11 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("distribution")
+        result = self._values.get("distribution")
+        return result
 
     @builtins.property
-    def distribution_paths(self) -> typing.Optional[typing.List[str]]:
+    def distribution_paths(self) -> typing.Optional[typing.List[builtins.str]]:
         """The file paths to invalidate in the CloudFront distribution.
 
         default
@@ -365,7 +376,8 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("distribution_paths")
+        result = self._values.get("distribution_paths")
+        return result
 
     @builtins.property
     def expires(self) -> typing.Optional[_Expiration_a422b4f1]:
@@ -379,7 +391,8 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("expires")
+        result = self._values.get("expires")
+        return result
 
     @builtins.property
     def memory_limit(self) -> typing.Optional[jsii.Number]:
@@ -394,7 +407,8 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("memory_limit")
+        result = self._values.get("memory_limit")
+        return result
 
     @builtins.property
     def metadata(self) -> typing.Optional["UserDefinedObjectMetadata"]:
@@ -408,10 +422,11 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("metadata")
+        result = self._values.get("metadata")
+        return result
 
     @builtins.property
-    def prune(self) -> typing.Optional[bool]:
+    def prune(self) -> typing.Optional[builtins.bool]:
         """If this is set to false, files in the destination bucket that do not exist in the asset, will NOT be deleted during deployment (create/update).
 
         default
@@ -422,10 +437,11 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("prune")
+        result = self._values.get("prune")
+        return result
 
     @builtins.property
-    def retain_on_delete(self) -> typing.Optional[bool]:
+    def retain_on_delete(self) -> typing.Optional[builtins.bool]:
         """If this is set to "false", the destination files will be deleted when the resource is deleted or the destination is updated.
 
         NOTICE: if this is set to "false" and destination bucket/prefix is updated,
@@ -439,7 +455,8 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("retain_on_delete")
+        result = self._values.get("retain_on_delete")
+        return result
 
     @builtins.property
     def role(self) -> typing.Optional[_IRole_e69bbae4]:
@@ -451,7 +468,8 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("role")
+        result = self._values.get("role")
+        return result
 
     @builtins.property
     def server_side_encryption(self) -> typing.Optional["ServerSideEncryption"]:
@@ -465,10 +483,11 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("server_side_encryption")
+        result = self._values.get("server_side_encryption")
+        return result
 
     @builtins.property
-    def server_side_encryption_aws_kms_key_id(self) -> typing.Optional[str]:
+    def server_side_encryption_aws_kms_key_id(self) -> typing.Optional[builtins.str]:
         """System-defined x-amz-server-side-encryption-aws-kms-key-id metadata to be set on all objects in the deployment.
 
         default
@@ -479,10 +498,13 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("server_side_encryption_aws_kms_key_id")
+        result = self._values.get("server_side_encryption_aws_kms_key_id")
+        return result
 
     @builtins.property
-    def server_side_encryption_customer_algorithm(self) -> typing.Optional[str]:
+    def server_side_encryption_customer_algorithm(
+        self,
+    ) -> typing.Optional[builtins.str]:
         """System-defined x-amz-server-side-encryption-customer-algorithm metadata to be set on all objects in the deployment.
 
         Warning: This is not a useful parameter until this bug is fixed: https://github.com/aws/aws-cdk/issues/6080
@@ -495,7 +517,8 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("server_side_encryption_customer_algorithm")
+        result = self._values.get("server_side_encryption_customer_algorithm")
+        return result
 
     @builtins.property
     def storage_class(self) -> typing.Optional["StorageClass"]:
@@ -509,10 +532,11 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("storage_class")
+        result = self._values.get("storage_class")
+        return result
 
     @builtins.property
-    def website_redirect_location(self) -> typing.Optional[str]:
+    def website_redirect_location(self) -> typing.Optional[builtins.str]:
         """System-defined x-amz-website-redirect-location metadata to be set on all objects in the deployment.
 
         default
@@ -523,12 +547,13 @@ class BucketDeploymentProps:
         stability
         :stability: experimental
         """
-        return self._values.get("website_redirect_location")
+        result = self._values.get("website_redirect_location")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -551,7 +576,7 @@ class CacheControl(
 
     @jsii.member(jsii_name="fromString")
     @builtins.classmethod
-    def from_string(cls, s: str) -> "CacheControl":
+    def from_string(cls, s: builtins.str) -> "CacheControl":
         """
         :param s: -
 
@@ -636,7 +661,7 @@ class CacheControl(
         """
         return jsii.sinvoke(cls, "sMaxAge", [t])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="value")
     def value(self) -> typing.Any:
         """
@@ -660,7 +685,7 @@ class DeploymentSourceContext:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "handler_role": handler_role,
         }
 
@@ -671,12 +696,14 @@ class DeploymentSourceContext:
         stability
         :stability: experimental
         """
-        return self._values.get("handler_role")
+        result = self._values.get("handler_role")
+        assert result is not None, "Required property 'handler_role' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -686,7 +713,8 @@ class DeploymentSourceContext:
 
 
 class Expires(
-    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_s3_deployment.Expires"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_s3_deployment.Expires",
 ):
     """Used for HTTP expires header, which influences downstream caches.
 
@@ -739,7 +767,7 @@ class Expires(
 
     @jsii.member(jsii_name="fromString")
     @builtins.classmethod
-    def from_string(cls, s: str) -> "Expires":
+    def from_string(cls, s: builtins.str) -> "Expires":
         """
         :param s: -
 
@@ -748,7 +776,7 @@ class Expires(
         """
         return jsii.sinvoke(cls, "fromString", [s])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="value")
     def value(self) -> typing.Any:
         """
@@ -759,7 +787,7 @@ class Expires(
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_s3_deployment.ISource")
-class ISource(jsii.compat.Protocol):
+class ISource(typing_extensions.Protocol):
     """Represents a source for bucket deployments.
 
     stability
@@ -772,7 +800,10 @@ class ISource(jsii.compat.Protocol):
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, scope: _Construct_f50a3f53, *, handler_role: _IRole_e69bbae4
+        self,
+        scope: _Construct_f50a3f53,
+        *,
+        handler_role: _IRole_e69bbae4,
     ) -> "SourceConfig":
         """Binds the source to a bucket deployment.
 
@@ -792,11 +823,14 @@ class _ISourceProxy:
     :stability: experimental
     """
 
-    __jsii_type__ = "monocdk-experiment.aws_s3_deployment.ISource"
+    __jsii_type__: typing.ClassVar[str] = "monocdk-experiment.aws_s3_deployment.ISource"
 
     @jsii.member(jsii_name="bind")
     def bind(
-        self, scope: _Construct_f50a3f53, *, handler_role: _IRole_e69bbae4
+        self,
+        scope: _Construct_f50a3f53,
+        *,
+        handler_role: _IRole_e69bbae4,
     ) -> "SourceConfig":
         """Binds the source to a bucket deployment.
 
@@ -834,7 +868,8 @@ class ServerSideEncryption(enum.Enum):
 
 
 class Source(
-    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_s3_deployment.Source"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_s3_deployment.Source",
 ):
     """Specifies bucket deployment source.
 
@@ -852,13 +887,13 @@ class Source(
     @builtins.classmethod
     def asset(
         cls,
-        path: str,
+        path: builtins.str,
         *,
         readers: typing.Optional[typing.List[_IGrantable_0fcfc53a]] = None,
-        source_hash: typing.Optional[str] = None,
-        exclude: typing.Optional[typing.List[str]] = None,
+        source_hash: typing.Optional[builtins.str] = None,
+        exclude: typing.Optional[typing.List[builtins.str]] = None,
         follow: typing.Optional[_FollowMode_f74e7125] = None,
-        asset_hash: typing.Optional[str] = None,
+        asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_16f7047a] = None,
         bundling: typing.Optional[_BundlingOptions_0cab5223] = None,
     ) -> "ISource":
@@ -890,7 +925,11 @@ class Source(
 
     @jsii.member(jsii_name="bucket")
     @builtins.classmethod
-    def bucket(cls, bucket: _IBucket_25bad983, zip_object_key: str) -> "ISource":
+    def bucket(
+        cls,
+        bucket: _IBucket_25bad983,
+        zip_object_key: builtins.str,
+    ) -> "ISource":
         """Uses a .zip file stored in an S3 bucket as the source for the destination bucket contents.
 
         :param bucket: The S3 Bucket.
@@ -908,7 +947,12 @@ class Source(
     name_mapping={"bucket": "bucket", "zip_object_key": "zipObjectKey"},
 )
 class SourceConfig:
-    def __init__(self, *, bucket: _IBucket_25bad983, zip_object_key: str) -> None:
+    def __init__(
+        self,
+        *,
+        bucket: _IBucket_25bad983,
+        zip_object_key: builtins.str,
+    ) -> None:
         """
         :param bucket: The source bucket to deploy from.
         :param zip_object_key: An S3 object key in the source bucket that points to a zip file.
@@ -916,7 +960,7 @@ class SourceConfig:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "bucket": bucket,
             "zip_object_key": zip_object_key,
         }
@@ -928,21 +972,25 @@ class SourceConfig:
         stability
         :stability: experimental
         """
-        return self._values.get("bucket")
+        result = self._values.get("bucket")
+        assert result is not None, "Required property 'bucket' is missing"
+        return result
 
     @builtins.property
-    def zip_object_key(self) -> str:
+    def zip_object_key(self) -> builtins.str:
         """An S3 object key in the source bucket that points to a zip file.
 
         stability
         :stability: experimental
         """
-        return self._values.get("zip_object_key")
+        result = self._values.get("zip_object_key")
+        assert result is not None, "Required property 'zip_object_key' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -1009,12 +1057,12 @@ class UserDefinedObjectMetadata:
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
