@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -36,11 +36,11 @@ class EmailSubscription(
 
     def __init__(
         self,
-        email_address: str,
+        email_address: builtins.str,
         *,
-        json: typing.Optional[bool] = None,
+        json: typing.Optional[builtins.bool] = None,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """
         :param email_address: -
@@ -85,7 +85,7 @@ class LambdaSubscription(
         fn: _IFunction_1c1de0bc,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """
         :param fn: -
@@ -126,10 +126,10 @@ class SmsSubscription(
 
     def __init__(
         self,
-        phone_number: str,
+        phone_number: builtins.str,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """
         :param phone_number: -
@@ -172,9 +172,9 @@ class SqsSubscription(
         self,
         queue: _IQueue_b743f559,
         *,
-        raw_message_delivery: typing.Optional[bool] = None,
+        raw_message_delivery: typing.Optional[builtins.bool] = None,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """
         :param queue: -
@@ -218,7 +218,7 @@ class SubscriptionProps:
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """Options to subscribing to an SNS topic.
 
@@ -228,7 +228,7 @@ class SubscriptionProps:
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
@@ -246,12 +246,13 @@ class SubscriptionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("dead_letter_queue")
+        result = self._values.get("dead_letter_queue")
+        return result
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -260,12 +261,13 @@ class SubscriptionProps:
         stability
         :stability: experimental
         """
-        return self._values.get("filter_policy")
+        result = self._values.get("filter_policy")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -291,12 +293,12 @@ class UrlSubscription(
 
     def __init__(
         self,
-        url: str,
+        url: builtins.str,
         *,
         protocol: typing.Optional[_SubscriptionProtocol_3d1a4bcf] = None,
-        raw_message_delivery: typing.Optional[bool] = None,
+        raw_message_delivery: typing.Optional[builtins.bool] = None,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """
         :param url: -
@@ -344,9 +346,9 @@ class UrlSubscriptionProps(SubscriptionProps):
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
         protocol: typing.Optional[_SubscriptionProtocol_3d1a4bcf] = None,
-        raw_message_delivery: typing.Optional[bool] = None,
+        raw_message_delivery: typing.Optional[builtins.bool] = None,
     ) -> None:
         """Options for URL subscriptions.
 
@@ -358,7 +360,7 @@ class UrlSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
@@ -380,12 +382,13 @@ class UrlSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("dead_letter_queue")
+        result = self._values.get("dead_letter_queue")
+        return result
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -394,7 +397,8 @@ class UrlSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("filter_policy")
+        result = self._values.get("filter_policy")
+        return result
 
     @builtins.property
     def protocol(self) -> typing.Optional[_SubscriptionProtocol_3d1a4bcf]:
@@ -406,10 +410,11 @@ class UrlSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("protocol")
+        result = self._values.get("protocol")
+        return result
 
     @builtins.property
-    def raw_message_delivery(self) -> typing.Optional[bool]:
+    def raw_message_delivery(self) -> typing.Optional[builtins.bool]:
         """The message to the queue is the same as it was sent to the topic.
 
         If false, the message will be wrapped in an SNS envelope.
@@ -420,12 +425,13 @@ class UrlSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("raw_message_delivery")
+        result = self._values.get("raw_message_delivery")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -448,8 +454,8 @@ class EmailSubscriptionProps(SubscriptionProps):
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
-        json: typing.Optional[bool] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
+        json: typing.Optional[builtins.bool] = None,
     ) -> None:
         """Options for email subscriptions.
 
@@ -460,7 +466,7 @@ class EmailSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
@@ -480,12 +486,13 @@ class EmailSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("dead_letter_queue")
+        result = self._values.get("dead_letter_queue")
+        return result
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -494,10 +501,11 @@ class EmailSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("filter_policy")
+        result = self._values.get("filter_policy")
+        return result
 
     @builtins.property
-    def json(self) -> typing.Optional[bool]:
+    def json(self) -> typing.Optional[builtins.bool]:
         """Indicates if the full notification JSON should be sent to the email address or just the message text.
 
         default
@@ -506,12 +514,13 @@ class EmailSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("json")
+        result = self._values.get("json")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -533,7 +542,7 @@ class LambdaSubscriptionProps(SubscriptionProps):
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """Properties for a Lambda subscription.
 
@@ -543,7 +552,7 @@ class LambdaSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
@@ -561,12 +570,13 @@ class LambdaSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("dead_letter_queue")
+        result = self._values.get("dead_letter_queue")
+        return result
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -575,12 +585,13 @@ class LambdaSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("filter_policy")
+        result = self._values.get("filter_policy")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -602,7 +613,7 @@ class SmsSubscriptionProps(SubscriptionProps):
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
     ) -> None:
         """Options for SMS subscriptions.
 
@@ -612,7 +623,7 @@ class SmsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
@@ -630,12 +641,13 @@ class SmsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("dead_letter_queue")
+        result = self._values.get("dead_letter_queue")
+        return result
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -644,12 +656,13 @@ class SmsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("filter_policy")
+        result = self._values.get("filter_policy")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -672,8 +685,8 @@ class SqsSubscriptionProps(SubscriptionProps):
         self,
         *,
         dead_letter_queue: typing.Optional[_IQueue_b743f559] = None,
-        filter_policy: typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]] = None,
-        raw_message_delivery: typing.Optional[bool] = None,
+        filter_policy: typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]] = None,
+        raw_message_delivery: typing.Optional[builtins.bool] = None,
     ) -> None:
         """Properties for an SQS subscription.
 
@@ -684,7 +697,7 @@ class SqsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue is not None:
             self._values["dead_letter_queue"] = dead_letter_queue
         if filter_policy is not None:
@@ -704,12 +717,13 @@ class SqsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("dead_letter_queue")
+        result = self._values.get("dead_letter_queue")
+        return result
 
     @builtins.property
     def filter_policy(
         self,
-    ) -> typing.Optional[typing.Mapping[str, _SubscriptionFilter_91537200]]:
+    ) -> typing.Optional[typing.Mapping[builtins.str, _SubscriptionFilter_91537200]]:
         """The filter policy.
 
         default
@@ -718,10 +732,11 @@ class SqsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("filter_policy")
+        result = self._values.get("filter_policy")
+        return result
 
     @builtins.property
-    def raw_message_delivery(self) -> typing.Optional[bool]:
+    def raw_message_delivery(self) -> typing.Optional[builtins.bool]:
         """The message to the queue is the same as it was sent to the topic.
 
         If false, the message will be wrapped in an SNS envelope.
@@ -732,12 +747,13 @@ class SqsSubscriptionProps(SubscriptionProps):
         stability
         :stability: experimental
         """
-        return self._values.get("raw_message_delivery")
+        result = self._values.get("raw_message_delivery")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
