@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -38,15 +38,15 @@ class CfnWorkspace(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
-        bundle_id: str,
-        directory_id: str,
-        user_name: str,
-        root_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        bundle_id: builtins.str,
+        directory_id: builtins.str,
+        user_name: builtins.str,
+        root_volume_encryption_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        user_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        volume_encryption_key: typing.Optional[str] = None,
+        user_volume_encryption_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        volume_encryption_key: typing.Optional[builtins.str] = None,
         workspace_properties: typing.Optional[typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Create a new ``AWS::WorkSpaces::Workspace``.
@@ -88,25 +88,26 @@ class CfnWorkspace(
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
-        self, props: typing.Mapping[str, typing.Any]
-    ) -> typing.Mapping[str, typing.Any]:
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
         """
         :param props: -
         """
         return jsii.invoke(self, "renderProperties", [props])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_2508893f:
         """``AWS::WorkSpaces::Workspace.Tags``.
@@ -116,9 +117,9 @@ class CfnWorkspace(
         """
         return jsii.get(self, "tags")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="bundleId")
-    def bundle_id(self) -> str:
+    def bundle_id(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.BundleId``.
 
         see
@@ -126,13 +127,13 @@ class CfnWorkspace(
         """
         return jsii.get(self, "bundleId")
 
-    @bundle_id.setter
-    def bundle_id(self, value: str) -> None:
+    @bundle_id.setter # type: ignore
+    def bundle_id(self, value: builtins.str) -> None:
         jsii.set(self, "bundleId", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="directoryId")
-    def directory_id(self) -> str:
+    def directory_id(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.DirectoryId``.
 
         see
@@ -140,13 +141,13 @@ class CfnWorkspace(
         """
         return jsii.get(self, "directoryId")
 
-    @directory_id.setter
-    def directory_id(self, value: str) -> None:
+    @directory_id.setter # type: ignore
+    def directory_id(self, value: builtins.str) -> None:
         jsii.set(self, "directoryId", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="userName")
-    def user_name(self) -> str:
+    def user_name(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.UserName``.
 
         see
@@ -154,15 +155,15 @@ class CfnWorkspace(
         """
         return jsii.get(self, "userName")
 
-    @user_name.setter
-    def user_name(self, value: str) -> None:
+    @user_name.setter # type: ignore
+    def user_name(self, value: builtins.str) -> None:
         jsii.set(self, "userName", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="rootVolumeEncryptionEnabled")
     def root_volume_encryption_enabled(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.RootVolumeEncryptionEnabled``.
 
         see
@@ -170,17 +171,18 @@ class CfnWorkspace(
         """
         return jsii.get(self, "rootVolumeEncryptionEnabled")
 
-    @root_volume_encryption_enabled.setter
+    @root_volume_encryption_enabled.setter # type: ignore
     def root_volume_encryption_enabled(
-        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "rootVolumeEncryptionEnabled", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="userVolumeEncryptionEnabled")
     def user_volume_encryption_enabled(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.UserVolumeEncryptionEnabled``.
 
         see
@@ -188,15 +190,16 @@ class CfnWorkspace(
         """
         return jsii.get(self, "userVolumeEncryptionEnabled")
 
-    @user_volume_encryption_enabled.setter
+    @user_volume_encryption_enabled.setter # type: ignore
     def user_volume_encryption_enabled(
-        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+        self,
+        value: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "userVolumeEncryptionEnabled", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="volumeEncryptionKey")
-    def volume_encryption_key(self) -> typing.Optional[str]:
+    def volume_encryption_key(self) -> typing.Optional[builtins.str]:
         """``AWS::WorkSpaces::Workspace.VolumeEncryptionKey``.
 
         see
@@ -204,11 +207,11 @@ class CfnWorkspace(
         """
         return jsii.get(self, "volumeEncryptionKey")
 
-    @volume_encryption_key.setter
-    def volume_encryption_key(self, value: typing.Optional[str]) -> None:
+    @volume_encryption_key.setter # type: ignore
+    def volume_encryption_key(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "volumeEncryptionKey", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="workspaceProperties")
     def workspace_properties(
         self,
@@ -220,7 +223,7 @@ class CfnWorkspace(
         """
         return jsii.get(self, "workspaceProperties")
 
-    @workspace_properties.setter
+    @workspace_properties.setter # type: ignore
     def workspace_properties(
         self,
         value: typing.Optional[typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]],
@@ -242,9 +245,9 @@ class CfnWorkspace(
         def __init__(
             self,
             *,
-            compute_type_name: typing.Optional[str] = None,
+            compute_type_name: typing.Optional[builtins.str] = None,
             root_volume_size_gib: typing.Optional[jsii.Number] = None,
-            running_mode: typing.Optional[str] = None,
+            running_mode: typing.Optional[builtins.str] = None,
             running_mode_auto_stop_timeout_in_minutes: typing.Optional[jsii.Number] = None,
             user_volume_size_gib: typing.Optional[jsii.Number] = None,
         ) -> None:
@@ -258,7 +261,7 @@ class CfnWorkspace(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html
             """
-            self._values = {}
+            self._values: typing.Dict[str, typing.Any] = {}
             if compute_type_name is not None:
                 self._values["compute_type_name"] = compute_type_name
             if root_volume_size_gib is not None:
@@ -271,13 +274,14 @@ class CfnWorkspace(
                 self._values["user_volume_size_gib"] = user_volume_size_gib
 
         @builtins.property
-        def compute_type_name(self) -> typing.Optional[str]:
+        def compute_type_name(self) -> typing.Optional[builtins.str]:
             """``CfnWorkspace.WorkspacePropertiesProperty.ComputeTypeName``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-computetypename
             """
-            return self._values.get("compute_type_name")
+            result = self._values.get("compute_type_name")
+            return result
 
         @builtins.property
         def root_volume_size_gib(self) -> typing.Optional[jsii.Number]:
@@ -286,16 +290,18 @@ class CfnWorkspace(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-rootvolumesizegib
             """
-            return self._values.get("root_volume_size_gib")
+            result = self._values.get("root_volume_size_gib")
+            return result
 
         @builtins.property
-        def running_mode(self) -> typing.Optional[str]:
+        def running_mode(self) -> typing.Optional[builtins.str]:
             """``CfnWorkspace.WorkspacePropertiesProperty.RunningMode``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-runningmode
             """
-            return self._values.get("running_mode")
+            result = self._values.get("running_mode")
+            return result
 
         @builtins.property
         def running_mode_auto_stop_timeout_in_minutes(
@@ -306,7 +312,8 @@ class CfnWorkspace(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-runningmodeautostoptimeoutinminutes
             """
-            return self._values.get("running_mode_auto_stop_timeout_in_minutes")
+            result = self._values.get("running_mode_auto_stop_timeout_in_minutes")
+            return result
 
         @builtins.property
         def user_volume_size_gib(self) -> typing.Optional[jsii.Number]:
@@ -315,12 +322,13 @@ class CfnWorkspace(
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-uservolumesizegib
             """
-            return self._values.get("user_volume_size_gib")
+            result = self._values.get("user_volume_size_gib")
+            return result
 
-        def __eq__(self, rhs) -> bool:
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-        def __ne__(self, rhs) -> bool:
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
             return not (rhs == self)
 
         def __repr__(self) -> str:
@@ -347,13 +355,13 @@ class CfnWorkspaceProps:
     def __init__(
         self,
         *,
-        bundle_id: str,
-        directory_id: str,
-        user_name: str,
-        root_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        bundle_id: builtins.str,
+        directory_id: builtins.str,
+        user_name: builtins.str,
+        root_volume_encryption_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        user_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        volume_encryption_key: typing.Optional[str] = None,
+        user_volume_encryption_enabled: typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]] = None,
+        volume_encryption_key: typing.Optional[builtins.str] = None,
         workspace_properties: typing.Optional[typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WorkSpaces::Workspace``.
@@ -370,7 +378,7 @@ class CfnWorkspaceProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "bundle_id": bundle_id,
             "directory_id": directory_id,
             "user_name": user_name,
@@ -387,42 +395,49 @@ class CfnWorkspaceProps:
             self._values["workspace_properties"] = workspace_properties
 
     @builtins.property
-    def bundle_id(self) -> str:
+    def bundle_id(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.BundleId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-bundleid
         """
-        return self._values.get("bundle_id")
+        result = self._values.get("bundle_id")
+        assert result is not None, "Required property 'bundle_id' is missing"
+        return result
 
     @builtins.property
-    def directory_id(self) -> str:
+    def directory_id(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.DirectoryId``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-directoryid
         """
-        return self._values.get("directory_id")
+        result = self._values.get("directory_id")
+        assert result is not None, "Required property 'directory_id' is missing"
+        return result
 
     @builtins.property
-    def user_name(self) -> str:
+    def user_name(self) -> builtins.str:
         """``AWS::WorkSpaces::Workspace.UserName``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-username
         """
-        return self._values.get("user_name")
+        result = self._values.get("user_name")
+        assert result is not None, "Required property 'user_name' is missing"
+        return result
 
     @builtins.property
     def root_volume_encryption_enabled(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.RootVolumeEncryptionEnabled``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-rootvolumeencryptionenabled
         """
-        return self._values.get("root_volume_encryption_enabled")
+        result = self._values.get("root_volume_encryption_enabled")
+        return result
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -431,27 +446,30 @@ class CfnWorkspaceProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-tags
         """
-        return self._values.get("tags")
+        result = self._values.get("tags")
+        return result
 
     @builtins.property
     def user_volume_encryption_enabled(
         self,
-    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.UserVolumeEncryptionEnabled``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-uservolumeencryptionenabled
         """
-        return self._values.get("user_volume_encryption_enabled")
+        result = self._values.get("user_volume_encryption_enabled")
+        return result
 
     @builtins.property
-    def volume_encryption_key(self) -> typing.Optional[str]:
+    def volume_encryption_key(self) -> typing.Optional[builtins.str]:
         """``AWS::WorkSpaces::Workspace.VolumeEncryptionKey``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-volumeencryptionkey
         """
-        return self._values.get("volume_encryption_key")
+        result = self._values.get("volume_encryption_key")
+        return result
 
     @builtins.property
     def workspace_properties(
@@ -462,12 +480,13 @@ class CfnWorkspaceProps:
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-workspaceproperties
         """
-        return self._values.get("workspace_properties")
+        result = self._values.get("workspace_properties")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
