@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
@@ -47,16 +47,16 @@ class AwsCustomResource(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         policy: "AwsCustomResourcePolicy",
-        function_name: typing.Optional[str] = None,
-        install_latest_aws_sdk: typing.Optional[bool] = None,
+        function_name: typing.Optional[builtins.str] = None,
+        install_latest_aws_sdk: typing.Optional[builtins.bool] = None,
         log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
         on_create: typing.Optional["AwsSdkCall"] = None,
         on_delete: typing.Optional["AwsSdkCall"] = None,
         on_update: typing.Optional["AwsSdkCall"] = None,
-        resource_type: typing.Optional[str] = None,
+        resource_type: typing.Optional[builtins.str] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
         timeout: typing.Optional[_Duration_5170c158] = None,
     ) -> None:
@@ -93,7 +93,7 @@ class AwsCustomResource(
         jsii.create(AwsCustomResource, self, [scope, id, props])
 
     @jsii.member(jsii_name="getResponseField")
-    def get_response_field(self, data_path: str) -> str:
+    def get_response_field(self, data_path: builtins.str) -> builtins.str:
         """Returns response data for the AWS SDK call as string.
 
         Example for S3 / listBucket : 'Buckets.0.Name'
@@ -110,7 +110,10 @@ class AwsCustomResource(
         return jsii.invoke(self, "getResponseField", [data_path])
 
     @jsii.member(jsii_name="getResponseFieldReference")
-    def get_response_field_reference(self, data_path: str) -> _Reference_d68b1ce5:
+    def get_response_field_reference(
+        self,
+        data_path: builtins.str,
+    ) -> _Reference_d68b1ce5:
         """Returns response data for the AWS SDK call.
 
         Example for S3 / listBucket : 'Buckets.0.Name'
@@ -129,7 +132,7 @@ class AwsCustomResource(
         """
         return jsii.invoke(self, "getResponseFieldReference", [data_path])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="grantPrincipal")
     def grant_principal(self) -> _IPrincipal_97126874:
         """The principal to grant permissions to.
@@ -153,7 +156,9 @@ class AwsCustomResourcePolicy(
     @jsii.member(jsii_name="fromSdkCalls")
     @builtins.classmethod
     def from_sdk_calls(
-        cls, *, resources: typing.List[str]
+        cls,
+        *,
+        resources: typing.List[builtins.str],
     ) -> "AwsCustomResourcePolicy":
         """Generate IAM Policy Statements from the configured SDK calls.
 
@@ -171,7 +176,8 @@ class AwsCustomResourcePolicy(
     @jsii.member(jsii_name="fromStatements")
     @builtins.classmethod
     def from_statements(
-        cls, statements: typing.List[_PolicyStatement_f75dc775]
+        cls,
+        statements: typing.List[_PolicyStatement_f75dc775],
     ) -> "AwsCustomResourcePolicy":
         """Explicit IAM Policy Statements.
 
@@ -182,9 +188,9 @@ class AwsCustomResourcePolicy(
         """
         return jsii.sinvoke(cls, "fromStatements", [statements])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="ANY_RESOURCE")
-    def ANY_RESOURCE(cls) -> typing.List[str]:
+    def ANY_RESOURCE(cls) -> typing.List[builtins.str]:
         """Use this constant to configure access to any resource.
 
         stability
@@ -192,7 +198,7 @@ class AwsCustomResourcePolicy(
         """
         return jsii.sget(cls, "ANY_RESOURCE")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="statements")
     def statements(self) -> typing.List[_PolicyStatement_f75dc775]:
         """statements for explicit policy.
@@ -202,9 +208,9 @@ class AwsCustomResourcePolicy(
         """
         return jsii.get(self, "statements")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="resources")
-    def resources(self) -> typing.Optional[typing.List[str]]:
+    def resources(self) -> typing.Optional[typing.List[builtins.str]]:
         """resources for auto-generated from SDK calls.
 
         stability
@@ -234,13 +240,13 @@ class AwsCustomResourceProps:
         self,
         *,
         policy: "AwsCustomResourcePolicy",
-        function_name: typing.Optional[str] = None,
-        install_latest_aws_sdk: typing.Optional[bool] = None,
+        function_name: typing.Optional[builtins.str] = None,
+        install_latest_aws_sdk: typing.Optional[builtins.bool] = None,
         log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
         on_create: typing.Optional["AwsSdkCall"] = None,
         on_delete: typing.Optional["AwsSdkCall"] = None,
         on_update: typing.Optional["AwsSdkCall"] = None,
-        resource_type: typing.Optional[str] = None,
+        resource_type: typing.Optional[builtins.str] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
         timeout: typing.Optional[_Duration_5170c158] = None,
     ) -> None:
@@ -268,7 +274,7 @@ class AwsCustomResourceProps:
             on_delete = AwsSdkCall(**on_delete)
         if isinstance(on_update, dict):
             on_update = AwsSdkCall(**on_update)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "policy": policy,
         }
         if function_name is not None:
@@ -306,10 +312,12 @@ class AwsCustomResourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("policy")
+        result = self._values.get("policy")
+        assert result is not None, "Required property 'policy' is missing"
+        return result
 
     @builtins.property
-    def function_name(self) -> typing.Optional[str]:
+    def function_name(self) -> typing.Optional[builtins.str]:
         """A name for the Lambda function implementing this custom resource.
 
         default
@@ -321,10 +329,11 @@ class AwsCustomResourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("function_name")
+        result = self._values.get("function_name")
+        return result
 
     @builtins.property
-    def install_latest_aws_sdk(self) -> typing.Optional[bool]:
+    def install_latest_aws_sdk(self) -> typing.Optional[builtins.bool]:
         """Whether to install the latest AWS SDK v2. Allows to use the latest API calls documented at https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html.
 
         The installation takes around 60 seconds.
@@ -335,7 +344,8 @@ class AwsCustomResourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("install_latest_aws_sdk")
+        result = self._values.get("install_latest_aws_sdk")
+        return result
 
     @builtins.property
     def log_retention(self) -> typing.Optional[_RetentionDays_bdc7ad1f]:
@@ -347,7 +357,8 @@ class AwsCustomResourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("log_retention")
+        result = self._values.get("log_retention")
+        return result
 
     @builtins.property
     def on_create(self) -> typing.Optional["AwsSdkCall"]:
@@ -359,7 +370,8 @@ class AwsCustomResourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("on_create")
+        result = self._values.get("on_create")
+        return result
 
     @builtins.property
     def on_delete(self) -> typing.Optional["AwsSdkCall"]:
@@ -371,7 +383,8 @@ class AwsCustomResourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("on_delete")
+        result = self._values.get("on_delete")
+        return result
 
     @builtins.property
     def on_update(self) -> typing.Optional["AwsSdkCall"]:
@@ -383,10 +396,11 @@ class AwsCustomResourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("on_update")
+        result = self._values.get("on_update")
+        return result
 
     @builtins.property
-    def resource_type(self) -> typing.Optional[str]:
+    def resource_type(self) -> typing.Optional[builtins.str]:
         """Cloudformation Resource type.
 
         default
@@ -395,7 +409,8 @@ class AwsCustomResourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("resource_type")
+        result = self._values.get("resource_type")
+        return result
 
     @builtins.property
     def role(self) -> typing.Optional[_IRole_e69bbae4]:
@@ -411,7 +426,8 @@ class AwsCustomResourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("role")
+        result = self._values.get("role")
+        return result
 
     @builtins.property
     def timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -423,12 +439,13 @@ class AwsCustomResourceProps:
         stability
         :stability: experimental
         """
-        return self._values.get("timeout")
+        result = self._values.get("timeout")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -455,14 +472,14 @@ class AwsSdkCall:
     def __init__(
         self,
         *,
-        action: str,
-        service: str,
-        api_version: typing.Optional[str] = None,
-        ignore_error_codes_matching: typing.Optional[str] = None,
-        output_path: typing.Optional[str] = None,
+        action: builtins.str,
+        service: builtins.str,
+        api_version: typing.Optional[builtins.str] = None,
+        ignore_error_codes_matching: typing.Optional[builtins.str] = None,
+        output_path: typing.Optional[builtins.str] = None,
         parameters: typing.Any = None,
         physical_resource_id: typing.Optional["PhysicalResourceId"] = None,
-        region: typing.Optional[str] = None,
+        region: typing.Optional[builtins.str] = None,
     ) -> None:
         """An AWS SDK call.
 
@@ -478,7 +495,7 @@ class AwsSdkCall:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "action": action,
             "service": service,
         }
@@ -496,7 +513,7 @@ class AwsSdkCall:
             self._values["region"] = region
 
     @builtins.property
-    def action(self) -> str:
+    def action(self) -> builtins.str:
         """The service action to call.
 
         see
@@ -504,10 +521,12 @@ class AwsSdkCall:
         stability
         :stability: experimental
         """
-        return self._values.get("action")
+        result = self._values.get("action")
+        assert result is not None, "Required property 'action' is missing"
+        return result
 
     @builtins.property
-    def service(self) -> str:
+    def service(self) -> builtins.str:
         """The service to call.
 
         see
@@ -515,10 +534,12 @@ class AwsSdkCall:
         stability
         :stability: experimental
         """
-        return self._values.get("service")
+        result = self._values.get("service")
+        assert result is not None, "Required property 'service' is missing"
+        return result
 
     @builtins.property
-    def api_version(self) -> typing.Optional[str]:
+    def api_version(self) -> typing.Optional[builtins.str]:
         """API version to use for the service.
 
         default
@@ -529,10 +550,11 @@ class AwsSdkCall:
         stability
         :stability: experimental
         """
-        return self._values.get("api_version")
+        result = self._values.get("api_version")
+        return result
 
     @builtins.property
-    def ignore_error_codes_matching(self) -> typing.Optional[str]:
+    def ignore_error_codes_matching(self) -> typing.Optional[builtins.str]:
         """The regex pattern to use to catch API errors.
 
         The ``code`` property of the
@@ -545,10 +567,11 @@ class AwsSdkCall:
         stability
         :stability: experimental
         """
-        return self._values.get("ignore_error_codes_matching")
+        result = self._values.get("ignore_error_codes_matching")
+        return result
 
     @builtins.property
-    def output_path(self) -> typing.Optional[str]:
+    def output_path(self) -> typing.Optional[builtins.str]:
         """Restrict the data returned by the custom resource to a specific path in the API response.
 
         Use this to limit the data returned by the custom
@@ -563,7 +586,8 @@ class AwsSdkCall:
         stability
         :stability: experimental
         """
-        return self._values.get("output_path")
+        result = self._values.get("output_path")
+        return result
 
     @builtins.property
     def parameters(self) -> typing.Any:
@@ -577,7 +601,8 @@ class AwsSdkCall:
         stability
         :stability: experimental
         """
-        return self._values.get("parameters")
+        result = self._values.get("parameters")
+        return result
 
     @builtins.property
     def physical_resource_id(self) -> typing.Optional["PhysicalResourceId"]:
@@ -591,10 +616,11 @@ class AwsSdkCall:
         stability
         :stability: experimental
         """
-        return self._values.get("physical_resource_id")
+        result = self._values.get("physical_resource_id")
+        return result
 
     @builtins.property
-    def region(self) -> typing.Optional[str]:
+    def region(self) -> typing.Optional[builtins.str]:
         """The region to send service requests to.
 
         **Note: Cross-region operations are generally considered an anti-pattern.**
@@ -606,12 +632,13 @@ class AwsSdkCall:
         stability
         :stability: experimental
         """
-        return self._values.get("region")
+        result = self._values.get("region")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -632,7 +659,7 @@ class PhysicalResourceId(
 
     @jsii.member(jsii_name="fromResponse")
     @builtins.classmethod
-    def from_response(cls, response_path: str) -> "PhysicalResourceId":
+    def from_response(cls, response_path: builtins.str) -> "PhysicalResourceId":
         """Extract the physical resource id from the path (dot notation) to the data in the API call response.
 
         :param response_path: -
@@ -644,7 +671,7 @@ class PhysicalResourceId(
 
     @jsii.member(jsii_name="of")
     @builtins.classmethod
-    def of(cls, id: str) -> "PhysicalResourceId":
+    def of(cls, id: builtins.str) -> "PhysicalResourceId":
         """Explicit physical resource id.
 
         :param id: -
@@ -654,9 +681,9 @@ class PhysicalResourceId(
         """
         return jsii.sinvoke(cls, "of", [id])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="id")
-    def id(self) -> typing.Optional[str]:
+    def id(self) -> typing.Optional[builtins.str]:
         """Literal string to be used as the physical id.
 
         stability
@@ -664,9 +691,9 @@ class PhysicalResourceId(
         """
         return jsii.get(self, "id")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="responsePath")
-    def response_path(self) -> typing.Optional[str]:
+    def response_path(self) -> typing.Optional[builtins.str]:
         """Path to a response data element to be used as the physical id.
 
         stability
@@ -675,6 +702,33 @@ class PhysicalResourceId(
         return jsii.get(self, "responsePath")
 
 
+class PhysicalResourceIdReference(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.custom_resources.PhysicalResourceIdReference",
+):
+    """Reference to the physical resource id that can be passed to the AWS operation as a parameter.
+
+    stability
+    :stability: experimental
+    """
+
+    def __init__(self) -> None:
+        """
+        stability
+        :stability: experimental
+        """
+        jsii.create(PhysicalResourceIdReference, self, [])
+
+    @jsii.member(jsii_name="toJSON")
+    def to_json(self) -> builtins.str:
+        """toJSON serialization to replace ``PhysicalResourceIdReference`` with a magic string.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "toJSON", [])
+
+
 @jsii.implements(_ICustomResourceProvider_6c6f53c6)
 class Provider(
     _Construct_f50a3f53,
@@ -690,7 +744,7 @@ class Provider(
     def __init__(
         self,
         scope: _Construct_f50a3f53,
-        id: str,
+        id: builtins.str,
         *,
         on_event_handler: _IFunction_1c1de0bc,
         is_complete_handler: typing.Optional[_IFunction_1c1de0bc] = None,
@@ -734,7 +788,7 @@ class Provider(
         """
         return jsii.invoke(self, "bind", [_])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="onEventHandler")
     def on_event_handler(self) -> _IFunction_1c1de0bc:
         """The user-defined AWS Lambda function which is invoked for all resource lifecycle operations (CREATE/UPDATE/DELETE).
@@ -744,9 +798,9 @@ class Provider(
         """
         return jsii.get(self, "onEventHandler")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="serviceToken")
-    def service_token(self) -> str:
+    def service_token(self) -> builtins.str:
         """The service token to use in order to define custom resources that are backed by this provider.
 
         stability
@@ -754,7 +808,7 @@ class Provider(
         """
         return jsii.get(self, "serviceToken")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="isCompleteHandler")
     def is_complete_handler(self) -> typing.Optional[_IFunction_1c1de0bc]:
         """The user-defined AWS Lambda function which is invoked asynchronously in order to determine if the operation is complete.
@@ -797,7 +851,7 @@ class ProviderProps:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "on_event_handler": on_event_handler,
         }
         if is_complete_handler is not None:
@@ -821,7 +875,9 @@ class ProviderProps:
         stability
         :stability: experimental
         """
-        return self._values.get("on_event_handler")
+        result = self._values.get("on_event_handler")
+        assert result is not None, "Required property 'on_event_handler' is missing"
+        return result
 
     @builtins.property
     def is_complete_handler(self) -> typing.Optional[_IFunction_1c1de0bc]:
@@ -841,7 +897,8 @@ class ProviderProps:
         stability
         :stability: experimental
         """
-        return self._values.get("is_complete_handler")
+        result = self._values.get("is_complete_handler")
+        return result
 
     @builtins.property
     def log_retention(self) -> typing.Optional[_RetentionDays_bdc7ad1f]:
@@ -857,7 +914,8 @@ class ProviderProps:
         stability
         :stability: experimental
         """
-        return self._values.get("log_retention")
+        result = self._values.get("log_retention")
+        return result
 
     @builtins.property
     def query_interval(self) -> typing.Optional[_Duration_5170c158]:
@@ -873,7 +931,8 @@ class ProviderProps:
         stability
         :stability: experimental
         """
-        return self._values.get("query_interval")
+        result = self._values.get("query_interval")
+        return result
 
     @builtins.property
     def total_timeout(self) -> typing.Optional[_Duration_5170c158]:
@@ -887,12 +946,13 @@ class ProviderProps:
         stability
         :stability: experimental
         """
-        return self._values.get("total_timeout")
+        result = self._values.get("total_timeout")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -907,7 +967,7 @@ class ProviderProps:
     name_mapping={"resources": "resources"},
 )
 class SdkCallsPolicyOptions:
-    def __init__(self, *, resources: typing.List[str]) -> None:
+    def __init__(self, *, resources: typing.List[builtins.str]) -> None:
         """Options for the auto-generation of policies based on the configured SDK calls.
 
         :param resources: The resources that the calls will have access to. It is best to use specific resource ARN's when possible. However, you can also use ``AwsCustomResourcePolicy.ANY_RESOURCE`` to allow access to all resources. For example, when ``onCreate`` is used to create a resource which you don't know the physical name of in advance. Note that will apply to ALL SDK calls.
@@ -915,12 +975,12 @@ class SdkCallsPolicyOptions:
         stability
         :stability: experimental
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "resources": resources,
         }
 
     @builtins.property
-    def resources(self) -> typing.List[str]:
+    def resources(self) -> typing.List[builtins.str]:
         """The resources that the calls will have access to.
 
         It is best to use specific resource ARN's when possible. However, you can also use ``AwsCustomResourcePolicy.ANY_RESOURCE``
@@ -932,12 +992,14 @@ class SdkCallsPolicyOptions:
         stability
         :stability: experimental
         """
-        return self._values.get("resources")
+        result = self._values.get("resources")
+        assert result is not None, "Required property 'resources' is missing"
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -952,6 +1014,7 @@ __all__ = [
     "AwsCustomResourceProps",
     "AwsSdkCall",
     "PhysicalResourceId",
+    "PhysicalResourceIdReference",
     "Provider",
     "ProviderProps",
     "SdkCallsPolicyOptions",
