@@ -5,14 +5,15 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from .._jsii import *
 
 
 class Default(
-    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Default"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.region_info.Default",
 ):
     """Provides default values for certain regional information points.
 
@@ -22,7 +23,12 @@ class Default(
 
     @jsii.member(jsii_name="servicePrincipal")
     @builtins.classmethod
-    def service_principal(cls, service: str, region: str, url_suffix: str) -> str:
+    def service_principal(
+        cls,
+        service: builtins.str,
+        region: builtins.str,
+        url_suffix: builtins.str,
+    ) -> builtins.str:
         """Computes a "standard" AWS Service principal for a given service, region and suffix.
 
         This is useful for example when
@@ -39,9 +45,9 @@ class Default(
         """
         return jsii.sinvoke(cls, "servicePrincipal", [service, region, url_suffix])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="VPC_ENDPOINT_SERVICE_NAME_PREFIX")
-    def VPC_ENDPOINT_SERVICE_NAME_PREFIX(cls) -> str:
+    def VPC_ENDPOINT_SERVICE_NAME_PREFIX(cls) -> builtins.str:
         """The default value for a VPC Endpoint Service name prefix, useful if you do not have a synthesize-time region literal available (all you have is ``{ "Ref": "AWS::Region" }``).
 
         stability
@@ -59,7 +65,11 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
 
     @jsii.member(jsii_name="find")
     @builtins.classmethod
-    def find(cls, region: str, name: str) -> typing.Optional[str]:
+    def find(
+        cls,
+        region: builtins.str,
+        name: builtins.str,
+    ) -> typing.Optional[builtins.str]:
         """Retrieves a fact from this Fact database.
 
         :param region: the name of the region (e.g: ``us-east-1``).
@@ -76,7 +86,9 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
     @jsii.member(jsii_name="register")
     @builtins.classmethod
     def register(
-        cls, fact: "IFact", allow_replacing: typing.Optional[bool] = None
+        cls,
+        fact: "IFact",
+        allow_replacing: typing.Optional[builtins.bool] = None,
     ) -> None:
         """Registers a new fact in this Fact database.
 
@@ -90,7 +102,7 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
 
     @jsii.member(jsii_name="requireFact")
     @builtins.classmethod
-    def require_fact(cls, region: str, name: str) -> str:
+    def require_fact(cls, region: builtins.str, name: builtins.str) -> builtins.str:
         """Retrieve a fact from the Fact database.
 
         (retrieval will fail if the specified region or
@@ -107,7 +119,10 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
     @jsii.member(jsii_name="unregister")
     @builtins.classmethod
     def unregister(
-        cls, region: str, name: str, value: typing.Optional[str] = None
+        cls,
+        region: builtins.str,
+        name: builtins.str,
+        value: typing.Optional[builtins.str] = None,
     ) -> None:
         """Removes a fact from the database.
 
@@ -120,9 +135,9 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
         """
         return jsii.sinvoke(cls, "unregister", [region, name, value])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="regions")
-    def regions(cls) -> typing.List[str]:
+    def regions(cls) -> typing.List[builtins.str]:
         """
         return
         :return:
@@ -137,7 +152,8 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.Fa
 
 
 class FactName(
-    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.FactName"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.region_info.FactName",
 ):
     """All standardized fact names.
 
@@ -154,7 +170,7 @@ class FactName(
 
     @jsii.member(jsii_name="servicePrincipal")
     @builtins.classmethod
-    def service_principal(cls, service: str) -> str:
+    def service_principal(cls, service: builtins.str) -> builtins.str:
         """The name of the regional service principal for a given service.
 
         :param service: the service name, either simple (e.g: ``s3``, ``codedeploy``) or qualified (e.g: ``s3.amazonaws.com``). The ``.amazonaws.com`` and ``.amazonaws.com.cn`` domains are stripped from service names, so they are canonicalized in that respect.
@@ -164,9 +180,9 @@ class FactName(
         """
         return jsii.sinvoke(cls, "servicePrincipal", [service])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="CDK_METADATA_RESOURCE_AVAILABLE")
-    def CDK_METADATA_RESOURCE_AVAILABLE(cls) -> str:
+    def CDK_METADATA_RESOURCE_AVAILABLE(cls) -> builtins.str:
         """Whether the AWS::CDK::Metadata CloudFormation Resource is available in-region or not.
 
         The value is a boolean
@@ -177,9 +193,9 @@ class FactName(
         """
         return jsii.sget(cls, "CDK_METADATA_RESOURCE_AVAILABLE")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="DLC_REPOSITORY_ACCOUNT")
-    def DLC_REPOSITORY_ACCOUNT(cls) -> str:
+    def DLC_REPOSITORY_ACCOUNT(cls) -> builtins.str:
         """The ID of the AWS account that owns the public ECR repository that contains the AWS Deep Learning Containers images in a given region.
 
         stability
@@ -187,9 +203,9 @@ class FactName(
         """
         return jsii.sget(cls, "DLC_REPOSITORY_ACCOUNT")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="DOMAIN_SUFFIX")
-    def DOMAIN_SUFFIX(cls) -> str:
+    def DOMAIN_SUFFIX(cls) -> builtins.str:
         """The domain suffix for a region (e.g: 'amazonaws.com`).
 
         stability
@@ -197,9 +213,9 @@ class FactName(
         """
         return jsii.sget(cls, "DOMAIN_SUFFIX")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="ELBV2_ACCOUNT")
-    def ELBV2_ACCOUNT(cls) -> str:
+    def ELBV2_ACCOUNT(cls) -> builtins.str:
         """The account for ELBv2 in this region.
 
         stability
@@ -207,9 +223,9 @@ class FactName(
         """
         return jsii.sget(cls, "ELBV2_ACCOUNT")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="PARTITION")
-    def PARTITION(cls) -> str:
+    def PARTITION(cls) -> builtins.str:
         """The name of the partition for a region (e.g: 'aws', 'aws-cn', ...).
 
         stability
@@ -217,9 +233,9 @@ class FactName(
         """
         return jsii.sget(cls, "PARTITION")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="S3_STATIC_WEBSITE_ENDPOINT")
-    def S3_STATIC_WEBSITE_ENDPOINT(cls) -> str:
+    def S3_STATIC_WEBSITE_ENDPOINT(cls) -> builtins.str:
         """The endpoint used for hosting S3 static websites.
 
         stability
@@ -227,9 +243,9 @@ class FactName(
         """
         return jsii.sget(cls, "S3_STATIC_WEBSITE_ENDPOINT")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="S3_STATIC_WEBSITE_ZONE_53_HOSTED_ZONE_ID")
-    def S3_STATIC_WEBSITE_ZONE_53_HOSTED_ZONE_ID(cls) -> str:
+    def S3_STATIC_WEBSITE_ZONE_53_HOSTED_ZONE_ID(cls) -> builtins.str:
         """The endpoint used for aliasing S3 static websites in Route 53.
 
         stability
@@ -237,9 +253,9 @@ class FactName(
         """
         return jsii.sget(cls, "S3_STATIC_WEBSITE_ZONE_53_HOSTED_ZONE_ID")
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="VPC_ENDPOINT_SERVICE_NAME_PREFIX")
-    def VPC_ENDPOINT_SERVICE_NAME_PREFIX(cls) -> str:
+    def VPC_ENDPOINT_SERVICE_NAME_PREFIX(cls) -> builtins.str:
         """The prefix for VPC Endpoint Service names, cn.com.amazonaws.vpce for China regions, com.amazonaws.vpce otherwise.
 
         stability
@@ -249,7 +265,7 @@ class FactName(
 
 
 @jsii.interface(jsii_type="monocdk-experiment.region_info.IFact")
-class IFact(jsii.compat.Protocol):
+class IFact(typing_extensions.Protocol):
     """A fact that can be registered about a particular region.
 
     stability
@@ -260,9 +276,9 @@ class IFact(jsii.compat.Protocol):
     def __jsii_proxy_class__():
         return _IFactProxy
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """The name of this fact.
 
         Standardized values are provided by the ``Facts`` class.
@@ -272,9 +288,9 @@ class IFact(jsii.compat.Protocol):
         """
         ...
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="region")
-    def region(self) -> str:
+    def region(self) -> builtins.str:
         """The region for which this fact applies.
 
         stability
@@ -282,9 +298,9 @@ class IFact(jsii.compat.Protocol):
         """
         ...
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="value")
-    def value(self) -> typing.Optional[str]:
+    def value(self) -> typing.Optional[builtins.str]:
         """The value of this fact.
 
         stability
@@ -300,11 +316,11 @@ class _IFactProxy:
     :stability: experimental
     """
 
-    __jsii_type__ = "monocdk-experiment.region_info.IFact"
+    __jsii_type__: typing.ClassVar[str] = "monocdk-experiment.region_info.IFact"
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """The name of this fact.
 
         Standardized values are provided by the ``Facts`` class.
@@ -314,9 +330,9 @@ class _IFactProxy:
         """
         return jsii.get(self, "name")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="region")
-    def region(self) -> str:
+    def region(self) -> builtins.str:
         """The region for which this fact applies.
 
         stability
@@ -324,9 +340,9 @@ class _IFactProxy:
         """
         return jsii.get(self, "region")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="value")
-    def value(self) -> typing.Optional[str]:
+    def value(self) -> typing.Optional[builtins.str]:
         """The value of this fact.
 
         stability
@@ -336,7 +352,8 @@ class _IFactProxy:
 
 
 class RegionInfo(
-    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.region_info.RegionInfo"
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.region_info.RegionInfo",
 ):
     """Information pertaining to an AWS region.
 
@@ -346,7 +363,7 @@ class RegionInfo(
 
     @jsii.member(jsii_name="get")
     @builtins.classmethod
-    def get(cls, name: str) -> "RegionInfo":
+    def get(cls, name: builtins.str) -> "RegionInfo":
         """Obtain region info for a given region name.
 
         :param name: the name of the region (e.g: us-east-1).
@@ -358,7 +375,10 @@ class RegionInfo(
 
     @jsii.member(jsii_name="regionMap")
     @builtins.classmethod
-    def region_map(cls, fact_name: str) -> typing.Mapping[str, str]:
+    def region_map(
+        cls,
+        fact_name: builtins.str,
+    ) -> typing.Mapping[builtins.str, builtins.str]:
         """Retrieves a collection of all fact values for all regions that fact is defined in.
 
         :param fact_name: the name of the fact to retrieve values for. For a list of common fact names, see the FactName class
@@ -375,7 +395,7 @@ class RegionInfo(
         return jsii.sinvoke(cls, "regionMap", [fact_name])
 
     @jsii.member(jsii_name="servicePrincipal")
-    def service_principal(self, service: str) -> typing.Optional[str]:
+    def service_principal(self, service: builtins.str) -> typing.Optional[builtins.str]:
         """The name of the service principal for a given service in this region.
 
         :param service: the service name (e.g: s3.amazonaws.com).
@@ -385,7 +405,7 @@ class RegionInfo(
         """
         return jsii.invoke(self, "servicePrincipal", [service])
 
-    @jsii.python.classproperty
+    @jsii.python.classproperty # type: ignore
     @jsii.member(jsii_name="regions")
     def regions(cls) -> typing.List["RegionInfo"]:
         """
@@ -400,9 +420,9 @@ class RegionInfo(
         """
         return jsii.sget(cls, "regions")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cdkMetadataResourceAvailable")
-    def cdk_metadata_resource_available(self) -> bool:
+    def cdk_metadata_resource_available(self) -> builtins.bool:
         """Whether the ``AWS::CDK::Metadata`` CloudFormation Resource is available in this region or not.
 
         stability
@@ -410,18 +430,18 @@ class RegionInfo(
         """
         return jsii.get(self, "cdkMetadataResourceAvailable")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="name")
-    def name(self) -> str:
+    def name(self) -> builtins.str:
         """
         stability
         :stability: experimental
         """
         return jsii.get(self, "name")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="dlcRepositoryAccount")
-    def dlc_repository_account(self) -> typing.Optional[str]:
+    def dlc_repository_account(self) -> typing.Optional[builtins.str]:
         """The ID of the AWS account that owns the public ECR repository containing the AWS Deep Learning Containers images in this region.
 
         stability
@@ -429,9 +449,9 @@ class RegionInfo(
         """
         return jsii.get(self, "dlcRepositoryAccount")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="domainSuffix")
-    def domain_suffix(self) -> typing.Optional[str]:
+    def domain_suffix(self) -> typing.Optional[builtins.str]:
         """The domain name suffix (e.g: amazonaws.com) for this region.
 
         stability
@@ -439,9 +459,9 @@ class RegionInfo(
         """
         return jsii.get(self, "domainSuffix")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="elbv2Account")
-    def elbv2_account(self) -> typing.Optional[str]:
+    def elbv2_account(self) -> typing.Optional[builtins.str]:
         """The account ID for ELBv2 in this region.
 
         stability
@@ -449,9 +469,9 @@ class RegionInfo(
         """
         return jsii.get(self, "elbv2Account")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="partition")
-    def partition(self) -> typing.Optional[str]:
+    def partition(self) -> typing.Optional[builtins.str]:
         """The name of the ARN partition for this region (e.g: aws).
 
         stability
@@ -459,9 +479,9 @@ class RegionInfo(
         """
         return jsii.get(self, "partition")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="s3StaticWebsiteEndpoint")
-    def s3_static_website_endpoint(self) -> typing.Optional[str]:
+    def s3_static_website_endpoint(self) -> typing.Optional[builtins.str]:
         """The endpoint used by S3 static website hosting in this region (e.g: s3-static-website-us-east-1.amazonaws.com).
 
         stability
@@ -469,9 +489,9 @@ class RegionInfo(
         """
         return jsii.get(self, "s3StaticWebsiteEndpoint")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="s3StaticWebsiteHostedZoneId")
-    def s3_static_website_hosted_zone_id(self) -> typing.Optional[str]:
+    def s3_static_website_hosted_zone_id(self) -> typing.Optional[builtins.str]:
         """The hosted zone ID used by Route 53 to alias a S3 static website in this region (e.g: Z2O1EMRO9K5GLX).
 
         stability
@@ -479,9 +499,9 @@ class RegionInfo(
         """
         return jsii.get(self, "s3StaticWebsiteHostedZoneId")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="vpcEndpointServiceNamePrefix")
-    def vpc_endpoint_service_name_prefix(self) -> typing.Optional[str]:
+    def vpc_endpoint_service_name_prefix(self) -> typing.Optional[builtins.str]:
         """The prefix for VPC Endpoint Service names, cn.com.amazonaws.vpce for China regions, com.amazonaws.vpce otherwise.
 
         stability
